#!/usr/bin/perl

use strict;
use lib 't/lib';

use Test::Deep qw(cmp_deeply);

use FusionInventory::Agent::Tools::Hardware;
use FusionInventory::Test::Hardware;

my %tests = (
    'cisco/C1040.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1040 Software (C1140-K9W7-M), Version 12.4(25d)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 11-Aug-11 02:58 by prod_rel_team',
            SNMPHOSTNAME => 'WIFI-IPJ-etage2-82.wifi-mngt.dauphine.fr',
            MAC          => '00:00:00:00:00:00',
            MODEL        => 'Aironet 1040 series',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1040 Software (C1140-K9W7-M), Version 12.4(25d)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 11-Aug-11 02:58 by prod_rel_team',
            SNMPHOSTNAME => 'WIFI-IPJ-etage2-82.wifi-mngt.dauphine.fr',
            MAC          => 'a4:18:75:c2:67:00',
            MODELSNMP    => 'Networking2178',
            MODEL        => 'Aironet 1040 series',
            FIRMWARE     => undef,
            SERIAL       => 'FCZ1623Z2XQ',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Aironet 1040 series',
                COMMENTS     => 'Cisco IOS Software, C1040 Software (C1140-K9W7-M), Version 12.4(25d)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 11-Aug-11 02:58 by prod_rel_team',
                NAME         => 'WIFI-IPJ-etage2-82.wifi-mngt.dauphine.fr',
                SERIAL       => 'FCZ1623Z2XQ',
                FIRMWARE     => 'CW_VERSION$12.4(25d)JA1$',
                IPS          => {
                    IP => [
                        '192.168.55.82',
                    ],
                },
                MAC          => 'a4:18:75:c2:67:00',
                UPTIME       => '(829014147) 95 days, 22:49:01.47',
                CPU          => '96',
                RAM          => '95',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Do0',
                        IFDESCR          => 'Dot11Radio0',
                        IFTYPE           => '71',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => 'a4:18:75:c2:67:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(767607999) 88 days, 20:14:39.99',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '2545707486',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2562804791',
                        IFOUTERRORS      => '7309',
                    },
                    {
                        IFNUMBER         => '2',
                        IFNAME           => 'Do1',
                        IFDESCR          => 'Dot11Radio1',
                        IFTYPE           => '71',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => 'a4:18:75:a5:27:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(1620) 0:00:16.20',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '3',
                        IFNAME           => 'Gi0',
                        IFDESCR          => 'GigabitEthernet0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'a4:93:4c:93:a1:b5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1559) 0:00:15.59',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1203274941',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2425186262',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'Nu0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'Do0.7',
                        IFDESCR          => 'Dot11Radio0.7',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => 'a4:18:75:c2:67:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(767607999) 88 days, 20:14:39.99',
                        IFINOCTETS       => '1696380185',
                        IFOUTOCTETS      => '3114577963',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'Do0.18',
                        IFDESCR          => 'Dot11Radio0.18',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => 'a4:18:75:c2:67:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(767607999) 88 days, 20:14:39.99',
                        IFINOCTETS       => '154557539',
                        IFOUTOCTETS      => '2680413485',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'Do0.40',
                        IFDESCR          => 'Dot11Radio0.40',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => 'a4:18:75:c2:67:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(767607999) 88 days, 20:14:39.99',
                        IFINOCTETS       => '116190244',
                        IFOUTOCTETS      => '2076205012',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'Gi0.7',
                        IFDESCR          => 'GigabitEthernet0.7',
                        IFALIAS          => 'eduspot',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'a4:93:4c:93:a1:b5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1527) 0:00:15.27',
                        IFINOCTETS       => '1679633303',
                        IFOUTOCTETS      => '1704767676',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'Gi0.18',
                        IFDESCR          => 'GigabitEthernet0.18',
                        IFALIAS          => 'eduroam',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'a4:93:4c:93:a1:b5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1531) 0:00:15.31',
                        IFINOCTETS       => '2795453458',
                        IFOUTOCTETS      => '154132236',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'Gi0.40',
                        IFDESCR          => 'GigabitEthernet0.40',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'a4:93:4c:93:a1:b5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1531) 0:00:15.31',
                        IFINOCTETS       => '2883284913',
                        IFOUTOCTETS      => '111865705',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'BV1',
                        IFDESCR          => 'BVI1',
                        IFTYPE           => '209',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        IP               => '192.168.55.82',
                        MAC              => 'a4:93:4c:93:a1:b5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1634) 0:00:16.34',
                        IFINOCTETS       => '607347610',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '419789539',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C1130.1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2008 by Cisco Systems, Inc.
Compiled Wed 19-Mar-08 18:08 by prod_rel_team',
            SNMPHOSTNAME => 'ap-CP6-BU-161.wifi-mngt.dauphine.fr',
            MAC          => '00:00:00:00:00:00',
            MODEL        => 'Aironet 1130 series',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2008 by Cisco Systems, Inc.
Compiled Wed 19-Mar-08 18:08 by prod_rel_team',
            SNMPHOSTNAME => 'ap-CP6-BU-161.wifi-mngt.dauphine.fr',
            MAC          => '00:13:5f:fa:f2:50',
            MODELSNMP    => 'Networking2176',
            MODEL        => 'Aironet 1130 series',
            FIRMWARE     => undef,
            SERIAL       => 'FCZ0930Q00Z',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Aironet 1130 series',
                COMMENTS     => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2008 by Cisco Systems, Inc.
Compiled Wed 19-Mar-08 18:08 by prod_rel_team',
                NAME         => 'ap-CP6-BU-161.wifi-mngt.dauphine.fr',
                SERIAL       => 'FCZ0930Q00Z',
                FIRMWARE     => 'CW_VERSION$12.4(10b)JA3$',
                MAC          => '00:13:5f:fa:f2:50',
                CPU          => '97',
                RAM          => '23',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFDESCR          => 'Dot11Radio0',
                        IFTYPE           => '71',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:f2:50',
                        IFLASTCHANGE     => '(7701) 0:01:17.01',
                        IFINOCTETS       => '2723745631',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2002017105',
                        IFOUTERRORS      => '91561',
                    },
                    {
                        IFNUMBER         => '2',
                        IFDESCR          => 'Dot11Radio1',
                        IFTYPE           => '71',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fe:f2:30',
                        IFLASTCHANGE     => '(1204) 0:00:12.04',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '3',
                        IFDESCR          => 'FastEthernet0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b1:ce',
                        IFLASTCHANGE     => '(1142) 0:00:11.42',
                        IFINOCTETS       => '1922539881',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3697487330',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '4',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFDESCR          => 'Dot11Radio0.7',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:f2:50',
                        IFLASTCHANGE     => '(7607) 0:01:16.07',
                        IFINOCTETS       => '2687372679',
                        IFOUTOCTETS      => '1195595259',
                    },
                    {
                        IFNUMBER         => '6',
                        IFDESCR          => 'Dot11Radio0.18',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:f2:50',
                        IFLASTCHANGE     => '(7607) 0:01:16.07',
                        IFINOCTETS       => '23434868',
                        IFOUTOCTETS      => '822989071',
                    },
                    {
                        IFNUMBER         => '7',
                        IFDESCR          => 'Dot11Radio0.40',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:f2:50',
                        IFLASTCHANGE     => '(7607) 0:01:16.07',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '540',
                    },
                    {
                        IFNUMBER         => '8',
                        IFDESCR          => 'Dot11Radio1.40',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fe:f2:30',
                        IFLASTCHANGE     => '(1096) 0:00:10.96',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFDESCR          => 'FastEthernet0.7',
                        IFTYPE           => '135',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b1:ce',
                        IFLASTCHANGE     => '(1107) 0:00:11.07',
                        IFINOCTETS       => '3495668832',
                        IFOUTOCTETS      => '2702597576',
                    },
                    {
                        IFNUMBER         => '10',
                        IFDESCR          => 'FastEthernet0.18',
                        IFTYPE           => '135',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b1:ce',
                        IFLASTCHANGE     => '(1108) 0:00:11.08',
                        IFINOCTETS       => '843457950',
                        IFOUTOCTETS      => '23050498',
                    },
                    {
                        IFNUMBER         => '11',
                        IFDESCR          => 'FastEthernet0.40',
                        IFTYPE           => '135',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b1:ce',
                        IFLASTCHANGE     => '(1109) 0:00:11.09',
                        IFINOCTETS       => '1016603638',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFDESCR          => 'BVI1',
                        IFTYPE           => '209',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b1:ce',
                        IFLASTCHANGE     => '(1210) 0:00:12.10',
                        IFINOCTETS       => '410354460',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '10537521',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C1130.2.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2008 by Cisco Systems, Inc.
Compiled Wed 19-Mar-08 18:08 by prod_rel_team',
            SNMPHOSTNAME => 'ap-P405-45.wifi-mngt.dauphine.fr',
            MAC          => '00:00:00:00:00:00',
            MODEL        => 'Aironet 1130 series',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2008 by Cisco Systems, Inc.
Compiled Wed 19-Mar-08 18:08 by prod_rel_team',
            SNMPHOSTNAME => 'ap-P405-45.wifi-mngt.dauphine.fr',
            MAC          => '00:13:5f:fa:fa:50',
            MODELSNMP    => 'Networking2176',
            MODEL        => 'Aironet 1130 series',
            FIRMWARE     => undef,
            SERIAL       => 'FCZ0930Q01A',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Aironet 1130 series',
                COMMENTS     => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2008 by Cisco Systems, Inc.
Compiled Wed 19-Mar-08 18:08 by prod_rel_team',
                NAME         => 'ap-P405-45.wifi-mngt.dauphine.fr',
                SERIAL       => 'FCZ0930Q01A',
                FIRMWARE     => 'CW_VERSION$12.4(10b)JA3$',
                IPS          => {
                    IP => [
                        '192.168.55.45',
                    ],
                },
                MAC          => '00:13:5f:fa:fa:50',
                UPTIME       => '(34865419) 4 days, 0:50:54.19',
                CPU          => '98',
                RAM          => '23',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Do0',
                        IFDESCR          => 'Dot11Radio0',
                        IFTYPE           => '71',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:fa:50',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7532) 0:01:15.32',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '1847463852',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '782166020',
                        IFOUTERRORS      => '86765',
                    },
                    {
                        IFNUMBER         => '2',
                        IFNAME           => 'Do1',
                        IFDESCR          => 'Dot11Radio1',
                        IFTYPE           => '71',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fe:fa:30',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(1198) 0:00:11.98',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '3',
                        IFNAME           => 'Fa0',
                        IFDESCR          => 'FastEthernet0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b2:ce',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1136) 0:00:11.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3855516427',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2786837221',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'Nu0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'Do0.7',
                        IFDESCR          => 'Dot11Radio0.7',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:fa:50',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7438) 0:01:14.38',
                        IFINOCTETS       => '1833237924',
                        IFOUTOCTETS      => '3508924423',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'Do0.18',
                        IFDESCR          => 'Dot11Radio0.18',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:fa:50',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7438) 0:01:14.38',
                        IFINOCTETS       => '396827',
                        IFOUTOCTETS      => '694399025',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'Do0.40',
                        IFDESCR          => 'Dot11Radio0.40',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:fa:50',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7438) 0:01:14.38',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '6940608',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'Do1.40',
                        IFDESCR          => 'Dot11Radio1.40',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fe:fa:30',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(1089) 0:00:10.89',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'Fa0.7',
                        IFDESCR          => 'FastEthernet0.7',
                        IFALIAS          => 'eduspot',
                        IFTYPE           => '135',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b2:ce',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1100) 0:00:11.00',
                        IFINOCTETS       => '1143594822',
                        IFOUTOCTETS      => '1841662240',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'Fa0.18',
                        IFDESCR          => 'FastEthernet0.18',
                        IFALIAS          => 'eduroam',
                        IFTYPE           => '135',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b2:ce',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1102) 0:00:11.02',
                        IFINOCTETS       => '714789539',
                        IFOUTOCTETS      => '306665',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'Fa0.40',
                        IFDESCR          => 'FastEthernet0.40',
                        IFTYPE           => '135',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b2:ce',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1103) 0:00:11.03',
                        IFINOCTETS       => '970211324',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'BV1',
                        IFDESCR          => 'BVI1',
                        IFTYPE           => '209',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        IP               => '192.168.55.45',
                        MAC              => '00:14:6a:d6:b2:ce',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1204) 0:00:12.04',
                        IFINOCTETS       => '411852720',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '8408247',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C1130.3.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(21a)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Wed 16-Sep-09 18:36 by prod_rel_team',
            SNMPHOSTNAME => 'ap-D416-141.wifi-mngt.dauphine.fr',
            MAC          => '00:00:00:00:00:00',
            MODEL        => 'Aironet 1130 series',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(21a)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Wed 16-Sep-09 18:36 by prod_rel_team',
            SNMPHOSTNAME => 'ap-D416-141.wifi-mngt.dauphine.fr',
            MAC          => '00:13:5f:fa:f9:a0',
            MODELSNMP    => 'Networking2191',
            MODEL        => 'Aironet 1130 series',
            FIRMWARE     => undef,
            SERIAL       => 'FCZ0930Q01N',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Aironet 1130 series',
                COMMENTS     => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(21a)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Wed 16-Sep-09 18:36 by prod_rel_team',
                NAME         => 'ap-D416-141.wifi-mngt.dauphine.fr',
                SERIAL       => 'FCZ0930Q01N',
                FIRMWARE     => 'CW_VERSION$12.4(21a)JA1$',
                IPS          => {
                    IP => [
                        '192.168.55.141',
                    ],
                },
                MAC          => '00:13:5f:fa:f9:a0',
                UPTIME       => '(131654419) 15 days, 5:42:24.19',
                CPU          => '97',
                RAM          => '23',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Do0',
                        IFDESCR          => 'Dot11Radio0',
                        IFTYPE           => '71',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:f9:a0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '1986250540',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4034040569',
                        IFOUTERRORS      => '15496',
                    },
                    {
                        IFNUMBER         => '2',
                        IFNAME           => 'Do1',
                        IFDESCR          => 'Dot11Radio1',
                        IFTYPE           => '71',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fe:f9:80',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(1388) 0:00:13.88',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '3',
                        IFNAME           => 'Fa0',
                        IFDESCR          => 'FastEthernet0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b2:b8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1333) 0:00:13.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3182552204',
                        IFINERRORS       => '1817884',
                        IFOUTOCTETS      => '2589712033',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:0b:5f:cc:d8:80',
                                    '00:16:76:cf:94:62',
                                    '00:20:a6:49:7e:fb',
                                    '00:26:b6:15:20:23',
                                    '00:26:08:f9:3d:c4',
                                    '68:a8:6d:51:65:da',
                                    '7c:d1:c3:f4:e7:89',
                                    '10:9a:dd:a5:32:33',
                                    'bc:52:b7:38:91:13',
                                    'e0:b9:ba:af:ad:4f',
                                    'e0:f8:47:34:4c:b4',
                                    'e0:06:e6:96:d4:a1',
                                    'e8:06:88:57:6d:7d',
                                    '18:a9:05:e3:0c:f5',
                                    'fc:25:3f:7b:7d:f6',
                                    '28:6a:ba:59:82:44',
                                    '34:15:9e:94:10:71',
                                    '40:6c:8f:1d:c0:7f',
                                    '4c:0f:6e:d5:3c:02',
                                    '54:04:a6:96:01:e1',
                                    '5c:96:9d:76:78:9d',
                                    '5c:ac:4c:1a:0f:00',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'Nu0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'Do0.7',
                        IFDESCR          => 'Dot11Radio0.7',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:f9:a0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFINOCTETS       => '1525293600',
                        IFOUTOCTETS      => '902858571',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'Do0.18',
                        IFDESCR          => 'Dot11Radio0.18',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:f9:a0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFINOCTETS       => '8650226',
                        IFOUTOCTETS      => '827133541',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'Do0.40',
                        IFDESCR          => 'Dot11Radio0.40',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:f9:a0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFINOCTETS       => '46832680',
                        IFOUTOCTETS      => '39829396',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'Do1.40',
                        IFDESCR          => 'Dot11Radio1.40',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fe:f9:80',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(1288) 0:00:12.88',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'Fa0.7',
                        IFDESCR          => 'FastEthernet0.7',
                        IFALIAS          => 'eduspot',
                        IFTYPE           => '135',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b2:b8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1298) 0:00:12.98',
                        IFINOCTETS       => '3827474904',
                        IFOUTOCTETS      => '1534007354',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'Fa0.18',
                        IFDESCR          => 'FastEthernet0.18',
                        IFALIAS          => 'eduroam',
                        IFTYPE           => '135',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b2:b8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1299) 0:00:12.99',
                        IFINOCTETS       => '871447532',
                        IFOUTOCTETS      => '8082038',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'Fa0.40',
                        IFDESCR          => 'FastEthernet0.40',
                        IFTYPE           => '135',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b2:b8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1300) 0:00:13.00',
                        IFINOCTETS       => '1834903826',
                        IFOUTOCTETS      => '46294714',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'BV1',
                        IFDESCR          => 'BVI1',
                        IFTYPE           => '209',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        IP               => '192.168.55.141',
                        MAC              => '00:14:6a:d6:b2:b8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1402) 0:00:14.02',
                        IFINOCTETS       => '476038021',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '22916493',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C1130.4.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(21a)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Wed 16-Sep-09 18:36 by prod_rel_team',
            SNMPHOSTNAME => 'ap-D416-141.wifi-mngt.dauphine.fr',
            MAC          => '00:00:00:00:00:00',
            MODEL        => 'Aironet 1130 series',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(21a)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Wed 16-Sep-09 18:36 by prod_rel_team',
            SNMPHOSTNAME => 'ap-D416-141.wifi-mngt.dauphine.fr',
            MAC          => '00:13:5f:fa:f9:a0',
            MODELSNMP    => 'Networking2191',
            MODEL        => 'Aironet 1130 series',
            FIRMWARE     => undef,
            SERIAL       => 'FCZ0930Q01N',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Aironet 1130 series',
                COMMENTS     => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(21a)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Wed 16-Sep-09 18:36 by prod_rel_team',
                NAME         => 'ap-D416-141.wifi-mngt.dauphine.fr',
                SERIAL       => 'FCZ0930Q01N',
                FIRMWARE     => 'CW_VERSION$12.4(21a)JA1$',
                IPS          => {
                    IP => [
                        '192.168.55.141',
                    ],
                },
                MAC          => '00:13:5f:fa:f9:a0',
                UPTIME       => '(131936738) 15 days, 6:29:27.38',
                CPU          => '98',
                RAM          => '23',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Do0',
                        IFDESCR          => 'Dot11Radio0',
                        IFTYPE           => '71',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:f9:a0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '2008650512',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4262978259',
                        IFOUTERRORS      => '15567',
                    },
                    {
                        IFNUMBER         => '2',
                        IFNAME           => 'Do1',
                        IFDESCR          => 'Dot11Radio1',
                        IFTYPE           => '71',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fe:f9:80',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(1388) 0:00:13.88',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '3',
                        IFNAME           => 'Fa0',
                        IFDESCR          => 'FastEthernet0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b2:b8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1333) 0:00:13.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3482914011',
                        IFINERRORS       => '1817884',
                        IFOUTOCTETS      => '2611425256',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:0b:5f:cc:d8:80',
                                    '00:16:76:cf:94:62',
                                    '00:20:a6:49:7e:fb',
                                    '00:26:b6:15:20:23',
                                    '00:26:08:f9:3d:c4',
                                    '68:a8:6d:51:65:da',
                                    '7c:d1:c3:f4:e7:89',
                                    '10:9a:dd:a5:32:33',
                                    'bc:52:b7:38:91:13',
                                    'e0:b9:ba:af:ad:4f',
                                    'e0:f8:47:34:4c:b4',
                                    'e0:06:e6:96:d4:a1',
                                    'e8:06:88:57:6d:7d',
                                    '18:a9:05:e3:0c:f5',
                                    'fc:25:3f:7b:7d:f6',
                                    '28:6a:ba:59:82:44',
                                    '34:15:9e:94:10:71',
                                    '40:6c:8f:1d:c0:7f',
                                    '4c:0f:6e:d5:3c:02',
                                    '54:04:a6:96:01:e1',
                                    '5c:96:9d:76:78:9d',
                                    '5c:ac:4c:1a:0f:00',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'Nu0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'Do0.7',
                        IFDESCR          => 'Dot11Radio0.7',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:f9:a0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFINOCTETS       => '1545983180',
                        IFOUTOCTETS      => '1194767553',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'Do0.18',
                        IFDESCR          => 'Dot11Radio0.18',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:f9:a0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFINOCTETS       => '8650226',
                        IFOUTOCTETS      => '828451237',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'Do0.40',
                        IFDESCR          => 'Dot11Radio0.40',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fa:f9:a0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFINOCTETS       => '46832680',
                        IFOUTOCTETS      => '39829396',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'Do1.40',
                        IFDESCR          => 'Dot11Radio1.40',
                        IFTYPE           => '135',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        MAC              => '00:13:5f:fe:f9:80',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(1288) 0:00:12.88',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'Fa0.7',
                        IFDESCR          => 'FastEthernet0.7',
                        IFALIAS          => 'eduspot',
                        IFTYPE           => '135',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b2:b8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1298) 0:00:12.98',
                        IFINOCTETS       => '4128177048',
                        IFOUTOCTETS      => '1554773976',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'Fa0.18',
                        IFDESCR          => 'FastEthernet0.18',
                        IFALIAS          => 'eduroam',
                        IFTYPE           => '135',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b2:b8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1299) 0:00:12.99',
                        IFINOCTETS       => '872932219',
                        IFOUTOCTETS      => '8082038',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'Fa0.40',
                        IFDESCR          => 'FastEthernet0.40',
                        IFTYPE           => '135',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:14:6a:d6:b2:b8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1300) 0:00:13.00',
                        IFINOCTETS       => '1835337081',
                        IFOUTOCTETS      => '46294714',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'BV1',
                        IFDESCR          => 'BVI1',
                        IFTYPE           => '209',
                        IFSPEED          => '54000000',
                        IFMTU            => '1500',
                        IP               => '192.168.55.141',
                        MAC              => '00:14:6a:d6:b2:b8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1402) 0:00:14.02',
                        IFINOCTETS       => '476739635',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '23738876',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2924.1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco Internetwork Operating System Software 
IOS (tm) C2900XL Software (C2900XL-C3H2S-M), Version 12.0(5)WC17, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2007 by cisco Systems, Inc.
Compiled Tue 13-Feb-07 15:27 by antonino',
            MAC          => '00:01:96:38:57:40',
            MODEL        => 'Catalyst 2924 XLv',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco Internetwork Operating System Software 
IOS (tm) C2900XL Software (C2900XL-C3H2S-M), Version 12.0(5)WC17, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2007 by cisco Systems, Inc.
Compiled Tue 13-Feb-07 15:27 by antonino',
            MAC          => '00:01:96:38:57:40',
            MODELSNMP    => 'Networking1921',
            MODEL        => 'Catalyst 2924 XLv',
            FIRMWARE     => undef,
            SERIAL       => 'FAB0411S1FB',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2924 XLv',
                COMMENTS     => 'Cisco Internetwork Operating System Software 
IOS (tm) C2900XL Software (C2900XL-C3H2S-M), Version 12.0(5)WC17, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2007 by cisco Systems, Inc.
Compiled Tue 13-Feb-07 15:27 by antonino',
                CONTACT      => 'Service Informatique',
                SERIAL       => 'FAB0411S1FB',
                MAC          => '00:01:96:38:57:40',
                UPTIME       => '(284153455) 32 days, 21:18:54.55',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:40',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3560) 0:00:35.60',
                        IFINOCTETS       => '2068559518',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '239046073',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '2',
                        IFNAME           => 'Fa0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:41',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3768) 0:00:37.68',
                        IFINOCTETS       => '4145041811',
                        IFINERRORS       => '287',
                        IFOUTOCTETS      => '2773240205',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1b:21:2c:75:79',
                                    '00:1b:21:2c:75:7d',
                                    '00:1b:21:2c:76:65',
                                    '00:1b:21:2c:76:61',
                                    '00:1e:f7:0d:8f:c5',
                                    'c4:64:13:11:31:81',
                                    'c4:64:13:11:31:60',
                                    'c4:64:13:2b:f2:25',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '3',
                        IFNAME           => 'Fa0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:42',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4316) 0:00:43.16',
                        IFINOCTETS       => '313882495',
                        IFINERRORS       => '670',
                        IFOUTOCTETS      => '3165765220',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'Fa0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:43',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(278322224) 32 days, 5:07:02.24',
                        IFINOCTETS       => '82051036',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2297881053',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'Fa0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:44',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(280583541) 32 days, 11:23:55.41',
                        IFINOCTETS       => '2615405',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '769622527',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'Fa0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:45',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1156003) 3:12:40.03',
                        IFINOCTETS       => '337662308',
                        IFINERRORS       => '635',
                        IFOUTOCTETS      => '3188808108',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'Fa0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFALIAS          => '\"PC Badge doublon\\',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:46',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(278469857) 32 days, 5:31:38.57',
                        IFINOCTETS       => '69655815',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1528986873',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'Fa0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:47',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3083) 0:00:30.83',
                        IFINOCTETS       => '64',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '64',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'Fa0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:48',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3113) 0:00:31.13',
                        IFINOCTETS       => '64',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '64',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'Fa0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:49',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(283443490) 32 days, 19:20:34.90',
                        IFINOCTETS       => '757175979',
                        IFINERRORS       => '7',
                        IFOUTOCTETS      => '3427157577',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'Fa0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:4a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(283444792) 32 days, 19:20:47.92',
                        IFINOCTETS       => '268866403',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2095387873',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'Fa0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:4b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(283442119) 32 days, 19:20:21.19',
                        IFINOCTETS       => '911545598',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1184611073',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '13',
                        IFNAME           => 'Fa0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:4c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(282306267) 32 days, 16:11:02.67',
                        IFINOCTETS       => '2634719610',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3752721734',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '14',
                        IFNAME           => 'Fa0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFALIAS          => 'J142A-Amphi',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:4d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(279224229) 32 days, 7:37:22.29',
                        IFINOCTETS       => '2492870',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '85878063',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '15',
                        IFNAME           => 'Fa0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:4e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3297) 0:00:32.97',
                        IFINOCTETS       => '64',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '64',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '16',
                        IFNAME           => 'Fa0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFALIAS          => 'F13-J11B',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:4f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(277924858) 32 days, 4:00:48.58',
                        IFINOCTETS       => '41476203',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '568386769',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '17',
                        IFNAME           => 'Fa0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:50',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(102521827) 11 days, 20:46:58.27',
                        IFINOCTETS       => '399066298',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2515430057',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '18',
                        IFNAME           => 'Fa0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:51',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3390) 0:00:33.90',
                        IFINOCTETS       => '64',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '64',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '19',
                        IFNAME           => 'Fa0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:52',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3419) 0:00:34.19',
                        IFINOCTETS       => '64',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '64',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '20',
                        IFNAME           => 'Fa0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:53',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(120755527) 13 days, 23:25:55.27',
                        IFINOCTETS       => '13226590',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2768247810',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '21',
                        IFNAME           => 'Fa0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFALIAS          => 'F113-J095A',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:54',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3481) 0:00:34.81',
                        IFINOCTETS       => '64',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '64',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '22',
                        IFNAME           => 'Fa0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:55',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3513) 0:00:35.13',
                        IFINOCTETS       => '64',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '64',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '23',
                        IFNAME           => 'Fa0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:56',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3557) 0:00:35.57',
                        IFINOCTETS       => '64',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '64',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '24',
                        IFNAME           => 'Fa0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:57',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3571) 0:00:35.71',
                        IFINOCTETS       => '64',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '64',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '25',
                        IFNAME           => 'Fa0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:01:96:38:57:58',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3922) 0:00:39.22',
                        IFINOCTETS       => '64',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2594458902',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '26',
                        IFNAME           => 'Nu0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '27',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '0',
                        MAC              => '00:01:96:38:57:40',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                ]
            },
        }
    ],
    'cisco/C2951.1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco Internetwork Operating System Software 
IOS (tm) C2950 Software (C2950-I6K2L2Q4-M), Version 12.1(22)EA13, RELEASE SOFTWARE (fc2)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by cisco Systems, Inc.
Compiled Fri 27-F',
            MAC          => '00:0c:30:50:bb:c0',
            MODEL        => 'Catalyst 2950-24',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco Internetwork Operating System Software 
IOS (tm) C2950 Software (C2950-I6K2L2Q4-M), Version 12.1(22)EA13, RELEASE SOFTWARE (fc2)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by cisco Systems, Inc.
Compiled Fri 27-F',
            MAC          => '00:0c:30:50:bb:c0',
            MODELSNMP    => 'Networking1876',
            MODEL        => 'Catalyst 2950-24',
            FIRMWARE     => undef,
            SERIAL       => 'FOC0707Y03C',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2950-24',
                COMMENTS     => 'Cisco Internetwork Operating System Software 
IOS (tm) C2950 Software (C2950-I6K2L2Q4-M), Version 12.1(22)EA13, RELEASE SOFTWARE (fc2)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by cisco Systems, Inc.
Compiled Fri 27-F',
                CONTACT      => 'Service Informatique',
                LOCATION     => 'Recherche1-loctecN',
                SERIAL       => 'FOC0707Y03C',
                MAC          => '00:0c:30:50:bb:c0',
                UPTIME       => '(308499405) 35 days, 16:56:34.05',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Fa0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFALIAS          => 'C088A-R176',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:c1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(303016795) 35 days, 1:42:47.95',
                        IFINOCTETS       => '60889216',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '651190139',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '2',
                        IFNAME           => 'Fa0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFALIAS          => 'C089A-R176',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:c2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2249) 0:00:22.49',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '3',
                        IFNAME           => 'Fa0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFALIAS          => 'C090A-R177',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:c3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(303078788) 35 days, 1:53:07.88',
                        IFINOCTETS       => '179672391',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1131240344',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'Fa0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFALIAS          => 'C091A-R177',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:c4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(303160160) 35 days, 2:06:41.60',
                        IFINOCTETS       => '109243242',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '1359788681',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'Fa0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:c5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(304189272) 35 days, 4:58:12.72',
                        IFINOCTETS       => '292026344',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '62877405',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'Fa0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:c6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258602564) 29 days, 22:20:25.64',
                        IFINOCTETS       => '2521214202',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2918189544',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'Fa0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFALIAS          => 'C094A-R179',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:c7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(301712259) 34 days, 22:05:22.59',
                        IFINOCTETS       => '481054008',
                        IFINERRORS       => '2',
                        IFOUTOCTETS      => '184708223',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'Fa0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFALIAS          => 'C095A-R179',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:c8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(305717982) 35 days, 9:12:59.82',
                        IFINOCTETS       => '2825764704',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3441235419',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'Fa0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFALIAS          => 'C096A-R180-Imprimante',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:c9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(305648793) 35 days, 9:01:27.93',
                        IFINOCTETS       => '2292422171',
                        IFINERRORS       => '6',
                        IFOUTOCTETS      => '2489738042',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'Fa0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFALIAS          => 'C085B-R175',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:ca',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(274619951) 31 days, 18:49:59.51',
                        IFINOCTETS       => '28986718',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '293541492',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'Fa0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:cb',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2250) 0:00:22.50',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'Fa0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFALIAS          => 'C087B-R175',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:cc',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(302864335) 35 days, 1:17:23.35',
                        IFINOCTETS       => '557354284',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1221356798',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '13',
                        IFNAME           => 'Fa0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFALIAS          => 'C088B-R176',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:cd',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(308490907) 35 days, 16:55:09.07',
                        IFINOCTETS       => '52929160',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2426562181',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '14',
                        IFNAME           => 'Fa0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFALIAS          => 'C096B-R180-Imprimante',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:ce',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2250) 0:00:22.50',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '15',
                        IFNAME           => 'Fa0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFALIAS          => 'C097A-R180-Imprimante',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:cf',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2250) 0:00:22.50',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '16',
                        IFNAME           => 'Fa0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFALIAS          => 'C098A-R181-S.Heiden',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:d0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(251528055) 29 days, 2:41:20.55',
                        IFINOCTETS       => '563162',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1629466',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '17',
                        IFNAME           => 'Fa0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFALIAS          => 'C099A-R181-S.Heiden',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:d1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(303537660) 35 days, 3:09:36.60',
                        IFINOCTETS       => '1792523887',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2064844937',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '18',
                        IFNAME           => 'Fa0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFALIAS          => 'C101A-R182-Jayez-L005151',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:d2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(301768979) 34 days, 22:14:49.79',
                        IFINOCTETS       => '32917425',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '95390358',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '19',
                        IFNAME           => 'Fa0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:d3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2251) 0:00:22.51',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '20',
                        IFNAME           => 'Fa0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFALIAS          => 'C030B-R194',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:d4',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(215399437) 24 days, 22:19:54.37',
                        IFINOCTETS       => '1729564485',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1203073578',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '21',
                        IFNAME           => 'Fa0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:d5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2251) 0:00:22.51',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '22',
                        IFNAME           => 'Fa0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:d6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2251) 0:00:22.51',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '23',
                        IFNAME           => 'Fa0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFALIAS          => 'A8524-01L1-253',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:d7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2251) 0:00:22.51',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '24',
                        IFNAME           => 'Fa0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFALIAS          => 'C2950-01L1-105',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:d8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3980) 0:00:39.80',
                        IFINOCTETS       => '3672798189',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2215441865',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:01:96:33:58:57',
                                    '00:1b:21:2c:75:79',
                                    '00:1b:21:2c:75:7d',
                                    '00:1b:21:2c:76:65',
                                    '00:1b:21:2c:76:61',
                                    'c4:64:13:11:31:60',
                                    'c4:64:13:2b:f2:25',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '25',
                        IFNAME           => 'Nu0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '26',
                        IFNAME           => 'Vl1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:c0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(2290) 0:00:22.90',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '27',
                        IFNAME           => 'Vl615',
                        IFDESCR          => 'Vlan615',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0c:30:50:bb:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2870) 0:00:28.70',
                        IFINOCTETS       => '526252508',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3161575802',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.01.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
            SNMPHOSTNAME => 'CB-27.example.com',
            MAC          => '00:24:13:ea:a7:00',
            MODEL        => 'Catalyst 2960-24TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
            SNMPHOSTNAME => 'CB-27.example.com',
            MAC          => '00:24:13:ea:a7:00',
            MODELSNMP    => 'Networking2177',
            MODEL        => 'Catalyst 2960-24TC',
            FIRMWARE     => undef,
            SERIAL       => 'FOC1247X5DX',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-24TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
                NAME         => 'CB-27.example.com',
                SERIAL       => 'FOC1247X5DX',
                IPS          => {
                    IP => [
                        '192.168.1.27',
                    ],
                },
                MAC          => '00:24:13:ea:a7:00',
                UPTIME       => '(329794199) 38 days, 4:05:41.99',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vl1',
                        IFDESCR          => 'Vlan1',
                        IFALIAS          => 'MNGT',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.1.27',
                        MAC              => '00:24:13:ea:a7:40',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4607) 0:00:46.07',
                        IFINOCTETS       => '1955878377',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2756311186',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'Fa0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFALIAS          => 'pixin-int1-inside',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(35962354) 4 days, 3:53:43.54',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '3059673658',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2957789612',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'Fa0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:02',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4156) 0:00:41.56',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'Fa0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFALIAS          => 'MEDIA9-vers-CBI4061',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(45145198) 5 days, 5:24:11.98',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '106446611',
                        IFINERRORS       => '41',
                        IFOUTOCTETS      => '6780515',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'Fa0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:04',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4156) 0:00:41.56',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'Fa0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFALIAS          => 'PIX-int0-outside-i',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:05',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3688819692) 426 days, 22:43:16.92',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '55117404',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1951371841',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'Fa0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:06',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4156) 0:00:41.56',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'Fa0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:07',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(45289939) 5 days, 5:48:19.39',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '779472584',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '137886525',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'Fa0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:08',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4156) 0:00:41.56',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10009',
                        IFNAME           => 'Fa0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:09',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(449117911) 51 days, 23:32:59.11',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '3564203230',
                        IFINERRORS       => '86328',
                        IFOUTOCTETS      => '2567343375',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10010',
                        IFNAME           => 'Fa0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:0a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4156) 0:00:41.56',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10011',
                        IFNAME           => 'Fa0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFALIAS          => 'Snort',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:0b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4259630157) 493 days, 0:18:21.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4193136023',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '274037618',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:07:e9:06:a6:be',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10012',
                        IFNAME           => 'Fa0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:0c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4156) 0:00:41.56',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10013',
                        IFNAME           => 'Fa0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFALIAS          => 'Juniper-mgt',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:0d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(711110280) 82 days, 7:18:22.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2204612361',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1967389962',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:21:59:92:fb:7f',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10014',
                        IFNAME           => 'Fa0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:0e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4156) 0:00:41.56',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10015',
                        IFNAME           => 'Fa0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFALIAS          => 'VPN-ASA-outside',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:0f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3688824604) 426 days, 22:44:06.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3669484140',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3228371931',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10016',
                        IFNAME           => 'Fa0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:10',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4157) 0:00:41.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10017',
                        IFNAME           => 'Fa0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFALIAS          => 'VPN-ASA-inside',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:11',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3688836292) 426 days, 22:46:02.92',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1619195842',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '1395113604',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10018',
                        IFNAME           => 'Fa0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:12',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4157) 0:00:41.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10019',
                        IFNAME           => 'Fa0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:13',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4157) 0:00:41.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10020',
                        IFNAME           => 'Fa0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:14',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4157) 0:00:41.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10021',
                        IFNAME           => 'Fa0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:15',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4157) 0:00:41.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10022',
                        IFNAME           => 'Fa0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:16',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4157) 0:00:41.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10023',
                        IFNAME           => 'Fa0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:17',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4157) 0:00:41.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10024',
                        IFNAME           => 'Fa0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFALIAS          => 'codec regie video pr CB1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:18',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(180206948) 20 days, 20:34:29.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '62439235',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '929961356',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'Gi0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFALIAS          => 'vers 3550',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:19',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(310281198) 35 days, 21:53:31.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1780492746',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3781185060',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:0a:b8:92:56:40',
                                    '00:64:40:a6:58:c0',
                                    '00:64:40:a7:82:c0',
                                    '00:0b:fd:94:09:80',
                                    '00:0b:fd:9b:52:00',
                                    '00:0b:fd:ae:54:40',
                                    '00:0b:fd:15:ba:40',
                                    '00:0b:fd:15:bb:c0',
                                    '00:0b:5f:cc:d8:80',
                                    '00:0b:5f:cc:d8:8c',
                                    '00:0d:65:9e:18:40',
                                    '00:0d:bc:bd:66:c0',
                                    '00:0d:bd:92:3b:00',
                                    '00:0d:bd:92:4b:80',
                                    '00:0f:8f:47:91:c0',
                                    '00:d0:95:17:51:a3',
                                    '00:d0:95:3e:96:80',
                                    '00:d0:95:3e:96:83',
                                    '00:18:b9:92:08:40',
                                    '00:18:b9:b0:74:40',
                                    '00:18:b9:cc:27:c0',
                                    '00:18:b9:e3:75:c0',
                                    '00:18:b9:e3:7a:c0',
                                    '00:18:b9:e3:7e:40',
                                    '00:18:b9:e3:7f:40',
                                    '00:18:b9:e3:8e:40',
                                    '00:18:b9:e3:90:c0',
                                    '00:18:b9:e3:4d:40',
                                    '00:1a:6d:6c:f6:40',
                                    '00:1a:6d:b7:b8:40',
                                    '00:1a:6d:4f:6f:c0',
                                    '00:1a:6d:4f:74:c0',
                                    '00:1b:53:fd:d5:c0',
                                    '00:1b:54:d6:39:40',
                                    '00:1b:54:d6:3d:c0',
                                    '00:1b:54:db:6c:40',
                                    '00:1b:54:db:ec:c0',
                                    '00:1b:54:07:3c:c0',
                                    '00:1d:71:7c:77:c0',
                                    '00:21:59:94:bc:3f',
                                    '00:23:ab:dd:5d:c0',
                                    '00:24:13:a4:92:40',
                                    '00:24:13:ce:7d:40',
                                    '00:24:13:ce:d7:40',
                                    '00:24:50:06:4e:40',
                                    '00:04:dd:f9:93:00',
                                    '00:09:43:ec:d8:c0',
                                    '00:09:43:08:ea:c0',
                                    '00:09:43:09:04:00',
                                    '00:09:43:09:04:18',
                                    '00:09:43:09:08:40',
                                    '64:87:88:b0:79:41',
                                    '64:87:88:b0:7d:81',
                                    '64:87:88:b0:39:c1',
                                    '64:87:88:b0:3a:81',
                                    '64:87:88:b0:44:81',
                                    '64:87:88:b0:45:41',
                                    '6c:50:4d:f1:f7:40',
                                    '78:fe:3d:d4:b0:00',
                                    '78:fe:3d:d5:0e:ff',
                                    '78:fe:3d:df:1c:81',
                                    '78:fe:3d:df:20:01',
                                    '78:fe:3d:df:20:c1',
                                    '78:fe:3d:37:a8:c0',
                                    '78:fe:3d:37:5e:c0',
                                    'a8:d0:e5:b2:a0:c1',
                                    'a8:d0:e5:b2:ad:01',
                                    'a8:d0:e5:b2:ae:81',
                                    'a8:d0:e5:b2:be:41',
                                    'b4:a4:e3:eb:01:c0',
                                    'b4:14:89:32:00:40',
                                    'b4:14:89:38:19:c0',
                                    'b4:14:89:38:1d:40',
                                    'b4:14:89:38:22:40',
                                    'b4:14:89:38:28:c0',
                                    'b4:14:89:38:35:c0',
                                    'b4:14:89:38:38:40',
                                    'b4:14:89:38:3b:c0',
                                    'b8:ac:6f:94:57:ed',
                                    'b8:be:bf:af:f7:c0',
                                    'c4:0a:cb:ba:6d:c0',
                                    'c4:0a:cb:ba:6e:c0',
                                    'c4:0a:cb:cd:83:40',
                                    'c4:0a:cb:cd:86:40',
                                    'c4:0a:cb:cd:88:40',
                                    'c4:0a:cb:cd:8b:c0',
                                    'e8:e7:32:27:23:5f',
                                    'e8:e7:32:27:31:02',
                                    'e8:e7:32:27:38:30',
                                    'e8:e7:32:27:63:a0',
                                    'e8:e7:32:27:63:f4',
                                    'e8:e7:32:2a:e0:9e',
                                    'e8:e7:32:2a:e0:b6',
                                    'e8:e7:32:2a:e8:a4',
                                    'e8:e7:32:2a:e8:bc',
                                    'e8:e7:32:2b:c1:e2',
                                    'e8:e7:32:2b:c1:fb',
                                    'e8:e7:32:2b:cc:e7',
                                    'e8:e7:32:4b:78:f8',
                                    'e8:e7:32:4b:79:13',
                                    'e8:e7:32:4b:7b:b4',
                                    'e8:e7:32:4b:86:db',
                                    'e8:e7:32:4b:8a:cc',
                                    'e8:e7:32:4b:9b:d8',
                                    'e8:e7:32:5c:be:d3',
                                    'e8:04:62:1e:a3:c0',
                                    'e8:40:40:09:6a:40',
                                    'f4:7f:35:8a:2c:40',
                                    'f8:c0:01:c7:85:01',
                                    '2c:36:f8:7d:06:c0',
                                    '40:f4:ec:d6:80:40',
                                    '58:bc:27:78:54:40',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'Gi0/2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFALIAS          => 'LX250',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ea:a7:1a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4259602380) 493 days, 0:13:43.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1622468503',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2698146544',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:19:d1:92:0c:4c',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Nu0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.02.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
            SNMPHOSTNAME => 'AP-P101-59.example.com',
            MAC          => '00:24:13:ce:d7:00',
            MODEL        => 'Catalyst 2960-24TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
            SNMPHOSTNAME => 'AP-P101-59.example.com',
            MAC          => '00:24:13:ce:d7:00',
            MODELSNMP    => 'Networking2177',
            MODEL        => 'Catalyst 2960-24TC',
            FIRMWARE     => undef,
            SERIAL       => 'FOC1247X5D4',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-24TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
                NAME         => 'AP-P101-59.example.com',
                SERIAL       => 'FOC1247X5D4',
                MAC          => '00:24:13:ce:d7:00',
                CPU          => '81',
                RAM          => '64',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:40',
                        IFLASTCHANGE     => '(448584218) 51 days, 22:04:02.18',
                        IFINOCTETS       => '1969699486',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1143740170',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:01',
                        IFLASTCHANGE     => '(1666698681) 192 days, 21:43:06.81',
                        IFINOCTETS       => '160360322',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2520427958',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10002',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:02',
                        IFLASTCHANGE     => '(1288669773) 149 days, 3:38:17.73',
                        IFINOCTETS       => '1354978920',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '1444296343',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10003',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:03',
                        IFLASTCHANGE     => '(1667811201) 193 days, 0:48:32.01',
                        IFINOCTETS       => '1418474807',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3697736928',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10004',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:04',
                        IFLASTCHANGE     => '(361575212) 41 days, 20:22:32.12',
                        IFINOCTETS       => '972898572',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2874278107',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10005',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:05',
                        IFLASTCHANGE     => '(361564184) 41 days, 20:20:41.84',
                        IFINOCTETS       => '842225921',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2097721511',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10006',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:06',
                        IFLASTCHANGE     => '(1460643496) 169 days, 1:20:34.96',
                        IFINOCTETS       => '612658',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '7517632',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10007',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:07',
                        IFLASTCHANGE     => '(1545691195) 178 days, 21:35:11.95',
                        IFINOCTETS       => '860540279',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '356275802',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10008',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:08',
                        IFLASTCHANGE     => '(1669007485) 193 days, 4:07:54.85',
                        IFINOCTETS       => '59734207',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1849411001',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10009',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:09',
                        IFLASTCHANGE     => '(1599428965) 185 days, 2:51:29.65',
                        IFINOCTETS       => '2469094479',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4060044107',
                        IFOUTERRORS      => '5',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10010',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:0a',
                        IFLASTCHANGE     => '(1399544874) 161 days, 23:37:28.74',
                        IFINOCTETS       => '102950896',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '650135037',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10011',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:0b',
                        IFLASTCHANGE     => '(4167) 0:00:41.67',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10012',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:0c',
                        IFLASTCHANGE     => '(1666029375) 192 days, 19:51:33.75',
                        IFINOCTETS       => '43235636',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '680136759',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10013',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:0d',
                        IFLASTCHANGE     => '(1286978674) 148 days, 22:56:26.74',
                        IFINOCTETS       => '239329601',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '828899275',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10014',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:0e',
                        IFLASTCHANGE     => '(1668531324) 193 days, 2:48:33.24',
                        IFINOCTETS       => '330810944',
                        IFINERRORS       => '16887',
                        IFOUTOCTETS      => '1855427971',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10015',
                        IFDESCR          => 'FastEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:0f',
                        IFLASTCHANGE     => '(1667075555) 192 days, 22:45:55.55',
                        IFINOCTETS       => '107079056',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1133282038',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10016',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:10',
                        IFLASTCHANGE     => '(1332165044) 154 days, 4:27:30.44',
                        IFINOCTETS       => '75627900',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '857357031',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10017',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:11',
                        IFLASTCHANGE     => '(1399546606) 161 days, 23:37:46.06',
                        IFINOCTETS       => '1569285360',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '209932792',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10018',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:12',
                        IFLASTCHANGE     => '(1659597753) 192 days, 1:59:37.53',
                        IFINOCTETS       => '62683816',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '1032329852',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10019',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:13',
                        IFLASTCHANGE     => '(1660563317) 192 days, 4:40:33.17',
                        IFINOCTETS       => '148292480',
                        IFINERRORS       => '252',
                        IFOUTOCTETS      => '1865203761',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10020',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:14',
                        IFLASTCHANGE     => '(1286973610) 148 days, 22:55:36.10',
                        IFINOCTETS       => '1414423',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '37991943',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10021',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:15',
                        IFLASTCHANGE     => '(1666644488) 192 days, 21:34:04.88',
                        IFINOCTETS       => '470135831',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '2845209002',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10022',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:16',
                        IFLASTCHANGE     => '(1539355445) 178 days, 3:59:14.45',
                        IFINOCTETS       => '383001306',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '2428516158',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10023',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:17',
                        IFLASTCHANGE     => '(4168) 0:00:41.68',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10024',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:18',
                        IFLASTCHANGE     => '(4168) 0:00:41.68',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:19',
                        IFLASTCHANGE     => '(4168) 0:00:41.68',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:13:ce:d7:1a',
                        IFLASTCHANGE     => '(448584503) 51 days, 22:04:05.03',
                        IFINOCTETS       => '3449371397',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '2995445287',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0/5',
                                SYSNAME  => 'AP-Switch-51.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.51',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.03.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
            SNMPHOSTNAME => 'CP-P101-37.example.com',
            MAC          => '00:1b:54:d6:39:00',
            MODEL        => 'Catalyst 2960-24TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
            SNMPHOSTNAME => 'CP-P101-37.example.com',
            MAC          => '00:1b:54:d6:39:00',
            MODELSNMP    => 'Networking2177',
            MODEL        => 'Catalyst 2960-24TC',
            FIRMWARE     => undef,
            SERIAL       => 'FOC1113X1PE',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-24TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
                NAME         => 'CP-P101-37.example.com',
                SERIAL       => 'FOC1113X1PE',
                MAC          => '00:1b:54:d6:39:00',
                CPU          => '89',
                RAM          => '64',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:40',
                        IFLASTCHANGE     => '(4584) 0:00:45.84',
                        IFINOCTETS       => '2030921664',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '951088659',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:01',
                        IFLASTCHANGE     => '(1657748225) 191 days, 20:51:22.25',
                        IFINOCTETS       => '369925658',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '926844080',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10002',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:02',
                        IFLASTCHANGE     => '(4140) 0:00:41.40',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10003',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:03',
                        IFLASTCHANGE     => '(1641428469) 189 days, 23:31:24.69',
                        IFINOCTETS       => '393092436',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3227489290',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10004',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:04',
                        IFLASTCHANGE     => '(4140) 0:00:41.40',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10005',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:05',
                        IFLASTCHANGE     => '(1668711130) 193 days, 3:18:31.30',
                        IFINOCTETS       => '521485508',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '2052899224',
                        IFOUTERRORS      => '73',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10006',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:06',
                        IFLASTCHANGE     => '(4140) 0:00:41.40',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10007',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:07',
                        IFLASTCHANGE     => '(1149060288) 132 days, 23:50:02.88',
                        IFINOCTETS       => '152710057',
                        IFINERRORS       => '34',
                        IFOUTOCTETS      => '2698203912',
                        IFOUTERRORS      => '297',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10008',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:08',
                        IFLASTCHANGE     => '(1608943026) 186 days, 5:17:10.26',
                        IFINOCTETS       => '188163118',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1553262039',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10009',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:09',
                        IFLASTCHANGE     => '(1669071909) 193 days, 4:18:39.09',
                        IFINOCTETS       => '2609670352',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '3992264533',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10010',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:0a',
                        IFLASTCHANGE     => '(1651098591) 191 days, 2:23:05.91',
                        IFINOCTETS       => '49267770',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '654794463',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10011',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:0b',
                        IFLASTCHANGE     => '(1512173256) 175 days, 0:28:52.56',
                        IFINOCTETS       => '257576986',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4219065024',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10012',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:0c',
                        IFLASTCHANGE     => '(1512143171) 175 days, 0:23:51.71',
                        IFINOCTETS       => '36205380',
                        IFINERRORS       => '613',
                        IFOUTOCTETS      => '347903192',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10013',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:0d',
                        IFLASTCHANGE     => '(1634598779) 189 days, 4:33:07.79',
                        IFINOCTETS       => '208833434',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '191680982',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10014',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:0e',
                        IFLASTCHANGE     => '(4141) 0:00:41.41',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10015',
                        IFDESCR          => 'FastEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:0f',
                        IFLASTCHANGE     => '(1668167389) 193 days, 1:47:53.89',
                        IFINOCTETS       => '212801623',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2383669184',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10016',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:10',
                        IFLASTCHANGE     => '(1399398381) 161 days, 23:13:03.81',
                        IFINOCTETS       => '5589',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '631494',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10017',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:11',
                        IFLASTCHANGE     => '(1667752600) 193 days, 0:38:46.00',
                        IFINOCTETS       => '1638043019',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '469166891',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10018',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:12',
                        IFLASTCHANGE     => '(4141) 0:00:41.41',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10019',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:13',
                        IFLASTCHANGE     => '(1660466187) 192 days, 4:24:21.87',
                        IFINOCTETS       => '884179267',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3400637521',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10020',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:14',
                        IFLASTCHANGE     => '(1668286829) 193 days, 2:07:48.29',
                        IFINOCTETS       => '359416168',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '756432620',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10021',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:15',
                        IFLASTCHANGE     => '(4142) 0:00:41.42',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10022',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:16',
                        IFLASTCHANGE     => '(1546204896) 178 days, 23:00:48.96',
                        IFINOCTETS       => '204828',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2733536359',
                        IFOUTERRORS      => '2257',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10023',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:17',
                        IFLASTCHANGE     => '(4142) 0:00:41.42',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10024',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:18',
                        IFLASTCHANGE     => '(182404430) 21 days, 2:40:44.30',
                        IFINOCTETS       => '2724805151',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3155157885',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '64:87:88:b0:45:41',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10101',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:19',
                        IFLASTCHANGE     => '(16491) 0:02:44.91',
                        IFINOCTETS       => '3914931489',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2654463940',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'f8:c0:01:c7:85:01',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10102',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1b:54:d6:39:1a',
                        IFLASTCHANGE     => '(1366004940) 158 days, 2:27:29.40',
                        IFINOCTETS       => '2925623154',
                        IFINERRORS       => '6',
                        IFOUTOCTETS      => '2183974366',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0/4',
                                SYSNAME  => 'CP-Switch-101.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.101',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.04.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(50)SE1, RELEASE SOFTWARE (fc2)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Mon 06-Apr-09 08:36 by amvarma',
            MAC          => '00:1a:6d:9d:23:00',
            MODEL        => 'Catalyst 2960-48TT',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(50)SE1, RELEASE SOFTWARE (fc2)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Mon 06-Apr-09 08:36 by amvarma',
            MAC          => '00:1a:6d:9d:23:00',
            MODELSNMP    => 'Networking1956',
            MODEL        => 'Catalyst 2960-48TT',
            FIRMWARE     => undef,
            SERIAL       => 'FOC1049Z7RN',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TT',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(50)SE1, RELEASE SOFTWARE (fc2)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Mon 06-Apr-09 08:36 by amvarma',
                LOCATION     => 'Recherche1-loctecN',
                SERIAL       => 'FOC1049Z7RN',
                MAC          => '00:1a:6d:9d:23:00',
                UPTIME       => '(308478285) 35 days, 16:53:02.85',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:40',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4144) 0:00:41.44',
                        IFINOCTETS       => '3516',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '615',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:41',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7886) 0:01:18.86',
                        IFINOCTETS       => '2251471785',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '286127141',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'Fa0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFALIAS          => 'C046A-R131',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:01',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(274486595) 31 days, 18:27:45.95',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '8377',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '8039',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'Fa0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFALIAS          => 'C047A-R131',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:02',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4356) 0:00:43.56',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'Fa0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFALIAS          => 'C057B-R161',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4356) 0:00:43.56',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'Fa0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFALIAS          => 'C043B-R133',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:04',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4356) 0:00:43.56',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'Fa0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFALIAS          => 'C048B-R157 F.Lupu-Dell-Scale 00:08:74:1e:46:7b',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:05',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'Fa0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:06',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'Fa0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:07',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'Fa0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:08',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10009',
                        IFNAME           => 'Fa0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:09',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(249372923) 28 days, 20:42:09.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1054580',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3806443766',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10010',
                        IFNAME           => 'Fa0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:0a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(299914444) 34 days, 17:05:44.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2096941',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '977213699',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10011',
                        IFNAME           => 'Fa0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:0b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(179157864) 20 days, 17:39:38.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3931513',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2396979049',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10012',
                        IFNAME           => 'Fa0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:0c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8574) 0:01:25.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2366114',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2005431730',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10013',
                        IFNAME           => 'Fa0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFALIAS          => 'C057A-R161 B.Pateyron 00:03:93:ac:33:48',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:0d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(268534034) 31 days, 1:55:40.34',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '381991911',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1003764265',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10014',
                        IFNAME           => 'Fa0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:0e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(302884951) 35 days, 1:20:49.51',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '79575793',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '651793413',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10015',
                        IFNAME           => 'Fa0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFALIAS          => 'C059A-M.Guezzah 00:11:43:a4:c8:5c',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:0f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(235757413) 27 days, 6:52:54.13',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '67899905',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '208408457',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10016',
                        IFNAME           => 'Fa0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFALIAS          => 'C060A-R163 Lafon',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:10',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10017',
                        IFNAME           => 'Fa0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:11',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4559) 0:00:45.59',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '394681957',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10018',
                        IFNAME           => 'Fa0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:12',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(303482260) 35 days, 3:00:22.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2420463446',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1961681052',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10019',
                        IFNAME           => 'Fa0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:13',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10020',
                        IFNAME           => 'Fa0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:14',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(303271002) 35 days, 2:25:10.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4021716383',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2269332039',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10021',
                        IFNAME           => 'Fa0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFALIAS          => 'C059B-R163 Mehdi Guezzah Serveur Win',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:15',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(302190971) 34 days, 23:25:09.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '211747976',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3802961593',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10022',
                        IFNAME           => 'Fa0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFALIAS          => 'C71B',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:16',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(276176642) 31 days, 23:09:26.42',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '1509322',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '16797448',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10023',
                        IFNAME           => 'Fa0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFALIAS          => 'onduleur',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:17',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10024',
                        IFNAME           => 'Fa0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:18',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10025',
                        IFNAME           => 'Fa0/25',
                        IFDESCR          => 'FastEthernet0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:19',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10026',
                        IFNAME           => 'Fa0/26',
                        IFDESCR          => 'FastEthernet0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:1a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(301989661) 34 days, 22:51:36.61',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '9565924',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '116408328',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10027',
                        IFNAME           => 'Fa0/27',
                        IFDESCR          => 'FastEthernet0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:1b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(245765225) 28 days, 10:40:52.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3452382522',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3680075113',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10028',
                        IFNAME           => 'Fa0/28',
                        IFDESCR          => 'FastEthernet0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:1c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(207446855) 24 days, 0:14:28.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '51170836',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '934210769',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10029',
                        IFNAME           => 'Fa0/29',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:1d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10030',
                        IFNAME           => 'Fa0/30',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(179376296) 20 days, 18:16:02.96',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8805389',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '625009670',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10031',
                        IFNAME           => 'Fa0/31',
                        IFDESCR          => 'FastEthernet0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:1f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(251422216) 29 days, 2:23:42.16',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '98215557',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '48570148',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10032',
                        IFNAME           => 'Fa0/32',
                        IFDESCR          => 'FastEthernet0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:20',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4358) 0:00:43.58',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10033',
                        IFNAME           => 'Fa0/33',
                        IFDESCR          => 'FastEthernet0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:21',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4358) 0:00:43.58',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10034',
                        IFNAME           => 'Fa0/34',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:22',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(303975821) 35 days, 4:22:38.21',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '1406916349',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1184498155',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10035',
                        IFNAME           => 'Fa0/35',
                        IFDESCR          => 'FastEthernet0/35',
                        IFALIAS          => 'conf_inter',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:23',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(296990528) 34 days, 8:58:25.28',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '4022754',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '341153770',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10036',
                        IFNAME           => 'Fa0/36',
                        IFDESCR          => 'FastEthernet0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:24',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4358) 0:00:43.58',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10037',
                        IFNAME           => 'Fa0/37',
                        IFDESCR          => 'FastEthernet0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:25',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(275058029) 31 days, 20:03:00.29',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '861396',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '5073664',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10038',
                        IFNAME           => 'Fa0/38',
                        IFDESCR          => 'FastEthernet0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:26',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(308468383) 35 days, 16:51:23.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '305488102',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3020738923',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10039',
                        IFNAME           => 'Fa0/39',
                        IFDESCR          => 'FastEthernet0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:27',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4358) 0:00:43.58',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10040',
                        IFNAME           => 'Fa0/40',
                        IFDESCR          => 'FastEthernet0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:28',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(257597766) 29 days, 19:32:57.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3485684785',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2816523712',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10041',
                        IFNAME           => 'Fa0/41',
                        IFDESCR          => 'FastEthernet0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:29',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(301739265) 34 days, 22:09:52.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2106724549',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '1169216285',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10042',
                        IFNAME           => 'Fa0/42',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:2a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(303457383) 35 days, 2:56:13.83',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '570676480',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1439884782',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10043',
                        IFNAME           => 'Fa0/43',
                        IFDESCR          => 'FastEthernet0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:2b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(213879972) 24 days, 18:06:39.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '12256557',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1641139230',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10044',
                        IFNAME           => 'Fa0/44',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:2c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4359) 0:00:43.59',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10045',
                        IFNAME           => 'Fa0/45',
                        IFDESCR          => 'FastEthernet0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:2d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4359) 0:00:43.59',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10046',
                        IFNAME           => 'Fa0/46',
                        IFDESCR          => 'FastEthernet0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:2e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259319200) 30 days, 0:19:52.00',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '1748345',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1092855',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10047',
                        IFNAME           => 'Fa0/47',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:2f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(267746706) 30 days, 23:44:27.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '15102369',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '785002890',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10048',
                        IFNAME           => 'Fa0/48',
                        IFDESCR          => 'FastEthernet0/48',
                        IFALIAS          => 'D-h2610-poe-01L1-5026.Interface.26',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:30',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4872) 0:00:48.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1892565339',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1906464200',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'b4:39:d6:49:5b:a6',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'Gi0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:31',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(14025619) 1 day, 14:57:36.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '174630655',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '839081165',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1b:21:2c:75:79',
                                    '00:1b:21:2c:75:7d',
                                    '00:1b:21:2c:76:65',
                                    '00:1b:21:2c:76:61',
                                    '00:1e:7a:f5:09:47',
                                    'c4:64:13:11:31:81',
                                    'c4:64:13:11:31:60',
                                    'c4:64:13:2b:f2:25',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'Gi0/2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6d:9d:23:32',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4359) 0:00:43.59',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Nu0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.08.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            SNMPHOSTNAME => 'AP-74.example.com',
            MAC          => 'c4:0a:cb:cd:86:00',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            SNMPHOSTNAME => 'AP-74.example.com',
            MAC          => 'c4:0a:cb:cd:86:00',
            MODELSNMP    => 'Networking2179',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => 'FOC1511W1A2',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
                NAME         => 'AP-74.example.com',
                MEMORY       => '4',
                SERIAL       => 'FOC1511W1A2',
                FIRMWARE     => '15.0(1)SE3',
                IPS          => {
                    IP => [
                        '192.168.1.74',
                    ],
                },
                MAC          => 'c4:0a:cb:cd:86:00',
                UPTIME       => '(347543457) 40 days, 5:23:54.57',
                CPU          => '83',
                RAM          => '64',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vl1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.1.74',
                        MAC              => 'c4:0a:cb:cd:86:40',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(33843) 0:05:38.43',
                        IFINOCTETS       => '1474264407',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '328275733',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'Fa0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFALIAS          => 'P513-AP-T-5018 ',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:01',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4122) 0:00:41.22',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'Fa0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:02',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(346931458) 40 days, 3:41:54.58',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '236588628',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1309670942',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'Fa0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFALIAS          => 'AP-I-3013-P313b',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(346733109) 40 days, 3:08:51.09',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '244400373',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2758132634',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'Fa0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:04',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(347248129) 40 days, 4:34:41.29',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '306005406',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2237159677',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'Fa0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFALIAS          => 'AP-I-3016-P313b',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:05',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(346709972) 40 days, 3:04:59.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '341205155',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4244518876',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'Fa0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:06',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(299032702) 34 days, 14:38:47.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '103424675',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1103108996',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'Fa0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:07',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(347364747) 40 days, 4:54:07.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '384186304',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '680410947',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'Fa0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFALIAS          => 'P503-AP-I-5023',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:08',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(304905559) 35 days, 6:57:35.59',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1711110227',
                        IFOUTERRORS      => '5306391',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10009',
                        IFNAME           => 'Fa0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFALIAS          => 'AP-I-3023-P305TER',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:09',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4122) 0:00:41.22',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10010',
                        IFNAME           => 'Fa0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFALIAS          => 'AP-I-xxxx-P316',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:0a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(199152305) 23 days, 1:12:03.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '352167261',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '472288711',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10011',
                        IFNAME           => 'Fa0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:0b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4122) 0:00:41.22',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10012',
                        IFNAME           => 'Fa0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFALIAS          => 'AP-I-xxxx-P316',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:0c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(292879038) 33 days, 21:33:10.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '947341952',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3871739267',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10013',
                        IFNAME           => 'Fa0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:0d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4122) 0:00:41.22',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10014',
                        IFNAME           => 'Fa0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFALIAS          => 'P316g-P316',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:0e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(347014191) 40 days, 3:55:41.91',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '310298783',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3190072208',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10015',
                        IFNAME           => 'Fa0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:0f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10016',
                        IFNAME           => 'Fa0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:10',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10017',
                        IFNAME           => 'Fa0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:11',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10018',
                        IFNAME           => 'Fa0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:12',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10019',
                        IFNAME           => 'Fa0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFALIAS          => 'AP-318B',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:13',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(347064484) 40 days, 4:04:04.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '257298363',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '462767851',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10020',
                        IFNAME           => 'Fa0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFALIAS          => 'AP-I-4012',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:14',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(344231637) 39 days, 20:11:56.37',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '485150014',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2831486943',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10021',
                        IFNAME           => 'Fa0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFALIAS          => 'AP-318B',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:15',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(19407) 0:03:14.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '80068166',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3115275205',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10022',
                        IFNAME           => 'Fa0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:16',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10023',
                        IFNAME           => 'Fa0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFALIAS          => 'AP-318g',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:17',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(345462929) 39 days, 23:37:09.29',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '214483908',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1039775044',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10024',
                        IFNAME           => 'Fa0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:18',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10025',
                        IFNAME           => 'Fa0/25',
                        IFDESCR          => 'FastEthernet0/25',
                        IFALIAS          => 'P412 AB-I-4009',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:19',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(347389474) 40 days, 4:58:14.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '197928734',
                        IFINERRORS       => '10114',
                        IFOUTOCTETS      => '2278558878',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10026',
                        IFNAME           => 'Fa0/26',
                        IFDESCR          => 'FastEthernet0/26',
                        IFALIAS          => 'P033 API-0024',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:1a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10027',
                        IFNAME           => 'Fa0/27',
                        IFDESCR          => 'FastEthernet0/27',
                        IFALIAS          => 'AP-I-4011',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:1b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17566) 0:02:55.66',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '660664840',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '189899557',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10028',
                        IFNAME           => 'Fa0/28',
                        IFDESCR          => 'FastEthernet0/28',
                        IFALIAS          => 'AP-I-4118-A402',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:1c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(346865571) 40 days, 3:30:55.71',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '533303751',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1170216684',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10029',
                        IFNAME           => 'Fa0/29',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:1d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(346295021) 40 days, 1:55:50.21',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '182135404',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1274821872',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10030',
                        IFNAME           => 'Fa0/30',
                        IFDESCR          => 'FastEthernet0/30',
                        IFALIAS          => 'P031 API-0027',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:1e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10031',
                        IFNAME           => 'Fa0/31',
                        IFDESCR          => 'FastEthernet0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:1f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(16871) 0:02:48.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '29059300',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '633177844',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10032',
                        IFNAME           => 'Fa0/32',
                        IFDESCR          => 'FastEthernet0/32',
                        IFALIAS          => 'AP-I-4104',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:20',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(223291471) 25 days, 20:15:14.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '214096311',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '4206248334',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10033',
                        IFNAME           => 'Fa0/33',
                        IFDESCR          => 'FastEthernet0/33',
                        IFALIAS          => 'AP-I-4037-P406BIS',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:21',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(320907355) 37 days, 3:24:33.55',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '95132469',
                        IFINERRORS       => '2369',
                        IFOUTOCTETS      => '587991352',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10034',
                        IFNAME           => 'Fa0/34',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:22',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(347143890) 40 days, 4:17:18.90',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '489015270',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1209925409',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10035',
                        IFNAME           => 'Fa0/35',
                        IFDESCR          => 'FastEthernet0/35',
                        IFALIAS          => 'IRIS-CREDEP',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:23',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10036',
                        IFNAME           => 'Fa0/36',
                        IFDESCR          => 'FastEthernet0/36',
                        IFALIAS          => 'AP-I-4116',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:24',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(347141430) 40 days, 4:16:54.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '432349066',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '427746098',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10037',
                        IFNAME           => 'Fa0/37',
                        IFDESCR          => 'FastEthernet0/37',
                        IFALIAS          => 'IRIS-CREDEP',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:25',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10038',
                        IFNAME           => 'Fa0/38',
                        IFDESCR          => 'FastEthernet0/38',
                        IFALIAS          => 'AP-I-4115 A406',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:26',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(50167) 0:08:21.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '273611216',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3366833064',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10039',
                        IFNAME           => 'Fa0/39',
                        IFDESCR          => 'FastEthernet0/39',
                        IFALIAS          => 'IRIS-CREDEP',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:27',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(311161429) 36 days, 0:20:14.29',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '50812277',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '523659377',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10040',
                        IFNAME           => 'Fa0/40',
                        IFDESCR          => 'FastEthernet0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:28',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10041',
                        IFNAME           => 'Fa0/41',
                        IFDESCR          => 'FastEthernet0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:29',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10042',
                        IFNAME           => 'Fa0/42',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:2a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(48708) 0:08:07.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '510737178',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3327711715',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10043',
                        IFNAME           => 'Fa0/43',
                        IFDESCR          => 'FastEthernet0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:2b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10044',
                        IFNAME           => 'Fa0/44',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:2c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(46296) 0:07:42.96',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '614324126',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1211817539',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10045',
                        IFNAME           => 'Fa0/45',
                        IFDESCR          => 'FastEthernet0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:2d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10046',
                        IFNAME           => 'Fa0/46',
                        IFDESCR          => 'FastEthernet0/46',
                        IFALIAS          => 'IRIS-CREDEP',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:2e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10047',
                        IFNAME           => 'Fa0/47',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:2f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10048',
                        IFNAME           => 'Fa0/48',
                        IFDESCR          => 'FastEthernet0/48',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:30',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'Gi0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:31',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'Gi0/2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:86:32',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(33930) 0:05:39.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2071109510',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '275105132',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0/1',
                                SYSNAME  => 'AP-Switch-51.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.51',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Nu0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.09.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            SNMPHOSTNAME => 'CB-C005-208.Dauphine',
            MAC          => '64:d9:89:8d:b1:80',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            SNMPHOSTNAME => 'CB-C005-208.Dauphine',
            MAC          => '64:d9:89:8d:b1:80',
            MODELSNMP    => 'Networking2179',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => 'FOC1511W19F',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
                NAME         => 'CB-C005-208.Dauphine',
                MEMORY       => '5',
                SERIAL       => 'FOC1511W19F',
                FIRMWARE     => '15.0(1)SE3',
                MAC          => '64:d9:89:8d:b1:80',
                CPU          => '89',
                RAM          => '64',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:c0',
                        IFLASTCHANGE     => '(595775969) 68 days, 22:55:59.69',
                        IFINOCTETS       => '2847919715',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2431876662',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:81',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10002',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:82',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10003',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:83',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10004',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:84',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10005',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:85',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10006',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:86',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10007',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:87',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10008',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:88',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10009',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:89',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10010',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:8a',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10011',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:8b',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10012',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:8c',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10013',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:8d',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10014',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:8e',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10015',
                        IFDESCR          => 'FastEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:8f',
                        IFLASTCHANGE     => '(1629636421) 188 days, 14:46:04.21',
                        IFINOCTETS       => '158358580',
                        IFINERRORS       => '2',
                        IFOUTOCTETS      => '2542256749',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10016',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:90',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10017',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:91',
                        IFLASTCHANGE     => '(4253) 0:00:42.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10018',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:92',
                        IFLASTCHANGE     => '(4254) 0:00:42.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10019',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:93',
                        IFLASTCHANGE     => '(4254) 0:00:42.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10020',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:94',
                        IFLASTCHANGE     => '(4254) 0:00:42.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10021',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:95',
                        IFLASTCHANGE     => '(4254) 0:00:42.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10022',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:96',
                        IFLASTCHANGE     => '(4254) 0:00:42.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10023',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:97',
                        IFLASTCHANGE     => '(4254) 0:00:42.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10024',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:98',
                        IFLASTCHANGE     => '(4254) 0:00:42.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10025',
                        IFDESCR          => 'FastEthernet0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:99',
                        IFLASTCHANGE     => '(4254) 0:00:42.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10026',
                        IFDESCR          => 'FastEthernet0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:9a',
                        IFLASTCHANGE     => '(4254) 0:00:42.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10027',
                        IFDESCR          => 'FastEthernet0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:9b',
                        IFLASTCHANGE     => '(4254) 0:00:42.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10028',
                        IFDESCR          => 'FastEthernet0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:9c',
                        IFLASTCHANGE     => '(4254) 0:00:42.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10029',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:9d',
                        IFLASTCHANGE     => '(4254) 0:00:42.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10030',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:9e',
                        IFLASTCHANGE     => '(4255) 0:00:42.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10031',
                        IFDESCR          => 'FastEthernet0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:9f',
                        IFLASTCHANGE     => '(4255) 0:00:42.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10032',
                        IFDESCR          => 'FastEthernet0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:a0',
                        IFLASTCHANGE     => '(4255) 0:00:42.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10033',
                        IFDESCR          => 'FastEthernet0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:a1',
                        IFLASTCHANGE     => '(4255) 0:00:42.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10034',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:a2',
                        IFLASTCHANGE     => '(4255) 0:00:42.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10035',
                        IFDESCR          => 'FastEthernet0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:a3',
                        IFLASTCHANGE     => '(4255) 0:00:42.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10036',
                        IFDESCR          => 'FastEthernet0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:a4',
                        IFLASTCHANGE     => '(4255) 0:00:42.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10037',
                        IFDESCR          => 'FastEthernet0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:a5',
                        IFLASTCHANGE     => '(4255) 0:00:42.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10038',
                        IFDESCR          => 'FastEthernet0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:a6',
                        IFLASTCHANGE     => '(4255) 0:00:42.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10039',
                        IFDESCR          => 'FastEthernet0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:a7',
                        IFLASTCHANGE     => '(4255) 0:00:42.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10040',
                        IFDESCR          => 'FastEthernet0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:a8',
                        IFLASTCHANGE     => '(4255) 0:00:42.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10041',
                        IFDESCR          => 'FastEthernet0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:a9',
                        IFLASTCHANGE     => '(4255) 0:00:42.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10042',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:aa',
                        IFLASTCHANGE     => '(4256) 0:00:42.56',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10043',
                        IFDESCR          => 'FastEthernet0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:ab',
                        IFLASTCHANGE     => '(4256) 0:00:42.56',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10044',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:ac',
                        IFLASTCHANGE     => '(4256) 0:00:42.56',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10045',
                        IFDESCR          => 'FastEthernet0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:ad',
                        IFLASTCHANGE     => '(4256) 0:00:42.56',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10046',
                        IFDESCR          => 'FastEthernet0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:ae',
                        IFLASTCHANGE     => '(4256) 0:00:42.56',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10047',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:af',
                        IFLASTCHANGE     => '(4256) 0:00:42.56',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10048',
                        IFDESCR          => 'FastEthernet0/48',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:b0',
                        IFLASTCHANGE     => '(4256) 0:00:42.56',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:b1',
                        IFLASTCHANGE     => '(595776056) 68 days, 22:56:00.56',
                        IFINOCTETS       => '627337006',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2755039325',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet1/0/23',
                                SYSNAME  => 'CB-C005-202.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.202',
                                MODEL    => 'cisco WS-C2960S-24TD-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10102',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:d9:89:8d:b1:b2',
                        IFLASTCHANGE     => '(4256) 0:00:42.56',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10501',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.10.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            SNMPHOSTNAME => 'CB-C005-206.Dauphine',
            MAC          => '2c:36:f8:7d:09:00',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            SNMPHOSTNAME => 'CB-C005-206.Dauphine',
            MAC          => '2c:36:f8:7d:09:00',
            MODELSNMP    => 'Networking2179',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => 'FCQ1605X4UZ',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
                NAME         => 'CB-C005-206.Dauphine',
                MEMORY       => '4',
                SERIAL       => 'FCQ1605X4UZ',
                FIRMWARE     => '15.0(1)SE3',
                MAC          => '2c:36:f8:7d:09:00',
                CPU          => '80',
                RAM          => '64',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:40',
                        IFLASTCHANGE     => '(596600541) 69 days, 1:13:25.41',
                        IFINOCTETS       => '2876037603',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2448955914',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:01',
                        IFLASTCHANGE     => '(4230) 0:00:42.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10002',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:02',
                        IFLASTCHANGE     => '(4230) 0:00:42.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10003',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:03',
                        IFLASTCHANGE     => '(4230) 0:00:42.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10004',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:04',
                        IFLASTCHANGE     => '(4230) 0:00:42.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10005',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:05',
                        IFLASTCHANGE     => '(4230) 0:00:42.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10006',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:06',
                        IFLASTCHANGE     => '(4230) 0:00:42.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10007',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:07',
                        IFLASTCHANGE     => '(4230) 0:00:42.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10008',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:08',
                        IFLASTCHANGE     => '(4230) 0:00:42.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10009',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:09',
                        IFLASTCHANGE     => '(4230) 0:00:42.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10010',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:0a',
                        IFLASTCHANGE     => '(4230) 0:00:42.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10011',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:0b',
                        IFLASTCHANGE     => '(4230) 0:00:42.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10012',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:0c',
                        IFLASTCHANGE     => '(4231) 0:00:42.31',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10013',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:0d',
                        IFLASTCHANGE     => '(4231) 0:00:42.31',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10014',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:0e',
                        IFLASTCHANGE     => '(1623443346) 187 days, 21:33:53.46',
                        IFINOCTETS       => '13649415',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '144458186',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10015',
                        IFDESCR          => 'FastEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:0f',
                        IFLASTCHANGE     => '(4231) 0:00:42.31',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10016',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:10',
                        IFLASTCHANGE     => '(4231) 0:00:42.31',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10017',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:11',
                        IFLASTCHANGE     => '(1626503610) 188 days, 6:03:56.10',
                        IFINOCTETS       => '1619463572',
                        IFINERRORS       => '6301',
                        IFOUTOCTETS      => '977154644',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10018',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:12',
                        IFLASTCHANGE     => '(4231) 0:00:42.31',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10019',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:13',
                        IFLASTCHANGE     => '(1633323510) 189 days, 1:00:35.10',
                        IFINOCTETS       => '2525677665',
                        IFINERRORS       => '3',
                        IFOUTOCTETS      => '3438774464',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10020',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:14',
                        IFLASTCHANGE     => '(1633441760) 189 days, 1:20:17.60',
                        IFINOCTETS       => '2557592156',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '36851033',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10021',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:15',
                        IFLASTCHANGE     => '(4231) 0:00:42.31',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10022',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:16',
                        IFLASTCHANGE     => '(4231) 0:00:42.31',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10023',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:17',
                        IFLASTCHANGE     => '(4231) 0:00:42.31',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10024',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:18',
                        IFLASTCHANGE     => '(4231) 0:00:42.31',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10025',
                        IFDESCR          => 'FastEthernet0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:19',
                        IFLASTCHANGE     => '(1600000985) 185 days, 4:26:49.85',
                        IFINOCTETS       => '193179946',
                        IFINERRORS       => '6',
                        IFOUTOCTETS      => '1349888727',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10026',
                        IFDESCR          => 'FastEthernet0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:1a',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10027',
                        IFDESCR          => 'FastEthernet0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:1b',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10028',
                        IFDESCR          => 'FastEthernet0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:1c',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10029',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:1d',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10030',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:1e',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10031',
                        IFDESCR          => 'FastEthernet0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:1f',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10032',
                        IFDESCR          => 'FastEthernet0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:20',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10033',
                        IFDESCR          => 'FastEthernet0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:21',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10034',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:22',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10035',
                        IFDESCR          => 'FastEthernet0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:23',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10036',
                        IFDESCR          => 'FastEthernet0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:24',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10037',
                        IFDESCR          => 'FastEthernet0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:25',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10038',
                        IFDESCR          => 'FastEthernet0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:26',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10039',
                        IFDESCR          => 'FastEthernet0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:27',
                        IFLASTCHANGE     => '(1632988529) 189 days, 0:04:45.29',
                        IFINOCTETS       => '2100830282',
                        IFINERRORS       => '13004',
                        IFOUTOCTETS      => '2691288013',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10040',
                        IFDESCR          => 'FastEthernet0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:28',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10041',
                        IFDESCR          => 'FastEthernet0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:29',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10042',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:2a',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10043',
                        IFDESCR          => 'FastEthernet0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:2b',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10044',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:2c',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10045',
                        IFDESCR          => 'FastEthernet0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:2d',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10046',
                        IFDESCR          => 'FastEthernet0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:2e',
                        IFLASTCHANGE     => '(1622956857) 187 days, 20:12:48.57',
                        IFINOCTETS       => '1500391',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '157324648',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10047',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:2f',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10048',
                        IFDESCR          => 'FastEthernet0/48',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:30',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:31',
                        IFLASTCHANGE     => '(596600629) 69 days, 1:13:26.29',
                        IFINOCTETS       => '1720265539',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2490856586',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet1/0/22',
                                SYSNAME  => 'CB-C005-202.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.202',
                                MODEL    => 'cisco WS-C2960S-24TD-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10102',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:09:32',
                        IFLASTCHANGE     => '(4232) 0:00:42.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10501',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.11.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            SNMPHOSTNAME => 'CB-C005-207.Dauphine',
            MAC          => '2c:36:f8:7d:06:80',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            SNMPHOSTNAME => 'CB-C005-207.Dauphine',
            MAC          => '2c:36:f8:7d:06:80',
            MODELSNMP    => 'Networking2179',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => 'FCQ1605X4VP',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
                NAME         => 'CB-C005-207.Dauphine',
                MEMORY       => '4',
                SERIAL       => 'FCQ1605X4VP',
                FIRMWARE     => '15.0(1)SE3',
                MAC          => '2c:36:f8:7d:06:80',
                CPU          => '92',
                RAM          => '64',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:c0',
                        IFLASTCHANGE     => '(595957433) 68 days, 23:26:14.33',
                        IFINOCTETS       => '2446137012',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2022849692',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:81',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10002',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:82',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10003',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:83',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10004',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:84',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10005',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:85',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10006',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:86',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10007',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:87',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10008',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:88',
                        IFLASTCHANGE     => '(1615911411) 187 days, 0:38:34.11',
                        IFINOCTETS       => '4162799898',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2434568578',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10009',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:89',
                        IFLASTCHANGE     => '(1615374157) 186 days, 23:09:01.57',
                        IFINOCTETS       => '50514456',
                        IFINERRORS       => '45',
                        IFOUTOCTETS      => '3168236376',
                        IFOUTERRORS      => '148',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10010',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:8a',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10011',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:8b',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10012',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:8c',
                        IFLASTCHANGE     => '(1623513609) 187 days, 21:45:36.09',
                        IFINOCTETS       => '171288465',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2095312613',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10013',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:8d',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10014',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:8e',
                        IFLASTCHANGE     => '(1486671356) 172 days, 1:38:33.56',
                        IFINOCTETS       => '279026381',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3945616377',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10015',
                        IFDESCR          => 'FastEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:8f',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10016',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:90',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10017',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:91',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10018',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:92',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10019',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:93',
                        IFLASTCHANGE     => '(1631466876) 188 days, 19:51:08.76',
                        IFINOCTETS       => '1354428366',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2678286274',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10020',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:94',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10021',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:95',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10022',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:96',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10023',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:97',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10024',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:98',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10025',
                        IFDESCR          => 'FastEthernet0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:99',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10026',
                        IFDESCR          => 'FastEthernet0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:9a',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10027',
                        IFDESCR          => 'FastEthernet0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:9b',
                        IFLASTCHANGE     => '(1324013317) 153 days, 5:48:53.17',
                        IFINOCTETS       => '1354391915',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1640684234',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10028',
                        IFDESCR          => 'FastEthernet0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:9c',
                        IFLASTCHANGE     => '(4125) 0:00:41.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10029',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:9d',
                        IFLASTCHANGE     => '(419610) 1:09:56.10',
                        IFINOCTETS       => '1535589407',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2548890840',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10030',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:9e',
                        IFLASTCHANGE     => '(4125) 0:00:41.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10031',
                        IFDESCR          => 'FastEthernet0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:9f',
                        IFLASTCHANGE     => '(4125) 0:00:41.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10032',
                        IFDESCR          => 'FastEthernet0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:a0',
                        IFLASTCHANGE     => '(4125) 0:00:41.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10033',
                        IFDESCR          => 'FastEthernet0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:a1',
                        IFLASTCHANGE     => '(4125) 0:00:41.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10034',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:a2',
                        IFLASTCHANGE     => '(4125) 0:00:41.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10035',
                        IFDESCR          => 'FastEthernet0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:a3',
                        IFLASTCHANGE     => '(4125) 0:00:41.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10036',
                        IFDESCR          => 'FastEthernet0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:a4',
                        IFLASTCHANGE     => '(4125) 0:00:41.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10037',
                        IFDESCR          => 'FastEthernet0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:a5',
                        IFLASTCHANGE     => '(4125) 0:00:41.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10038',
                        IFDESCR          => 'FastEthernet0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:a6',
                        IFLASTCHANGE     => '(4125) 0:00:41.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10039',
                        IFDESCR          => 'FastEthernet0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:a7',
                        IFLASTCHANGE     => '(4125) 0:00:41.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10040',
                        IFDESCR          => 'FastEthernet0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:a8',
                        IFLASTCHANGE     => '(4125) 0:00:41.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10041',
                        IFDESCR          => 'FastEthernet0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:a9',
                        IFLASTCHANGE     => '(4126) 0:00:41.26',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10042',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:aa',
                        IFLASTCHANGE     => '(4126) 0:00:41.26',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10043',
                        IFDESCR          => 'FastEthernet0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:ab',
                        IFLASTCHANGE     => '(4126) 0:00:41.26',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10044',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:ac',
                        IFLASTCHANGE     => '(4126) 0:00:41.26',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10045',
                        IFDESCR          => 'FastEthernet0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:ad',
                        IFLASTCHANGE     => '(4126) 0:00:41.26',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10046',
                        IFDESCR          => 'FastEthernet0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:ae',
                        IFLASTCHANGE     => '(4126) 0:00:41.26',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10047',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:af',
                        IFLASTCHANGE     => '(4126) 0:00:41.26',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10048',
                        IFDESCR          => 'FastEthernet0/48',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:b0',
                        IFLASTCHANGE     => '(4126) 0:00:41.26',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:b1',
                        IFLASTCHANGE     => '(595957522) 68 days, 23:26:15.22',
                        IFINOCTETS       => '3690690104',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3489062289',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet1/0/21',
                                SYSNAME  => 'CB-C005-202.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.202',
                                MODEL    => 'cisco WS-C2960S-24TD-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10102',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '2c:36:f8:7d:06:b2',
                        IFLASTCHANGE     => '(4126) 0:00:41.26',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10501',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.12.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            SNMPHOSTNAME => 'CB-C005-205.Dauphine',
            MAC          => 'c4:0a:cb:22:e5:80',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            SNMPHOSTNAME => 'CB-C005-205.Dauphine',
            MAC          => 'c4:0a:cb:22:e5:80',
            MODELSNMP    => 'Networking2179',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => 'FOC1511W1CB',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
                NAME         => 'CB-C005-205.Dauphine',
                MEMORY       => '4',
                SERIAL       => 'FOC1511W1CB',
                FIRMWARE     => '15.0(1)SE3',
                MAC          => 'c4:0a:cb:22:e5:80',
                CPU          => '79',
                RAM          => '64',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:c0',
                        IFLASTCHANGE     => '(596609075) 69 days, 1:14:50.75',
                        IFINOCTETS       => '2871212296',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2443338754',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:81',
                        IFLASTCHANGE     => '(4058) 0:00:40.58',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10002',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:82',
                        IFLASTCHANGE     => '(4058) 0:00:40.58',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10003',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:83',
                        IFLASTCHANGE     => '(4058) 0:00:40.58',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10004',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:84',
                        IFLASTCHANGE     => '(4058) 0:00:40.58',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10005',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:85',
                        IFLASTCHANGE     => '(4058) 0:00:40.58',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10006',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:86',
                        IFLASTCHANGE     => '(4058) 0:00:40.58',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10007',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:87',
                        IFLASTCHANGE     => '(4058) 0:00:40.58',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10008',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:88',
                        IFLASTCHANGE     => '(4058) 0:00:40.58',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10009',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:89',
                        IFLASTCHANGE     => '(4059) 0:00:40.59',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10010',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:8a',
                        IFLASTCHANGE     => '(4059) 0:00:40.59',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10011',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:8b',
                        IFLASTCHANGE     => '(4059) 0:00:40.59',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10012',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:8c',
                        IFLASTCHANGE     => '(4059) 0:00:40.59',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10013',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:8d',
                        IFLASTCHANGE     => '(4059) 0:00:40.59',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10014',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:8e',
                        IFLASTCHANGE     => '(1631510009) 188 days, 19:58:20.09',
                        IFINOCTETS       => '1544560270',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3483278393',
                        IFOUTERRORS      => '10994',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10015',
                        IFDESCR          => 'FastEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:8f',
                        IFLASTCHANGE     => '(4059) 0:00:40.59',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10016',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:90',
                        IFLASTCHANGE     => '(1634398586) 189 days, 3:59:45.86',
                        IFINOCTETS       => '2724601483',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '2696552369',
                        IFOUTERRORS      => '10943',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10017',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:91',
                        IFLASTCHANGE     => '(4059) 0:00:40.59',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10018',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:92',
                        IFLASTCHANGE     => '(4059) 0:00:40.59',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10019',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:93',
                        IFLASTCHANGE     => '(4059) 0:00:40.59',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10020',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:94',
                        IFLASTCHANGE     => '(4059) 0:00:40.59',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10021',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:95',
                        IFLASTCHANGE     => '(4059) 0:00:40.59',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10022',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:96',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10023',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:97',
                        IFLASTCHANGE     => '(1630510233) 188 days, 17:11:42.33',
                        IFINOCTETS       => '174047329',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '916141211',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10024',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:98',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10025',
                        IFDESCR          => 'FastEthernet0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:99',
                        IFLASTCHANGE     => '(1630510161) 188 days, 17:11:41.61',
                        IFINOCTETS       => '171612321',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '993850547',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10026',
                        IFDESCR          => 'FastEthernet0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:9a',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10027',
                        IFDESCR          => 'FastEthernet0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:9b',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10028',
                        IFDESCR          => 'FastEthernet0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:9c',
                        IFLASTCHANGE     => '(1476276530) 170 days, 20:46:05.30',
                        IFINOCTETS       => '787254341',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1382513486',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10029',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:9d',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10030',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:9e',
                        IFLASTCHANGE     => '(1002540637) 116 days, 0:50:06.37',
                        IFINOCTETS       => '18309',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '28180240',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10031',
                        IFDESCR          => 'FastEthernet0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:9f',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10032',
                        IFDESCR          => 'FastEthernet0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:a0',
                        IFLASTCHANGE     => '(1002352522) 116 days, 0:18:45.22',
                        IFINOCTETS       => '1961',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1145076',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10033',
                        IFDESCR          => 'FastEthernet0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:a1',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10034',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:a2',
                        IFLASTCHANGE     => '(1630510297) 188 days, 17:11:42.97',
                        IFINOCTETS       => '184171260',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2034868762',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10035',
                        IFDESCR          => 'FastEthernet0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:a3',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10036',
                        IFDESCR          => 'FastEthernet0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:a4',
                        IFLASTCHANGE     => '(1002376442) 116 days, 0:22:44.42',
                        IFINOCTETS       => '6108',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '10636434',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10037',
                        IFDESCR          => 'FastEthernet0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:a5',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10038',
                        IFDESCR          => 'FastEthernet0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:a6',
                        IFLASTCHANGE     => '(1580441927) 182 days, 22:06:59.27',
                        IFINOCTETS       => '229049',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3882553',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10039',
                        IFDESCR          => 'FastEthernet0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:a7',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10040',
                        IFDESCR          => 'FastEthernet0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:a8',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10041',
                        IFDESCR          => 'FastEthernet0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:a9',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10042',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:aa',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10043',
                        IFDESCR          => 'FastEthernet0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:ab',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10044',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:ac',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10045',
                        IFDESCR          => 'FastEthernet0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:ad',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10046',
                        IFDESCR          => 'FastEthernet0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:ae',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10047',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:af',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10048',
                        IFDESCR          => 'FastEthernet0/48',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:b0',
                        IFLASTCHANGE     => '(4060) 0:00:40.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:b1',
                        IFLASTCHANGE     => '(596609163) 69 days, 1:14:51.63',
                        IFINOCTETS       => '1510685316',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4095281856',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet1/0/24',
                                SYSNAME  => 'CB-C005-202.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.202',
                                MODEL    => 'cisco WS-C2960S-24TD-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10102',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:22:e5:b2',
                        IFLASTCHANGE     => '(4061) 0:00:40.61',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10501',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.20.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
            SNMPHOSTNAME => 'CP-lt-40.example.com',
            MAC          => '04:c5:a4:42:f2:80',
            MODEL        => 'Catalyst 2960-8TC-S',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
            SNMPHOSTNAME => 'CP-lt-40.example.com',
            MAC          => '04:c5:a4:42:f2:80',
            MODELSNMP    => 'Networking2183',
            MODEL        => 'Catalyst 2960-8TC-S',
            FIRMWARE     => undef,
            SERIAL       => 'FOC1508V4B5',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-8TC-S',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
                NAME         => 'CP-lt-40.example.com',
                MEMORY       => '22',
                SERIAL       => 'FOC1508V4B5',
                FIRMWARE     => 'CW_VERSION$12.2(50)SE5$',
                IPS          => {
                    IP => [
                        '192.168.1.40',
                    ],
                },
                MAC          => '04:c5:a4:42:f2:80',
                UPTIME       => '(69260934) 8 days, 0:23:29.34',
                CPU          => '97',
                RAM          => '64',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vl1',
                        IFDESCR          => 'Vlan1',
                        IFALIAS          => 'MNGT',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.1.40',
                        MAC              => '04:c5:a4:42:f2:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4584) 0:00:45.84',
                        IFINOCTETS       => '1908443810',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '21744655',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'Fa0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4688) 0:00:46.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1599380',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '61797424',
                        IFOUTERRORS      => '2330',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'INFRA_SRV',
                                    NUMBER => '56',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'Fa0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:82',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4688) 0:00:46.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '658797',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '61239968',
                        IFOUTERRORS      => '2330',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'INFRA_SRV',
                                    NUMBER => '56',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'Fa0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:83',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4387) 0:00:43.87',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'INFRA_SRV',
                                    NUMBER => '56',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'Fa0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:84',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4387) 0:00:43.87',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'Fa0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:85',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4387) 0:00:43.87',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'Fa0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:86',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4387) 0:00:43.87',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'Fa0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4387) 0:00:43.87',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'Fa0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFALIAS          => 'VERS CB-INTERUFR-219 192.168.1.219 !',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(60319687) 6 days, 23:33:16.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '22175511',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2242606023',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'default',
                                    NUMBER => '1',
                                }
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '78:fe:3d:d5:0e:ff',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'Gi0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:89',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4861) 0:00:48.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '235512242',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '47433441',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CP1-CRIC-116.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(25)SEE1, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.116',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Nu0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.21.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
            SNMPHOSTNAME => 'default-40.example.com',
            MAC          => '04:c5:a4:42:f2:80',
            MODEL        => 'Catalyst 2960-8TC-S',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
            SNMPHOSTNAME => 'default-40.example.com',
            MAC          => '04:c5:a4:42:f2:80',
            MODELSNMP    => 'Networking2183',
            MODEL        => 'Catalyst 2960-8TC-S',
            FIRMWARE     => undef,
            SERIAL       => 'FOC1508V4B5',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-8TC-S',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
                NAME         => 'default-40.example.com',
                MEMORY       => '22',
                SERIAL       => 'FOC1508V4B5',
                FIRMWARE     => 'CW_VERSION$12.2(50)SE5$',
                MAC          => '04:c5:a4:42:f2:80',
                CPU          => '90',
                RAM          => '64',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:c0',
                        IFLASTCHANGE     => '(4765) 0:00:47.65',
                        IFINOCTETS       => '2211338520',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '439636656',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:81',
                        IFLASTCHANGE     => '(1699518194) 196 days, 16:53:01.94',
                        IFINOCTETS       => '77646872',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1451562620',
                        IFOUTERRORS      => '18',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'INFRA_SRV',
                                    NUMBER => '56',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:82',
                        IFLASTCHANGE     => '(4687) 0:00:46.87',
                        IFINOCTETS       => '48510643',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1448479479',
                        IFOUTERRORS      => '18',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'INFRA_SRV',
                                    NUMBER => '56',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:83',
                        IFLASTCHANGE     => '(4386) 0:00:43.86',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'INFRA_SRV',
                                    NUMBER => '56',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:84',
                        IFLASTCHANGE     => '(4386) 0:00:43.86',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:85',
                        IFLASTCHANGE     => '(4386) 0:00:43.86',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:86',
                        IFLASTCHANGE     => '(4386) 0:00:43.86',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:87',
                        IFLASTCHANGE     => '(4386) 0:00:43.86',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:88',
                        IFLASTCHANGE     => '(870221628) 100 days, 17:16:56.28',
                        IFINOCTETS       => '453028979',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2918695052',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'default',
                                    NUMBER => '1',
                                }
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '78:fe:3d:d5:0e:ff',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10101',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '04:c5:a4:42:f2:89',
                        IFLASTCHANGE     => '(4859) 0:00:48.59',
                        IFINOCTETS       => '2278713857',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1132732202',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CP1-CRIC-116.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(25)SEE1, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.116',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.22.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
            SNMPHOSTNAME => 'Scol-tmp-65.example.com',
            MAC          => 'e8:40:40:aa:73:80',
            MODEL        => 'Catalyst 2960-8TC-S',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
            SNMPHOSTNAME => 'Scol-tmp-65.example.com',
            MAC          => 'e8:40:40:aa:73:80',
            MODELSNMP    => 'Networking2183',
            MODEL        => 'Catalyst 2960-8TC-S',
            FIRMWARE     => undef,
            SERIAL       => 'FOC1511W532',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-8TC-S',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
                NAME         => 'Scol-tmp-65.example.com',
                MEMORY       => '22',
                SERIAL       => 'FOC1511W532',
                FIRMWARE     => 'CW_VERSION$12.2(50)SE5$',
                MAC          => 'e8:40:40:aa:73:80',
                CPU          => '90',
                RAM          => '64',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'e8:40:40:aa:73:c0',
                        IFLASTCHANGE     => '(4851) 0:00:48.51',
                        IFINOCTETS       => '255556080',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '74494857',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'e8:40:40:aa:73:81',
                        IFLASTCHANGE     => '(4449) 0:00:44.49',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'e8:40:40:aa:73:82',
                        IFLASTCHANGE     => '(4449) 0:00:44.49',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'e8:40:40:aa:73:83',
                        IFLASTCHANGE     => '(4449) 0:00:44.49',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'e8:40:40:aa:73:84',
                        IFLASTCHANGE     => '(4449) 0:00:44.49',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'e8:40:40:aa:73:85',
                        IFLASTCHANGE     => '(4449) 0:00:44.49',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'e8:40:40:aa:73:86',
                        IFLASTCHANGE     => '(4449) 0:00:44.49',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'e8:40:40:aa:73:87',
                        IFLASTCHANGE     => '(4449) 0:00:44.49',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'e8:40:40:aa:73:88',
                        IFLASTCHANGE     => '(4450) 0:00:44.50',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10101',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'e8:40:40:aa:73:89',
                        IFLASTCHANGE     => '(5140) 0:00:51.40',
                        IFINOCTETS       => '478357725',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '85760601',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0/13',
                                SYSNAME  => 'AP-Switch-51.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.51',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.24.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE4, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Fri 26-Mar-10 09:14 by prod_rel_team',
            SNMPHOSTNAME => 'AB-A422-7.example.com',
            MAC          => '40:f4:ec:d6:80:00',
            MODEL        => 'Catalyst 2960-8TC-S',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE4, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Fri 26-Mar-10 09:14 by prod_rel_team',
            SNMPHOSTNAME => 'AB-A422-7.example.com',
            MAC          => '40:f4:ec:d6:80:00',
            MODELSNMP    => 'Networking2184',
            MODEL        => 'Catalyst 2960-8TC-S',
            FIRMWARE     => undef,
            SERIAL       => 'FOC1501V1PS',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-8TC-S',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE4, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Fri 26-Mar-10 09:14 by prod_rel_team',
                NAME         => 'AB-A422-7.example.com',
                MEMORY       => '23',
                SERIAL       => 'FOC1501V1PS',
                FIRMWARE     => 'CW_VERSION$12.2(50)SE4$',
                IPS          => {
                    IP => [
                        '192.168.1.7',
                    ],
                },
                MAC          => '40:f4:ec:d6:80:00',
                UPTIME       => '(1513179720) 175 days, 3:16:37.20',
                CPU          => '92',
                RAM          => '64',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vl1',
                        IFDESCR          => 'Vlan1',
                        IFALIAS          => 'MNGT',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.1.7',
                        MAC              => '40:f4:ec:d6:80:40',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(18565332) 2 days, 3:34:13.32',
                        IFINOCTETS       => '2590321551',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '745432723',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'Fa0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '40:f4:ec:d6:80:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1480962412) 171 days, 9:47:04.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '68126956',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1326656584',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0005',
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'Fa0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFALIAS          => 'A424-INFO4.2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '40:f4:ec:d6:80:02',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0007',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'Fa0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFALIAS          => 'A424-INFO4.3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '40:f4:ec:d6:80:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0007',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'Fa0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '40:f4:ec:d6:80:04',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1481346896) 171 days, 10:51:08.96',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '2547705402',
                        IFINERRORS       => '2',
                        IFOUTOCTETS      => '2768496992',
                        IFOUTERRORS      => '3607',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0007',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'Fa0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '40:f4:ec:d6:80:05',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0007',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'Fa0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '40:f4:ec:d6:80:06',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0007',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'Fa0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '40:f4:ec:d6:80:07',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0007',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'Fa0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '40:f4:ec:d6:80:08',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0007',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'Gi0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '40:f4:ec:d6:80:09',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(18565530) 2 days, 3:34:15.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1388411911',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '3543298838',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0/1',
                                SYSNAME  => 'AB-Switch-1.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.1',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Nu0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.25.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AP-72.example.com',
            MAC          => 'c4:0a:cb:e6:f0:00',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AP-72.example.com',
            MAC          => 'c4:0a:cb:e6:f0:00',
            MODELSNMP    => 'Networking2416',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => undef,
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                NAME         => 'AP-72.example.com',
                MEMORY       => '20',
                IPS          => {
                    IP => [
                        '192.168.1.72',
                    ],
                },
                UPTIME       => '(353824260) 40 days, 22:50:42.60',
                CPU          => '88',
                RAM          => '60',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.1.72',
                        MAC              => 'c4:0a:cb:e6:f0:40',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(307811) 0:51:18.11',
                        IFINOCTETS       => '1610116325',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '352821127',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'FastEthernet0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:01',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4084) 0:00:40.84',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'FastEthernet0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:02',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4084) 0:00:40.84',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'FastEthernet0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:03',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(386721) 1:04:27.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '507105858',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '756332041',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'FastEthernet0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:04',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(379789) 1:03:17.89',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '153360360',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3117649181',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'FastEthernet0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:05',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(290882317) 33 days, 16:00:23.17',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '680518103',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2573011663',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'FastEthernet0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:06',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4084) 0:00:40.84',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'FastEthernet0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFALIAS          => 'AP-I-6023',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:07',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(388113) 1:04:41.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '671089899',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '504676058',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'FastEthernet0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:08',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(345475277) 39 days, 23:39:12.77',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '4087007195',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3060679302',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10009',
                        IFNAME           => 'FastEthernet0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFALIAS          => 'AP-I-6024',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:09',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(389128) 1:04:51.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2609224168',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3521084609',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10010',
                        IFNAME           => 'FastEthernet0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:0a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(347978569) 40 days, 6:36:25.69',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '341404625',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3580016358',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10011',
                        IFNAME           => 'FastEthernet0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:0b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(320577812) 37 days, 2:29:38.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '132249879',
                        IFINERRORS       => '1515',
                        IFOUTOCTETS      => '2442375155',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10012',
                        IFNAME           => 'FastEthernet0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFALIAS          => 'AP-I-4014-P417',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:0c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(321923662) 37 days, 6:13:56.62',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '1067415000',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '812503561',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10013',
                        IFNAME           => 'FastEthernet0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:0d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(390800) 1:05:08.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '359121911',
                        IFINERRORS       => '591',
                        IFOUTOCTETS      => '3433514988',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10014',
                        IFNAME           => 'FastEthernet0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:0e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(381013) 1:03:30.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '126151082',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2621084749',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10015',
                        IFNAME           => 'FastEthernet0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:0f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4086) 0:00:40.86',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10016',
                        IFNAME           => 'FastEthernet0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:10',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(353807472) 40 days, 22:47:54.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '166036634',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1799720061',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10017',
                        IFNAME           => 'FastEthernet0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:11',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(321857204) 37 days, 6:02:52.04',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '1791573126',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '823572932',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10018',
                        IFNAME           => 'FastEthernet0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:12',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(353200430) 40 days, 21:06:44.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '254622153',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1058979164',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10019',
                        IFNAME           => 'FastEthernet0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:13',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(349772612) 40 days, 11:35:26.12',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '303169302',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2456540728',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10020',
                        IFNAME           => 'FastEthernet0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:14',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(346052014) 40 days, 1:15:20.14',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '48582706',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '588495127',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10021',
                        IFNAME           => 'FastEthernet0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFALIAS          => 'Mme-Jomier',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:15',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(302480582) 35 days, 0:13:25.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '259332300',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '948041575',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10022',
                        IFNAME           => 'FastEthernet0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:16',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(190731649) 22 days, 1:48:36.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1796339792',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2377537428',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10023',
                        IFNAME           => 'FastEthernet0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:17',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4086) 0:00:40.86',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10024',
                        IFNAME           => 'FastEthernet0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:18',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(294316242) 34 days, 1:32:42.42',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '321715531',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '2995462255',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10025',
                        IFNAME           => 'FastEthernet0/25',
                        IFDESCR          => 'FastEthernet0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:19',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(392091) 1:05:20.91',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1139046158',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4061519092',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10026',
                        IFNAME           => 'FastEthernet0/26',
                        IFDESCR          => 'FastEthernet0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:1a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(353733331) 40 days, 22:35:33.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '897599736',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '608813461',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10027',
                        IFNAME           => 'FastEthernet0/27',
                        IFDESCR          => 'FastEthernet0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:1b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(391652) 1:05:16.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '363832282',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '84820619',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10028',
                        IFNAME           => 'FastEthernet0/28',
                        IFDESCR          => 'FastEthernet0/28',
                        IFALIAS          => 'AP-I-6028-B620gaucheEsc',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:1c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4086) 0:00:40.86',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10029',
                        IFNAME           => 'FastEthernet0/29',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:1d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4087) 0:00:40.87',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10030',
                        IFNAME           => 'FastEthernet0/30',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(353647873) 40 days, 22:21:18.73',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '501327004',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '175667222',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10031',
                        IFNAME           => 'FastEthernet0/31',
                        IFDESCR          => 'FastEthernet0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:1f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4087) 0:00:40.87',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10032',
                        IFNAME           => 'FastEthernet0/32',
                        IFDESCR          => 'FastEthernet0/32',
                        IFALIAS          => 'AP-I-5006 P512',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:20',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4087) 0:00:40.87',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10033',
                        IFNAME           => 'FastEthernet0/33',
                        IFDESCR          => 'FastEthernet0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:21',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(345958465) 40 days, 0:59:44.65',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '887485319',
                        IFINERRORS       => '3',
                        IFOUTOCTETS      => '2478842366',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10034',
                        IFNAME           => 'FastEthernet0/34',
                        IFDESCR          => 'FastEthernet0/34',
                        IFALIAS          => 'AP-I-6029-P620milieu',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:22',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(347817025) 40 days, 6:09:30.25',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '209395032',
                        IFINERRORS       => '2',
                        IFOUTOCTETS      => '1498951827',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '33',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10035',
                        IFNAME           => 'FastEthernet0/35',
                        IFDESCR          => 'FastEthernet0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:23',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4087) 0:00:40.87',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10036',
                        IFNAME           => 'FastEthernet0/36',
                        IFDESCR          => 'FastEthernet0/36',
                        IFALIAS          => 'AP-I-6030-P620Milieu',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:24',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4088) 0:00:40.88',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '33',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10037',
                        IFNAME           => 'FastEthernet0/37',
                        IFDESCR          => 'FastEthernet0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:25',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(389135) 1:04:51.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '761494658',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '495223509',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10038',
                        IFNAME           => 'FastEthernet0/38',
                        IFDESCR          => 'FastEthernet0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:26',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4088) 0:00:40.88',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10039',
                        IFNAME           => 'FastEthernet0/39',
                        IFDESCR          => 'FastEthernet0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:27',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(388603) 1:04:46.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '42789040',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2042259921',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10040',
                        IFNAME           => 'FastEthernet0/40',
                        IFDESCR          => 'FastEthernet0/40',
                        IFALIAS          => 'A716-AB-I-7106',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:28',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(353495549) 40 days, 21:55:55.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '29303899',
                        IFINERRORS       => '79',
                        IFOUTOCTETS      => '955469137',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '33',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10041',
                        IFNAME           => 'FastEthernet0/41',
                        IFDESCR          => 'FastEthernet0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:29',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4088) 0:00:40.88',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10042',
                        IFNAME           => 'FastEthernet0/42',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:2a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(379955) 1:03:19.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '715670159',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3890588264',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10043',
                        IFNAME           => 'FastEthernet0/43',
                        IFDESCR          => 'FastEthernet0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:2b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(225714255) 26 days, 2:59:02.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1838664412',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4125511793',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10044',
                        IFNAME           => 'FastEthernet0/44',
                        IFDESCR          => 'FastEthernet0/44',
                        IFALIAS          => 'AP-I-6032-P620Droit',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:2c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4089) 0:00:40.89',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '33',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10045',
                        IFNAME           => 'FastEthernet0/45',
                        IFDESCR          => 'FastEthernet0/45',
                        IFALIAS          => 'P620 API 6027 ',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:2d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(387140) 1:04:31.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '305141295',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2806555706',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '33',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10046',
                        IFNAME           => 'FastEthernet0/46',
                        IFDESCR          => 'FastEthernet0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:2e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4089) 0:00:40.89',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10047',
                        IFNAME           => 'FastEthernet0/47',
                        IFDESCR          => 'FastEthernet0/47',
                        IFALIAS          => 'P404b-AP-I-4033',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:2f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(314220564) 36 days, 8:50:05.64',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '122607678',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1393992022',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10048',
                        IFNAME           => 'FastEthernet0/48',
                        IFDESCR          => 'FastEthernet0/48',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:30',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4089) 0:00:40.89',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:31',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4089) 0:00:40.89',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet0/2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:f0:32',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(307810) 0:51:18.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2938291536',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3960287099',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0/18',
                                SYSNAME  => 'AP-Switch-51.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.51',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.26.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CB-243.example.com',
            MAC          => 'c4:0a:cb:e6:e8:80',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CB-243.example.com',
            MAC          => 'c4:0a:cb:e6:e8:80',
            MODELSNMP    => 'Networking2416',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => undef,
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                NAME         => 'CB-243.example.com',
                MEMORY       => '20',
                IPS          => {
                    IP => [
                        '192.168.1.243',
                    ],
                },
                UPTIME       => '(414811307) 48 days, 0:15:13.07',
                CPU          => '86',
                RAM          => '60',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.1.243',
                        MAC              => 'c4:0a:cb:e6:e8:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(243112293) 28 days, 3:18:42.93',
                        IFINOCTETS       => '1637558866',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '384759087',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'FastEthernet0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:81',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4102) 0:00:41.02',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'FastEthernet0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:82',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(413689479) 47 days, 21:08:14.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '497158253',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1780428234',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'FastEthernet0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFALIAS          => 'CB-I-6010-B640',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:83',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(407759248) 47 days, 4:39:52.48',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '1918969338',
                        IFINERRORS       => '83',
                        IFOUTOCTETS      => '1656161676',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'FastEthernet0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFALIAS          => 'CB-I-4011',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:84',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(347322) 0:57:53.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1333512877',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '490902365',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'FastEthernet0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:85',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(348425) 0:58:04.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2254790327',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'FastEthernet0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:86',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(79316261) 9 days, 4:19:22.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '336681994',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1735119533',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'FastEthernet0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(286399865) 33 days, 3:33:18.65',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '57958882',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2537069231',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'FastEthernet0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFALIAS          => 'CBI519A',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(64713) 0:10:47.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2472680676',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3964300497',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10009',
                        IFNAME           => 'FastEthernet0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFALIAS          => 'CB-I-6063',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:89',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(351505) 0:58:35.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2661465463',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1478400263',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10010',
                        IFNAME           => 'FastEthernet0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10011',
                        IFNAME           => 'FastEthernet0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:8b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(373737489) 43 days, 6:09:34.89',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '70054628',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2971444489',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10012',
                        IFNAME           => 'FastEthernet0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:8c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(3972) 0:00:39.72',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10013',
                        IFNAME           => 'FastEthernet0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFALIAS          => 'CBI-001 B046',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:8d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(362636524) 41 days, 23:19:25.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '64724386',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3721224604',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10014',
                        IFNAME           => 'FastEthernet0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFALIAS          => 'CB-I-5051 Paie',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:8e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(73773) 0:12:17.73',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '519576010',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2843625112',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10015',
                        IFNAME           => 'FastEthernet0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFALIAS          => 'CBI-1045 D120',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:8f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(180357) 0:30:03.57',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '1183137033',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2152244965',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10016',
                        IFNAME           => 'FastEthernet0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFALIAS          => 'D516  ',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:90',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(76978) 0:12:49.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1764424540',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3949275897',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10017',
                        IFNAME           => 'FastEthernet0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:91',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(413488740) 47 days, 20:34:47.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1772331613',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4283714395',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10018',
                        IFNAME           => 'FastEthernet0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:92',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(79221) 0:13:12.21',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '279675270',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '498238424',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10019',
                        IFNAME           => 'FastEthernet0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:93',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(383011347) 44 days, 7:55:13.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2474377606',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2431666154',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10020',
                        IFNAME           => 'FastEthernet0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:94',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4104) 0:00:41.04',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10021',
                        IFNAME           => 'FastEthernet0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:95',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(414329586) 47 days, 22:54:55.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2145039748',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3739481889',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10022',
                        IFNAME           => 'FastEthernet0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFALIAS          => 'CB-I-5052',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:96',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(413415234) 47 days, 20:22:32.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '910293590',
                        IFINERRORS       => '2253',
                        IFOUTOCTETS      => '2921028326',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10023',
                        IFNAME           => 'FastEthernet0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:97',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(414100489) 47 days, 22:16:44.89',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2569301891',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '3572352715',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10024',
                        IFNAME           => 'FastEthernet0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFALIAS          => 'CBI-1040 D116',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:98',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10025',
                        IFNAME           => 'FastEthernet0/25',
                        IFDESCR          => 'FastEthernet0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:99',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(180952) 0:30:09.52',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '295295371',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3467943347',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10026',
                        IFNAME           => 'FastEthernet0/26',
                        IFDESCR          => 'FastEthernet0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4032) 0:00:40.32',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10027',
                        IFNAME           => 'FastEthernet0/27',
                        IFDESCR          => 'FastEthernet0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:9b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(414019181) 47 days, 22:03:11.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '42248817',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2990042834',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10028',
                        IFNAME           => 'FastEthernet0/28',
                        IFDESCR          => 'FastEthernet0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:9c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10029',
                        IFNAME           => 'FastEthernet0/29',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:9d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(408542162) 47 days, 6:50:21.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '603870054',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2549513280',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10030',
                        IFNAME           => 'FastEthernet0/30',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:9e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(413100958) 47 days, 19:30:09.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '864068577',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '132773280',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10031',
                        IFNAME           => 'FastEthernet0/31',
                        IFDESCR          => 'FastEthernet0/31',
                        IFALIAS          => 'RJ4.17-ROCA8-REGIE',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:9f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10032',
                        IFNAME           => 'FastEthernet0/32',
                        IFDESCR          => 'FastEthernet0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:a0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10033',
                        IFNAME           => 'FastEthernet0/33',
                        IFDESCR          => 'FastEthernet0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:a1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(413521427) 47 days, 20:40:14.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3354112056',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '3851864674',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10034',
                        IFNAME           => 'FastEthernet0/34',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:a2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10035',
                        IFNAME           => 'FastEthernet0/35',
                        IFDESCR          => 'FastEthernet0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:a3',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(137703129) 15 days, 22:30:31.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2267002087',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2603564766',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10036',
                        IFNAME           => 'FastEthernet0/36',
                        IFDESCR          => 'FastEthernet0/36',
                        IFALIAS          => 'CIP-B421bis',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:a4',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(284034613) 32 days, 20:59:06.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3816451795',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2653475890',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '34',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10037',
                        IFNAME           => 'FastEthernet0/37',
                        IFDESCR          => 'FastEthernet0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:a5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10038',
                        IFNAME           => 'FastEthernet0/38',
                        IFDESCR          => 'FastEthernet0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:a6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(3894) 0:00:38.94',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10039',
                        IFNAME           => 'FastEthernet0/39',
                        IFDESCR          => 'FastEthernet0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:a7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(175648) 0:29:16.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1822106652',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1032818239',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10040',
                        IFNAME           => 'FastEthernet0/40',
                        IFDESCR          => 'FastEthernet0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(379363881) 43 days, 21:47:18.81',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '54822205',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3750350011',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10041',
                        IFNAME           => 'FastEthernet0/41',
                        IFDESCR          => 'FastEthernet0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:a9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10042',
                        IFNAME           => 'FastEthernet0/42',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:aa',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10043',
                        IFNAME           => 'FastEthernet0/43',
                        IFDESCR          => 'FastEthernet0/43',
                        IFALIAS          => 'B320 - CBI 3002',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:ab',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10044',
                        IFNAME           => 'FastEthernet0/44',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:ac',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10045',
                        IFNAME           => 'FastEthernet0/45',
                        IFDESCR          => 'FastEthernet0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:ad',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(293128108) 33 days, 22:14:41.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '70248823',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4137997403',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10046',
                        IFNAME           => 'FastEthernet0/46',
                        IFDESCR          => 'FastEthernet0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:ae',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(129384) 0:21:33.84',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '1784',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '83984',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10047',
                        IFNAME           => 'FastEthernet0/47',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:af',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(413634665) 47 days, 20:59:06.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '150380800',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4260968015',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10048',
                        IFNAME           => 'FastEthernet0/48',
                        IFDESCR          => 'FastEthernet0/48',
                        IFALIAS          => 'CBI-1041 D116',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:b0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(379351616) 43 days, 21:45:16.16',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '10167456',
                        IFINERRORS       => '122',
                        IFOUTOCTETS      => '287093414',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:b1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet0/2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:e6:e8:b2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(243112293) 28 days, 3:18:42.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1205874919',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2065905086',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet1/0/6',
                                SYSNAME  => 'CB-LT-0-6.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 15.0(2)SE, RELEASE SOFTWARE (fc1)',
                                IP       => '10.20.0.6',
                                MODEL    => 'cisco WS-C2960S-24TD-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.27.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AB-39.example.com',
            MAC          => 'c4:0a:cb:cd:83:00',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AB-39.example.com',
            MAC          => 'c4:0a:cb:cd:83:00',
            MODELSNMP    => 'Networking2416',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => undef,
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                NAME         => 'AB-39.example.com',
                MEMORY       => '20',
                IPS          => {
                    IP => [
                        '192.168.1.39',
                    ],
                },
                UPTIME       => '(399149124) 46 days, 4:44:51.24',
                CPU          => '86',
                RAM          => '60',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.1.39',
                        MAC              => 'c4:0a:cb:cd:83:40',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(19601) 0:03:16.01',
                        IFINOCTETS       => '1646773241',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '329970936',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'FastEthernet0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFALIAS          => 'B611-AB-I-6063',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(398986512) 46 days, 4:17:45.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1077054481',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1088658557',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'FastEthernet0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:02',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(90068) 0:15:00.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '54313218',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3893544945',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'FastEthernet0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4094) 0:00:40.94',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'FastEthernet0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:04',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(339058773) 39 days, 5:49:47.73',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '3179834',
                        IFINERRORS       => '11792',
                        IFOUTOCTETS      => '163540851',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'FastEthernet0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFALIAS          => 'B613-AB-I-6059',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:05',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(373402199) 43 days, 5:13:41.99',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '1442348',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '158749402',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '55',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'FastEthernet0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFALIAS          => 'B602b-AB-I-6004',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:06',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4095) 0:00:40.95',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'FastEthernet0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:07',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(274983991) 31 days, 19:50:39.91',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2017369650',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1932959363',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'FastEthernet0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:08',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(373287344) 43 days, 4:54:33.44',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '391240957',
                        IFINERRORS       => '135',
                        IFOUTOCTETS      => '1559704531',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10009',
                        IFNAME           => 'FastEthernet0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:09',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4095) 0:00:40.95',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10010',
                        IFNAME           => 'FastEthernet0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:0a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4095) 0:00:40.95',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10011',
                        IFNAME           => 'FastEthernet0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:0b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(355831562) 41 days, 4:25:15.62',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '429124969',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '291591497',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10012',
                        IFNAME           => 'FastEthernet0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:0c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(373499748) 43 days, 5:29:57.48',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '259419663',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1742189833',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10013',
                        IFNAME           => 'FastEthernet0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:0d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10014',
                        IFNAME           => 'FastEthernet0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:0e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(395997133) 45 days, 19:59:31.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '459538485',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3954590768',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10015',
                        IFNAME           => 'FastEthernet0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFALIAS          => 'B613-bis Ab-I-6057',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:0f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(18205) 0:03:02.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1693076107',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2993571232',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10016',
                        IFNAME           => 'FastEthernet0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:10',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(338548782) 39 days, 4:24:47.82',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '21782154',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3311245137',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10017',
                        IFNAME           => 'FastEthernet0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFALIAS          => 'B613-AB-I-6060',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:11',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(373399296) 43 days, 5:13:12.96',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '243936150',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '2320429264',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10018',
                        IFNAME           => 'FastEthernet0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:12',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10019',
                        IFNAME           => 'FastEthernet0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:13',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10020',
                        IFNAME           => 'FastEthernet0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFALIAS          => 'AB-I-6069-B609',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:14',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10021',
                        IFNAME           => 'FastEthernet0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:15',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(19761) 0:03:17.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '204126088',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1139583024',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10022',
                        IFNAME           => 'FastEthernet0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:16',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(94903926) 10 days, 23:37:19.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '273076162',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '105263224',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10023',
                        IFNAME           => 'FastEthernet0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFALIAS          => 'PB up/down 50 fois par minute...',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:17',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4009) 0:00:40.09',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10024',
                        IFNAME           => 'FastEthernet0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:18',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(83794) 0:13:57.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '295041092',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1169521450',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10025',
                        IFNAME           => 'FastEthernet0/25',
                        IFDESCR          => 'FastEthernet0/25',
                        IFALIAS          => 'AB-I-5102',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:19',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(398403951) 46 days, 2:40:39.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '159279876',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1299989040',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10026',
                        IFNAME           => 'FastEthernet0/26',
                        IFDESCR          => 'FastEthernet0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:1a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(83057) 0:13:50.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '154971075',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1462158495',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10027',
                        IFNAME           => 'FastEthernet0/27',
                        IFDESCR          => 'FastEthernet0/27',
                        IFALIAS          => 'IRIS-IDEFS',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:1b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(372714182) 43 days, 3:19:01.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '177661203',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '94822713',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10028',
                        IFNAME           => 'FastEthernet0/28',
                        IFDESCR          => 'FastEthernet0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:1c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(95601429) 11 days, 1:33:34.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2512344603',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2728136037',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10029',
                        IFNAME           => 'FastEthernet0/29',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:1d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4097) 0:00:40.97',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10030',
                        IFNAME           => 'FastEthernet0/30',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:1e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(398124187) 46 days, 1:54:01.87',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '92318275',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1525456045',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10031',
                        IFNAME           => 'FastEthernet0/31',
                        IFDESCR          => 'FastEthernet0/31',
                        IFALIAS          => 'IRIS-EURISCO',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:1f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4097) 0:00:40.97',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10032',
                        IFNAME           => 'FastEthernet0/32',
                        IFDESCR          => 'FastEthernet0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:20',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(396789246) 45 days, 22:11:32.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '230285879',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '644737321',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10033',
                        IFNAME           => 'FastEthernet0/33',
                        IFDESCR          => 'FastEthernet0/33',
                        IFALIAS          => 'IRIS-LEGOS',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:21',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(373799092) 43 days, 6:19:50.92',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '166684226',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3667580775',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10034',
                        IFNAME           => 'FastEthernet0/34',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:22',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(94510532) 10 days, 22:31:45.32',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '52192332',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '400503274',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10035',
                        IFNAME           => 'FastEthernet0/35',
                        IFDESCR          => 'FastEthernet0/35',
                        IFALIAS          => 'IRIS-CERDO',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:23',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(397607755) 46 days, 0:27:57.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '45344558',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3406155936',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10036',
                        IFNAME           => 'FastEthernet0/36',
                        IFDESCR          => 'FastEthernet0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:24',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(88446) 0:14:44.46',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '57169',
                        IFINERRORS       => '131',
                        IFOUTOCTETS      => '7049719',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10037',
                        IFNAME           => 'FastEthernet0/37',
                        IFDESCR          => 'FastEthernet0/37',
                        IFALIAS          => 'IRIS-LEGOS',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:25',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(350712465) 40 days, 14:12:04.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '178030566',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3153998775',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10038',
                        IFNAME           => 'FastEthernet0/38',
                        IFDESCR          => 'FastEthernet0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:26',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(78723) 0:13:07.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '248645438',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4040756127',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10039',
                        IFNAME           => 'FastEthernet0/39',
                        IFDESCR          => 'FastEthernet0/39',
                        IFALIAS          => 'IRIS-LEGOS',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:27',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4098) 0:00:40.98',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10040',
                        IFNAME           => 'FastEthernet0/40',
                        IFDESCR          => 'FastEthernet0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:28',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(346438944) 40 days, 2:19:49.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '929532514',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1935901378',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10041',
                        IFNAME           => 'FastEthernet0/41',
                        IFDESCR          => 'FastEthernet0/41',
                        IFALIAS          => 'IRIS-LEGOS',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:29',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(398827244) 46 days, 3:51:12.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '208685915',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1751732687',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10042',
                        IFNAME           => 'FastEthernet0/42',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:2a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4098) 0:00:40.98',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10043',
                        IFNAME           => 'FastEthernet0/43',
                        IFDESCR          => 'FastEthernet0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:2b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(638058) 1:46:20.58',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '19401258',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3382662662',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10044',
                        IFNAME           => 'FastEthernet0/44',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:2c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(73934) 0:12:19.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '828169904',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2621710761',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10045',
                        IFNAME           => 'FastEthernet0/45',
                        IFDESCR          => 'FastEthernet0/45',
                        IFALIAS          => 'IRIS-LEGOS',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:2d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(16148) 0:02:41.48',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '7191',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10046',
                        IFNAME           => 'FastEthernet0/46',
                        IFDESCR          => 'FastEthernet0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:2e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(3929) 0:00:39.29',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10047',
                        IFNAME           => 'FastEthernet0/47',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:2f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4099) 0:00:40.99',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10048',
                        IFNAME           => 'FastEthernet0/48',
                        IFDESCR          => 'FastEthernet0/48',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:30',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4099) 0:00:40.99',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFALIAS          => 'B606-AB-I-6008 wifi-B606-67',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:31',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(183826324) 21 days, 6:37:43.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2407842475',
                        IFINERRORS       => '787976',
                        IFOUTOCTETS      => '629744854',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet0/2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFALIAS          => 'AB-Switch-1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:83:32',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(19601) 0:03:16.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3464173483',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '1089744093',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0/15',
                                SYSNAME  => 'AB-Switch-1.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.1',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.28.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AB-35.example.com',
            MAC          => 'c4:0a:cb:95:39:00',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AB-35.example.com',
            MAC          => 'c4:0a:cb:95:39:00',
            MODELSNMP    => 'Networking2416',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => undef,
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                NAME         => 'AB-35.example.com',
                MEMORY       => '20',
                IPS          => {
                    IP => [
                        '192.168.1.35',
                    ],
                },
                UPTIME       => '(399196332) 46 days, 4:52:43.32',
                CPU          => '86',
                RAM          => '60',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.1.35',
                        MAC              => 'c4:0a:cb:95:39:40',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(397566922) 46 days, 0:21:09.22',
                        IFINOCTETS       => '1648762067',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '327002474',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'FastEthernet0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFALIAS          => 'B307-AB-I-3044',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:01',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4102) 0:00:41.02',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '31',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'FastEthernet0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:02',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(396563513) 45 days, 21:33:55.13',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '63981580',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '937738588',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'FastEthernet0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFALIAS          => 'UFRGEA',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4102) 0:00:41.02',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '31',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'FastEthernet0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFALIAS          => 'ABI-5011-B515',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:04',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(398236494) 46 days, 2:12:44.94',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '450344552',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3204214563',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'FastEthernet0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFALIAS          => 'UFRGEA',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:05',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(398401314) 46 days, 2:40:13.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '38840233',
                        IFINERRORS       => '2',
                        IFOUTOCTETS      => '452614371',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '31',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'FastEthernet0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFALIAS          => 'B307-AB-I-3043',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:06',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(108190) 0:18:01.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '549493032',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'FastEthernet0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFALIAS          => 'B309-AB-I-3037',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:07',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4102) 0:00:41.02',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '31',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'FastEthernet0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFALIAS          => 'AB-I-0055-B021',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:08',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '6',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10009',
                        IFNAME           => 'FastEthernet0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFALIAS          => 'AB-I-3032-B311b',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:09',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10010',
                        IFNAME           => 'FastEthernet0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:0a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(350878119) 40 days, 14:39:41.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '67816202',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '327285714',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10011',
                        IFNAME           => 'FastEthernet0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFALIAS          => 'AB-I-3025',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:0b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10012',
                        IFNAME           => 'FastEthernet0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFALIAS          => 'B216 ABI-2017',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:0c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(120665) 0:20:06.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '650951580',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '394157597',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10013',
                        IFNAME           => 'FastEthernet0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFALIAS          => 'AB-I-3021',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:0d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10014',
                        IFNAME           => 'FastEthernet0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFALIAS          => 'IRIS-CERDO',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:0e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10015',
                        IFNAME           => 'FastEthernet0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFALIAS          => 'AB-I-3022',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:0f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10016',
                        IFNAME           => 'FastEthernet0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:10',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4104) 0:00:41.04',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10017',
                        IFNAME           => 'FastEthernet0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFALIAS          => 'AB-I-3027-B313',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:11',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4104) 0:00:41.04',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10018',
                        IFNAME           => 'FastEthernet0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFALIAS          => 'B033-Lionel Lenoble',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:12',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(398731456) 46 days, 3:35:14.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '187013600',
                        IFINERRORS       => '6',
                        IFOUTOCTETS      => '2869573976',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10019',
                        IFNAME           => 'FastEthernet0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFALIAS          => 'AB-I-3035-B309b',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:13',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(95642711) 11 days, 1:40:27.11',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '60657',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '13077',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10020',
                        IFNAME           => 'FastEthernet0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:14',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(279218937) 32 days, 7:36:29.37',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '129005432',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1026310893',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10021',
                        IFNAME           => 'FastEthernet0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFALIAS          => 'AB-I-3024',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:15',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(345682468) 40 days, 0:13:44.68',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '16077838',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '331384323',
                        IFOUTERRORS      => '2',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10022',
                        IFNAME           => 'FastEthernet0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFALIAS          => 'AB-I-0046-B031',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:16',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(372688082) 43 days, 3:14:40.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '42629097',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2826019152',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10023',
                        IFNAME           => 'FastEthernet0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFALIAS          => 'AB-I-3028-B313',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:17',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10666876) 1 day, 5:37:48.76',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '9715655',
                        IFINERRORS       => '2',
                        IFOUTOCTETS      => '90823211',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10024',
                        IFNAME           => 'FastEthernet0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFALIAS          => 'AB-I 6061 B611B',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:18',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(105228) 0:17:32.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '491106439',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1386091241',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10025',
                        IFNAME           => 'FastEthernet0/25',
                        IFDESCR          => 'FastEthernet0/25',
                        IFALIAS          => 'B030 ABI0029',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:19',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '32',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10026',
                        IFNAME           => 'FastEthernet0/26',
                        IFDESCR          => 'FastEthernet0/26',
                        IFALIAS          => 'AB-I-6065 B609t',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:1a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(373696278) 43 days, 6:02:42.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '357716310',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '206058251',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10027',
                        IFNAME           => 'FastEthernet0/27',
                        IFDESCR          => 'FastEthernet0/27',
                        IFALIAS          => 'ETUD',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:1b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '6',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10028',
                        IFNAME           => 'FastEthernet0/28',
                        IFDESCR          => 'FastEthernet0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:1c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10029',
                        IFNAME           => 'FastEthernet0/29',
                        IFDESCR          => 'FastEthernet0/29',
                        IFALIAS          => 'ETUD',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:1d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '6',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10030',
                        IFNAME           => 'FastEthernet0/30',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:1e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10031',
                        IFNAME           => 'FastEthernet0/31',
                        IFDESCR          => 'FastEthernet0/31',
                        IFALIAS          => 'AB-I-3029-B313',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:1f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10032',
                        IFNAME           => 'FastEthernet0/32',
                        IFDESCR          => 'FastEthernet0/32',
                        IFALIAS          => 'AB-I-2015-B214',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:20',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(240662414) 27 days, 20:30:24.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1205439419',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2210751295',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10033',
                        IFNAME           => 'FastEthernet0/33',
                        IFDESCR          => 'FastEthernet0/33',
                        IFALIAS          => 'ETUD',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:21',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '6',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10034',
                        IFNAME           => 'FastEthernet0/34',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:22',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10035',
                        IFNAME           => 'FastEthernet0/35',
                        IFDESCR          => 'FastEthernet0/35',
                        IFALIAS          => 'UFRGEA',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:23',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '31',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10036',
                        IFNAME           => 'FastEthernet0/36',
                        IFDESCR          => 'FastEthernet0/36',
                        IFALIAS          => 'AB-I-0058 B019',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:24',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(240527926) 27 days, 20:07:59.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '836343698',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4232137886',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '32',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10037',
                        IFNAME           => 'FastEthernet0/37',
                        IFDESCR          => 'FastEthernet0/37',
                        IFALIAS          => 'ABI-6070',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:25',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(397557227) 46 days, 0:19:32.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '369211235',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2686165684',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10038',
                        IFNAME           => 'FastEthernet0/38',
                        IFDESCR          => 'FastEthernet0/38',
                        IFALIAS          => 'B216-AB-I-2018',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:26',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10039',
                        IFNAME           => 'FastEthernet0/39',
                        IFDESCR          => 'FastEthernet0/39',
                        IFALIAS          => 'ABI-0039 B038',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:27',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '6',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10040',
                        IFNAME           => 'FastEthernet0/40',
                        IFDESCR          => 'FastEthernet0/40',
                        IFALIAS          => 'AB-I-6014-IRISRuffin',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:28',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10041',
                        IFNAME           => 'FastEthernet0/41',
                        IFDESCR          => 'FastEthernet0/41',
                        IFALIAS          => 'ABI-6022',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:29',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '6',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10042',
                        IFNAME           => 'FastEthernet0/42',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:2a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10043',
                        IFNAME           => 'FastEthernet0/43',
                        IFDESCR          => 'FastEthernet0/43',
                        IFALIAS          => 'B419 419-02-I (bloc)',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:2b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '49',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10044',
                        IFNAME           => 'FastEthernet0/44',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:2c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(375400086) 43 days, 10:46:40.86',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '87723288',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1614810966',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10045',
                        IFNAME           => 'FastEthernet0/45',
                        IFDESCR          => 'FastEthernet0/45',
                        IFALIAS          => 'AB-I-2016',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:2d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10046',
                        IFNAME           => 'FastEthernet0/46',
                        IFDESCR          => 'FastEthernet0/46',
                        IFALIAS          => 'B017',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:2e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(338194023) 39 days, 3:25:40.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '288663124',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1813930953',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '6',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10047',
                        IFNAME           => 'FastEthernet0/47',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:2f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10048',
                        IFNAME           => 'FastEthernet0/48',
                        IFDESCR          => 'FastEthernet0/48',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:30',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:31',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet0/2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:95:39:32',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(397566921) 46 days, 0:21:09.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '771322567',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '1590529004',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0/2',
                                SYSNAME  => 'AB-Switch-1.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.1',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.29.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CP-106.example.com',
            MAC          => 'c4:0a:cb:cd:8b:80',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CP-106.example.com',
            MAC          => 'c4:0a:cb:cd:8b:80',
            MODELSNMP    => 'Networking2416',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => undef,
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                NAME         => 'CP-106.example.com',
                MEMORY       => '20',
                CPU          => '82',
                RAM          => '60',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:c0',
                        IFLASTCHANGE     => '(22495) 0:03:44.95',
                        IFINOCTETS       => '324306997',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '198326962',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'FastEthernet0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:81',
                        IFLASTCHANGE     => '(120329) 0:20:03.29',
                        IFINOCTETS       => '80308107',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1592600745',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'FastEthernet0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:82',
                        IFLASTCHANGE     => '(156236660) 18 days, 1:59:26.60',
                        IFINOCTETS       => '30585837',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '132128949',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'FastEthernet0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:83',
                        IFLASTCHANGE     => '(157187364) 18 days, 4:37:53.64',
                        IFINOCTETS       => '401747940',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '1589500122',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'FastEthernet0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:84',
                        IFLASTCHANGE     => '(4086) 0:00:40.86',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'FastEthernet0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:85',
                        IFLASTCHANGE     => '(147202045) 17 days, 0:53:40.45',
                        IFINOCTETS       => '159598301',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1870553961',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'FastEthernet0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:86',
                        IFLASTCHANGE     => '(4086) 0:00:40.86',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'FastEthernet0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:87',
                        IFLASTCHANGE     => '(132931) 0:22:09.31',
                        IFINOCTETS       => '452391194',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3555848377',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'FastEthernet0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:88',
                        IFLASTCHANGE     => '(157169607) 18 days, 4:34:56.07',
                        IFINOCTETS       => '137011271',
                        IFINERRORS       => '1073',
                        IFOUTOCTETS      => '172987482',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10009',
                        IFNAME           => 'FastEthernet0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:89',
                        IFLASTCHANGE     => '(136738) 0:22:47.38',
                        IFINOCTETS       => '84803097',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1950174094',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10010',
                        IFNAME           => 'FastEthernet0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:8a',
                        IFLASTCHANGE     => '(4087) 0:00:40.87',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10011',
                        IFNAME           => 'FastEthernet0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:8b',
                        IFLASTCHANGE     => '(142474) 0:23:44.74',
                        IFINOCTETS       => '136356734',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1729236803',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10012',
                        IFNAME           => 'FastEthernet0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:8c',
                        IFLASTCHANGE     => '(84365) 0:14:03.65',
                        IFINOCTETS       => '33108269',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '979250843',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10013',
                        IFNAME           => 'FastEthernet0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:8d',
                        IFLASTCHANGE     => '(157208813) 18 days, 4:41:28.13',
                        IFINOCTETS       => '32554739',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1466664361',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10014',
                        IFNAME           => 'FastEthernet0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:8e',
                        IFLASTCHANGE     => '(4087) 0:00:40.87',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10015',
                        IFNAME           => 'FastEthernet0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:8f',
                        IFLASTCHANGE     => '(155727668) 18 days, 0:34:36.68',
                        IFINOCTETS       => '182885356',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '11019714',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10016',
                        IFNAME           => 'FastEthernet0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:90',
                        IFLASTCHANGE     => '(4088) 0:00:40.88',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10017',
                        IFNAME           => 'FastEthernet0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:91',
                        IFLASTCHANGE     => '(155897899) 18 days, 1:02:58.99',
                        IFINOCTETS       => '185618733',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1136058308',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10018',
                        IFNAME           => 'FastEthernet0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:92',
                        IFLASTCHANGE     => '(120072415) 13 days, 21:32:04.15',
                        IFINOCTETS       => '32667238',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1751606549',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10019',
                        IFNAME           => 'FastEthernet0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:93',
                        IFLASTCHANGE     => '(972962) 2:42:09.62',
                        IFINOCTETS       => '806805605',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '845501901',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10020',
                        IFNAME           => 'FastEthernet0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:94',
                        IFLASTCHANGE     => '(4088) 0:00:40.88',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10021',
                        IFNAME           => 'FastEthernet0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:95',
                        IFLASTCHANGE     => '(159516) 0:26:35.16',
                        IFINOCTETS       => '3511113674',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2955248708',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10022',
                        IFNAME           => 'FastEthernet0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:96',
                        IFLASTCHANGE     => '(4089) 0:00:40.89',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10023',
                        IFNAME           => 'FastEthernet0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:97',
                        IFLASTCHANGE     => '(129040) 0:21:30.40',
                        IFINOCTETS       => '3895288',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '415142315',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10024',
                        IFNAME           => 'FastEthernet0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:98',
                        IFLASTCHANGE     => '(154708286) 17 days, 21:44:42.86',
                        IFINOCTETS       => '639422648',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1583482082',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10025',
                        IFNAME           => 'FastEthernet0/25',
                        IFDESCR          => 'FastEthernet0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:99',
                        IFLASTCHANGE     => '(4089) 0:00:40.89',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10026',
                        IFNAME           => 'FastEthernet0/26',
                        IFDESCR          => 'FastEthernet0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:9a',
                        IFLASTCHANGE     => '(4089) 0:00:40.89',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10027',
                        IFNAME           => 'FastEthernet0/27',
                        IFDESCR          => 'FastEthernet0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:9b',
                        IFLASTCHANGE     => '(4029) 0:00:40.29',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '24',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10028',
                        IFNAME           => 'FastEthernet0/28',
                        IFDESCR          => 'FastEthernet0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:9c',
                        IFLASTCHANGE     => '(50226) 0:08:22.26',
                        IFINOCTETS       => '107351309',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1105193530',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10029',
                        IFNAME           => 'FastEthernet0/29',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:9d',
                        IFLASTCHANGE     => '(4089) 0:00:40.89',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '24',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10030',
                        IFNAME           => 'FastEthernet0/30',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:9e',
                        IFLASTCHANGE     => '(48414) 0:08:04.14',
                        IFINOCTETS       => '259003',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '153717880',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10031',
                        IFNAME           => 'FastEthernet0/31',
                        IFDESCR          => 'FastEthernet0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:9f',
                        IFLASTCHANGE     => '(4090) 0:00:40.90',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10032',
                        IFNAME           => 'FastEthernet0/32',
                        IFDESCR          => 'FastEthernet0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:a0',
                        IFLASTCHANGE     => '(148809907) 17 days, 5:21:39.07',
                        IFINOCTETS       => '10780724',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '199413415',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10033',
                        IFNAME           => 'FastEthernet0/33',
                        IFDESCR          => 'FastEthernet0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:a1',
                        IFLASTCHANGE     => '(88578895) 10 days, 6:03:08.95',
                        IFINOCTETS       => '76801671',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '325559206',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '55',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10034',
                        IFNAME           => 'FastEthernet0/34',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:a2',
                        IFLASTCHANGE     => '(4090) 0:00:40.90',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '24',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10035',
                        IFNAME           => 'FastEthernet0/35',
                        IFDESCR          => 'FastEthernet0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:a3',
                        IFLASTCHANGE     => '(123585420) 14 days, 7:17:34.20',
                        IFINOCTETS       => '2047445154',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '909692649',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10036',
                        IFNAME           => 'FastEthernet0/36',
                        IFDESCR          => 'FastEthernet0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:a4',
                        IFLASTCHANGE     => '(54324491) 6 days, 6:54:04.91',
                        IFINOCTETS       => '206712049',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '288470454',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10037',
                        IFNAME           => 'FastEthernet0/37',
                        IFDESCR          => 'FastEthernet0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:a5',
                        IFLASTCHANGE     => '(1440739) 4:00:07.39',
                        IFINOCTETS       => '807464',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '860035231',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10038',
                        IFNAME           => 'FastEthernet0/38',
                        IFDESCR          => 'FastEthernet0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:a6',
                        IFLASTCHANGE     => '(4091) 0:00:40.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10039',
                        IFNAME           => 'FastEthernet0/39',
                        IFDESCR          => 'FastEthernet0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:a7',
                        IFLASTCHANGE     => '(4091) 0:00:40.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10040',
                        IFNAME           => 'FastEthernet0/40',
                        IFDESCR          => 'FastEthernet0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:a8',
                        IFLASTCHANGE     => '(39253) 0:06:32.53',
                        IFINOCTETS       => '993714857',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '26334686',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10041',
                        IFNAME           => 'FastEthernet0/41',
                        IFDESCR          => 'FastEthernet0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:a9',
                        IFLASTCHANGE     => '(4091) 0:00:40.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10042',
                        IFNAME           => 'FastEthernet0/42',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:aa',
                        IFLASTCHANGE     => '(4091) 0:00:40.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10043',
                        IFNAME           => 'FastEthernet0/43',
                        IFDESCR          => 'FastEthernet0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:ab',
                        IFLASTCHANGE     => '(4091) 0:00:40.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10044',
                        IFNAME           => 'FastEthernet0/44',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:ac',
                        IFLASTCHANGE     => '(3919) 0:00:39.19',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10045',
                        IFNAME           => 'FastEthernet0/45',
                        IFDESCR          => 'FastEthernet0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:ad',
                        IFLASTCHANGE     => '(4091) 0:00:40.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10046',
                        IFNAME           => 'FastEthernet0/46',
                        IFDESCR          => 'FastEthernet0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:ae',
                        IFLASTCHANGE     => '(155765287) 18 days, 0:40:52.87',
                        IFINOCTETS       => '69855460',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '314016603',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10047',
                        IFNAME           => 'FastEthernet0/47',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:af',
                        IFLASTCHANGE     => '(4091) 0:00:40.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10048',
                        IFNAME           => 'FastEthernet0/48',
                        IFDESCR          => 'FastEthernet0/48',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:b0',
                        IFLASTCHANGE     => '(4091) 0:00:40.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:b1',
                        IFLASTCHANGE     => '(4091) 0:00:40.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet0/2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:8b:b2',
                        IFLASTCHANGE     => '(22495) 0:03:44.95',
                        IFINOCTETS       => '667860899',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1234036200',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0/22',
                                SYSNAME  => 'CP-Switch-101.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.101',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.30.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AP-71.example.com',
            MAC          => 'c4:0a:cb:ab:68:80',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AP-71.example.com',
            MAC          => 'c4:0a:cb:ab:68:80',
            MODELSNMP    => 'Networking2416',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => undef,
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                NAME         => 'AP-71.example.com',
                MEMORY       => '20',
                CPU          => '83',
                RAM          => '60',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:c0',
                        IFLASTCHANGE     => '(18742) 0:03:07.42',
                        IFINOCTETS       => '166336386',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '92223141',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'FastEthernet0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:81',
                        IFLASTCHANGE     => '(4093) 0:00:40.93',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'FastEthernet0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:82',
                        IFLASTCHANGE     => '(4093) 0:00:40.93',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'FastEthernet0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:83',
                        IFLASTCHANGE     => '(4093) 0:00:40.93',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'FastEthernet0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:84',
                        IFLASTCHANGE     => '(4093) 0:00:40.93',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'FastEthernet0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:85',
                        IFLASTCHANGE     => '(4093) 0:00:40.93',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'FastEthernet0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:86',
                        IFLASTCHANGE     => '(4094) 0:00:40.94',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'FastEthernet0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:87',
                        IFLASTCHANGE     => '(4094) 0:00:40.94',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'FastEthernet0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:88',
                        IFLASTCHANGE     => '(384320) 1:04:03.20',
                        IFINOCTETS       => '949969381',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '441295959',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10009',
                        IFNAME           => 'FastEthernet0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:89',
                        IFLASTCHANGE     => '(51159683) 5 days, 22:06:36.83',
                        IFINOCTETS       => '12485333',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '462928907',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10010',
                        IFNAME           => 'FastEthernet0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:8a',
                        IFLASTCHANGE     => '(5877187) 16:19:31.87',
                        IFINOCTETS       => '162391644',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2027456597',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10011',
                        IFNAME           => 'FastEthernet0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:8b',
                        IFLASTCHANGE     => '(413977) 1:08:59.77',
                        IFINOCTETS       => '502829',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '12616711',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10012',
                        IFNAME           => 'FastEthernet0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:8c',
                        IFLASTCHANGE     => '(4094) 0:00:40.94',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10013',
                        IFNAME           => 'FastEthernet0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:8d',
                        IFLASTCHANGE     => '(414385) 1:09:03.85',
                        IFINOCTETS       => '1436417149',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3382839916',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10014',
                        IFNAME           => 'FastEthernet0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:8e',
                        IFLASTCHANGE     => '(4095) 0:00:40.95',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10015',
                        IFNAME           => 'FastEthernet0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:8f',
                        IFLASTCHANGE     => '(414101) 1:09:01.01',
                        IFINOCTETS       => '135900175',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2459505968',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10016',
                        IFNAME           => 'FastEthernet0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:90',
                        IFLASTCHANGE     => '(4095) 0:00:40.95',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10017',
                        IFNAME           => 'FastEthernet0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:91',
                        IFLASTCHANGE     => '(79551102) 9 days, 4:58:31.02',
                        IFINOCTETS       => '110108413',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1672644216',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10018',
                        IFNAME           => 'FastEthernet0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:92',
                        IFLASTCHANGE     => '(391184) 1:05:11.84',
                        IFINOCTETS       => '249425464',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4177097156',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '28',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10019',
                        IFNAME           => 'FastEthernet0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:93',
                        IFLASTCHANGE     => '(412878) 1:08:48.78',
                        IFINOCTETS       => '95344638',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1010945089',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10020',
                        IFNAME           => 'FastEthernet0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:94',
                        IFLASTCHANGE     => '(4095) 0:00:40.95',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10021',
                        IFNAME           => 'FastEthernet0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:95',
                        IFLASTCHANGE     => '(71212257) 8 days, 5:48:42.57',
                        IFINOCTETS       => '62480892',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '850459015',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10022',
                        IFNAME           => 'FastEthernet0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:96',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10023',
                        IFNAME           => 'FastEthernet0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:97',
                        IFLASTCHANGE     => '(411787) 1:08:37.87',
                        IFINOCTETS       => '2006974792',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2379000962',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10024',
                        IFNAME           => 'FastEthernet0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:98',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10025',
                        IFNAME           => 'FastEthernet0/25',
                        IFDESCR          => 'FastEthernet0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:99',
                        IFLASTCHANGE     => '(11117687) 1 day, 6:52:56.87',
                        IFINOCTETS       => '4563711',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '219374044',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10026',
                        IFNAME           => 'FastEthernet0/26',
                        IFDESCR          => 'FastEthernet0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:9a',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10027',
                        IFNAME           => 'FastEthernet0/27',
                        IFDESCR          => 'FastEthernet0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:9b',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10028',
                        IFNAME           => 'FastEthernet0/28',
                        IFDESCR          => 'FastEthernet0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:9c',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10029',
                        IFNAME           => 'FastEthernet0/29',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:9d',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10030',
                        IFNAME           => 'FastEthernet0/30',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:9e',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10031',
                        IFNAME           => 'FastEthernet0/31',
                        IFDESCR          => 'FastEthernet0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:9f',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10032',
                        IFNAME           => 'FastEthernet0/32',
                        IFDESCR          => 'FastEthernet0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:a0',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10033',
                        IFNAME           => 'FastEthernet0/33',
                        IFDESCR          => 'FastEthernet0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:a1',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10034',
                        IFNAME           => 'FastEthernet0/34',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:a2',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10035',
                        IFNAME           => 'FastEthernet0/35',
                        IFDESCR          => 'FastEthernet0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:a3',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10036',
                        IFNAME           => 'FastEthernet0/36',
                        IFDESCR          => 'FastEthernet0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:a4',
                        IFLASTCHANGE     => '(4097) 0:00:40.97',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10037',
                        IFNAME           => 'FastEthernet0/37',
                        IFDESCR          => 'FastEthernet0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:a5',
                        IFLASTCHANGE     => '(4097) 0:00:40.97',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10038',
                        IFNAME           => 'FastEthernet0/38',
                        IFDESCR          => 'FastEthernet0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:a6',
                        IFLASTCHANGE     => '(4097) 0:00:40.97',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10039',
                        IFNAME           => 'FastEthernet0/39',
                        IFDESCR          => 'FastEthernet0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:a7',
                        IFLASTCHANGE     => '(4097) 0:00:40.97',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10040',
                        IFNAME           => 'FastEthernet0/40',
                        IFDESCR          => 'FastEthernet0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:a8',
                        IFLASTCHANGE     => '(4097) 0:00:40.97',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10041',
                        IFNAME           => 'FastEthernet0/41',
                        IFDESCR          => 'FastEthernet0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:a9',
                        IFLASTCHANGE     => '(4097) 0:00:40.97',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '55',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10042',
                        IFNAME           => 'FastEthernet0/42',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:aa',
                        IFLASTCHANGE     => '(4097) 0:00:40.97',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10043',
                        IFNAME           => 'FastEthernet0/43',
                        IFDESCR          => 'FastEthernet0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:ab',
                        IFLASTCHANGE     => '(71113114) 8 days, 5:32:11.14',
                        IFINOCTETS       => '39828973',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '415391758',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10044',
                        IFNAME           => 'FastEthernet0/44',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:ac',
                        IFLASTCHANGE     => '(4098) 0:00:40.98',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10045',
                        IFNAME           => 'FastEthernet0/45',
                        IFDESCR          => 'FastEthernet0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:ad',
                        IFLASTCHANGE     => '(72050738) 8 days, 8:08:27.38',
                        IFINOCTETS       => '10411413',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '210423630',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10046',
                        IFNAME           => 'FastEthernet0/46',
                        IFDESCR          => 'FastEthernet0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:ae',
                        IFLASTCHANGE     => '(78218157) 9 days, 1:16:21.57',
                        IFINOCTETS       => '15360300',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '65411852',
                        IFOUTERRORS      => '474',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10047',
                        IFNAME           => 'FastEthernet0/47',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:af',
                        IFLASTCHANGE     => '(4098) 0:00:40.98',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10048',
                        IFNAME           => 'FastEthernet0/48',
                        IFDESCR          => 'FastEthernet0/48',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:b0',
                        IFLASTCHANGE     => '(4098) 0:00:40.98',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:b1',
                        IFLASTCHANGE     => '(402301) 1:07:03.01',
                        IFINOCTETS       => '1199196918',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3964600438',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'AP-A410-13.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.13',
                                MODEL    => 'cisco WS-C2960-8TC-S',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet0/2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ab:68:b2',
                        IFLASTCHANGE     => '(18742) 0:03:07.42',
                        IFINOCTETS       => '2969359472',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '2308685046',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0/17',
                                SYSNAME  => 'AP-Switch-51.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.51',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.32.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CP-129.example.com',
            MAC          => 'c4:0a:cb:cd:88:00',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CP-129.example.com',
            MAC          => 'c4:0a:cb:cd:88:00',
            MODELSNMP    => 'Networking2416',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => undef,
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                NAME         => 'CP-129.example.com',
                MEMORY       => '20',
                CPU          => '90',
                RAM          => '60',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:40',
                        IFLASTCHANGE     => '(4818) 0:00:48.18',
                        IFINOCTETS       => '342494300',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '209672405',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'FastEthernet0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:01',
                        IFLASTCHANGE     => '(155851887) 18 days, 0:55:18.87',
                        IFINOCTETS       => '139092153',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '1742419228',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'FastEthernet0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:02',
                        IFLASTCHANGE     => '(4067) 0:00:40.67',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'FastEthernet0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:03',
                        IFLASTCHANGE     => '(157084500) 18 days, 4:20:45.00',
                        IFINOCTETS       => '71450121',
                        IFINERRORS       => '189',
                        IFOUTOCTETS      => '532210388',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'FastEthernet0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:04',
                        IFLASTCHANGE     => '(19905) 0:03:19.05',
                        IFINOCTETS       => '430952526',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2153282605',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'FastEthernet0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:05',
                        IFLASTCHANGE     => '(42446) 0:07:04.46',
                        IFINOCTETS       => '253409112',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2083166134',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'FastEthernet0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:06',
                        IFLASTCHANGE     => '(4067) 0:00:40.67',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'FastEthernet0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:07',
                        IFLASTCHANGE     => '(4068) 0:00:40.68',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'FastEthernet0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:08',
                        IFLASTCHANGE     => '(4068) 0:00:40.68',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10009',
                        IFNAME           => 'FastEthernet0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:09',
                        IFLASTCHANGE     => '(11551577) 1 day, 8:05:15.77',
                        IFINOCTETS       => '7036113',
                        IFINERRORS       => '74',
                        IFOUTOCTETS      => '46155745',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10010',
                        IFNAME           => 'FastEthernet0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:0a',
                        IFLASTCHANGE     => '(25805) 0:04:18.05',
                        IFINOCTETS       => '303791372',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1572003616',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10011',
                        IFNAME           => 'FastEthernet0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:0b',
                        IFLASTCHANGE     => '(36176409) 4 days, 4:29:24.09',
                        IFINOCTETS       => '21173022',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '104717078',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10012',
                        IFNAME           => 'FastEthernet0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:0c',
                        IFLASTCHANGE     => '(156473469) 18 days, 2:38:54.69',
                        IFINOCTETS       => '529422442',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1497067739',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10013',
                        IFNAME           => 'FastEthernet0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:0d',
                        IFLASTCHANGE     => '(27594771) 3 days, 4:39:07.71',
                        IFINOCTETS       => '269553',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '556202230',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10014',
                        IFNAME           => 'FastEthernet0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:0e',
                        IFLASTCHANGE     => '(4068) 0:00:40.68',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10015',
                        IFNAME           => 'FastEthernet0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:0f',
                        IFLASTCHANGE     => '(156881980) 18 days, 3:46:59.80',
                        IFINOCTETS       => '290650374',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '942669195',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10016',
                        IFNAME           => 'FastEthernet0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:10',
                        IFLASTCHANGE     => '(155152038) 17 days, 22:58:40.38',
                        IFINOCTETS       => '425593965',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '1082667493',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10017',
                        IFNAME           => 'FastEthernet0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:11',
                        IFLASTCHANGE     => '(61871) 0:10:18.71',
                        IFINOCTETS       => '85600087',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '415511032',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10018',
                        IFNAME           => 'FastEthernet0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:12',
                        IFLASTCHANGE     => '(4069) 0:00:40.69',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10019',
                        IFNAME           => 'FastEthernet0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:13',
                        IFLASTCHANGE     => '(157014166) 18 days, 4:09:01.66',
                        IFINOCTETS       => '1101020097',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1273830488',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10020',
                        IFNAME           => 'FastEthernet0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:14',
                        IFLASTCHANGE     => '(4069) 0:00:40.69',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10021',
                        IFNAME           => 'FastEthernet0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:15',
                        IFLASTCHANGE     => '(494680) 1:22:26.80',
                        IFINOCTETS       => '4174769',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '8081125',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10022',
                        IFNAME           => 'FastEthernet0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:16',
                        IFLASTCHANGE     => '(156492827) 18 days, 2:42:08.27',
                        IFINOCTETS       => '219300370',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '1310224702',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10023',
                        IFNAME           => 'FastEthernet0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:17',
                        IFLASTCHANGE     => '(156722698) 18 days, 3:20:26.98',
                        IFINOCTETS       => '182718884',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1083092560',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10024',
                        IFNAME           => 'FastEthernet0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:18',
                        IFLASTCHANGE     => '(70020985) 8 days, 2:30:09.85',
                        IFINOCTETS       => '35025856',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '589031780',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10025',
                        IFNAME           => 'FastEthernet0/25',
                        IFDESCR          => 'FastEthernet0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:19',
                        IFLASTCHANGE     => '(70814) 0:11:48.14',
                        IFINOCTETS       => '230329713',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3842105064',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10026',
                        IFNAME           => 'FastEthernet0/26',
                        IFDESCR          => 'FastEthernet0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:1a',
                        IFLASTCHANGE     => '(156472527) 18 days, 2:38:45.27',
                        IFINOCTETS       => '904740817',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1522207991',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10027',
                        IFNAME           => 'FastEthernet0/27',
                        IFDESCR          => 'FastEthernet0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:1b',
                        IFLASTCHANGE     => '(4070) 0:00:40.70',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10028',
                        IFNAME           => 'FastEthernet0/28',
                        IFDESCR          => 'FastEthernet0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:1c',
                        IFLASTCHANGE     => '(4070) 0:00:40.70',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10029',
                        IFNAME           => 'FastEthernet0/29',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:1d',
                        IFLASTCHANGE     => '(4070) 0:00:40.70',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10030',
                        IFNAME           => 'FastEthernet0/30',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:1e',
                        IFLASTCHANGE     => '(4070) 0:00:40.70',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10031',
                        IFNAME           => 'FastEthernet0/31',
                        IFDESCR          => 'FastEthernet0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:1f',
                        IFLASTCHANGE     => '(4070) 0:00:40.70',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10032',
                        IFNAME           => 'FastEthernet0/32',
                        IFDESCR          => 'FastEthernet0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:20',
                        IFLASTCHANGE     => '(4070) 0:00:40.70',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10033',
                        IFNAME           => 'FastEthernet0/33',
                        IFDESCR          => 'FastEthernet0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:21',
                        IFLASTCHANGE     => '(4070) 0:00:40.70',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10034',
                        IFNAME           => 'FastEthernet0/34',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:22',
                        IFLASTCHANGE     => '(18502) 0:03:05.02',
                        IFINOCTETS       => '54802860',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '566699409',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10035',
                        IFNAME           => 'FastEthernet0/35',
                        IFDESCR          => 'FastEthernet0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:23',
                        IFLASTCHANGE     => '(78322684) 9 days, 1:33:46.84',
                        IFINOCTETS       => '639159257',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1673881452',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10036',
                        IFNAME           => 'FastEthernet0/36',
                        IFDESCR          => 'FastEthernet0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:24',
                        IFLASTCHANGE     => '(4070) 0:00:40.70',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10037',
                        IFNAME           => 'FastEthernet0/37',
                        IFDESCR          => 'FastEthernet0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:25',
                        IFLASTCHANGE     => '(44233383) 5 days, 2:52:13.83',
                        IFINOCTETS       => '174439316',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '333305315',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '3',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10038',
                        IFNAME           => 'FastEthernet0/38',
                        IFDESCR          => 'FastEthernet0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:26',
                        IFLASTCHANGE     => '(155164185) 17 days, 23:00:41.85',
                        IFINOCTETS       => '213617248',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1165949405',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10039',
                        IFNAME           => 'FastEthernet0/39',
                        IFDESCR          => 'FastEthernet0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:27',
                        IFLASTCHANGE     => '(148619821) 17 days, 4:49:58.21',
                        IFINOCTETS       => '221363175',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2459270527',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10040',
                        IFNAME           => 'FastEthernet0/40',
                        IFDESCR          => 'FastEthernet0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:28',
                        IFLASTCHANGE     => '(4071) 0:00:40.71',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10041',
                        IFNAME           => 'FastEthernet0/41',
                        IFDESCR          => 'FastEthernet0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:29',
                        IFLASTCHANGE     => '(66105) 0:11:01.05',
                        IFINOCTETS       => '255905393',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2966830873',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10042',
                        IFNAME           => 'FastEthernet0/42',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:2a',
                        IFLASTCHANGE     => '(15690) 0:02:36.90',
                        IFINOCTETS       => '1866640217',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3051142050',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10043',
                        IFNAME           => 'FastEthernet0/43',
                        IFDESCR          => 'FastEthernet0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:2b',
                        IFLASTCHANGE     => '(4071) 0:00:40.71',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10044',
                        IFNAME           => 'FastEthernet0/44',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:2c',
                        IFLASTCHANGE     => '(156105339) 18 days, 1:37:33.39',
                        IFINOCTETS       => '357067127',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1322368606',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10045',
                        IFNAME           => 'FastEthernet0/45',
                        IFDESCR          => 'FastEthernet0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:2d',
                        IFLASTCHANGE     => '(4071) 0:00:40.71',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10046',
                        IFNAME           => 'FastEthernet0/46',
                        IFDESCR          => 'FastEthernet0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:2e',
                        IFLASTCHANGE     => '(156408486) 18 days, 2:28:04.86',
                        IFINOCTETS       => '2531683071',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4131182755',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10047',
                        IFNAME           => 'FastEthernet0/47',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:2f',
                        IFLASTCHANGE     => '(4072) 0:00:40.72',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10048',
                        IFNAME           => 'FastEthernet0/48',
                        IFDESCR          => 'FastEthernet0/48',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:30',
                        IFLASTCHANGE     => '(4072) 0:00:40.72',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:31',
                        IFLASTCHANGE     => '(4072) 0:00:40.72',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet0/2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:88:32',
                        IFLASTCHANGE     => '(79048) 0:13:10.48',
                        IFINOCTETS       => '1843027809',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '2395085022',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0/11',
                                SYSNAME  => 'CP-Switch-101.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.101',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.33.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AP-73.example.com',
            MAC          => 'c4:0a:cb:ba:6c:00',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AP-73.example.com',
            MAC          => 'c4:0a:cb:ba:6c:00',
            MODELSNMP    => 'Networking2416',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => undef,
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                NAME         => 'AP-73.example.com',
                MEMORY       => '20',
                CPU          => '91',
                RAM          => '60',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:40',
                        IFLASTCHANGE     => '(187468) 0:31:14.68',
                        IFINOCTETS       => '144407765',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '83035701',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'FastEthernet0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:01',
                        IFLASTCHANGE     => '(69851016) 8 days, 2:01:50.16',
                        IFINOCTETS       => '72026347',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '551563172',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'FastEthernet0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:02',
                        IFLASTCHANGE     => '(2482988) 6:53:49.88',
                        IFINOCTETS       => '5751709',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '180494199',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'FastEthernet0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:03',
                        IFLASTCHANGE     => '(714923) 1:59:09.23',
                        IFINOCTETS       => '527872396',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2127212600',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'FastEthernet0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:04',
                        IFLASTCHANGE     => '(62551534) 7 days, 5:45:15.34',
                        IFINOCTETS       => '268465910',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1544870396',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'FastEthernet0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:05',
                        IFLASTCHANGE     => '(2650923) 7:21:49.23',
                        IFINOCTETS       => '1256518',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '138162383',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'FastEthernet0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:06',
                        IFLASTCHANGE     => '(4091) 0:00:40.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'FastEthernet0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:07',
                        IFLASTCHANGE     => '(61877376) 7 days, 3:52:53.76',
                        IFINOCTETS       => '178580626',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1013155442',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'FastEthernet0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:08',
                        IFLASTCHANGE     => '(4091) 0:00:40.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10009',
                        IFNAME           => 'FastEthernet0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:09',
                        IFLASTCHANGE     => '(68379177) 7 days, 21:56:31.77',
                        IFINOCTETS       => '236325752',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1049235021',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10010',
                        IFNAME           => 'FastEthernet0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:0a',
                        IFLASTCHANGE     => '(4091) 0:00:40.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10011',
                        IFNAME           => 'FastEthernet0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:0b',
                        IFLASTCHANGE     => '(71218823) 8 days, 5:49:48.23',
                        IFINOCTETS       => '44846590',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '1205965751',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10012',
                        IFNAME           => 'FastEthernet0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:0c',
                        IFLASTCHANGE     => '(70400905) 8 days, 3:33:29.05',
                        IFINOCTETS       => '140246634',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '907775152',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10013',
                        IFNAME           => 'FastEthernet0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:0d',
                        IFLASTCHANGE     => '(4091) 0:00:40.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10014',
                        IFNAME           => 'FastEthernet0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:0e',
                        IFLASTCHANGE     => '(4092) 0:00:40.92',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10015',
                        IFNAME           => 'FastEthernet0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:0f',
                        IFLASTCHANGE     => '(720940) 2:00:09.40',
                        IFINOCTETS       => '98005676',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '472359628',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10016',
                        IFNAME           => 'FastEthernet0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:10',
                        IFLASTCHANGE     => '(4092) 0:00:40.92',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10017',
                        IFNAME           => 'FastEthernet0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:11',
                        IFLASTCHANGE     => '(4092) 0:00:40.92',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10018',
                        IFNAME           => 'FastEthernet0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:12',
                        IFLASTCHANGE     => '(4092) 0:00:40.92',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10019',
                        IFNAME           => 'FastEthernet0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:13',
                        IFLASTCHANGE     => '(71289318) 8 days, 6:01:33.18',
                        IFINOCTETS       => '145683637',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1238652232',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10020',
                        IFNAME           => 'FastEthernet0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:14',
                        IFLASTCHANGE     => '(4092) 0:00:40.92',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10021',
                        IFNAME           => 'FastEthernet0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:15',
                        IFLASTCHANGE     => '(722434) 2:00:24.34',
                        IFINOCTETS       => '280071751',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1727731681',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10022',
                        IFNAME           => 'FastEthernet0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:16',
                        IFLASTCHANGE     => '(4093) 0:00:40.93',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10023',
                        IFNAME           => 'FastEthernet0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:17',
                        IFLASTCHANGE     => '(70989573) 8 days, 5:11:35.73',
                        IFINOCTETS       => '93118465',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '216068348',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10024',
                        IFNAME           => 'FastEthernet0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:18',
                        IFLASTCHANGE     => '(69618960) 8 days, 1:23:09.60',
                        IFINOCTETS       => '358479611',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '75384595',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10025',
                        IFNAME           => 'FastEthernet0/25',
                        IFDESCR          => 'FastEthernet0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:19',
                        IFLASTCHANGE     => '(70789112) 8 days, 4:38:11.12',
                        IFINOCTETS       => '6781078',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '643522671',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10026',
                        IFNAME           => 'FastEthernet0/26',
                        IFDESCR          => 'FastEthernet0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:1a',
                        IFLASTCHANGE     => '(779595) 2:09:55.95',
                        IFINOCTETS       => '113916008',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '741613119',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10027',
                        IFNAME           => 'FastEthernet0/27',
                        IFDESCR          => 'FastEthernet0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:1b',
                        IFLASTCHANGE     => '(4093) 0:00:40.93',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10028',
                        IFNAME           => 'FastEthernet0/28',
                        IFDESCR          => 'FastEthernet0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:1c',
                        IFLASTCHANGE     => '(69389190) 8 days, 0:44:51.90',
                        IFINOCTETS       => '7992856',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '241156515',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10029',
                        IFNAME           => 'FastEthernet0/29',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:1d',
                        IFLASTCHANGE     => '(4094) 0:00:40.94',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10030',
                        IFNAME           => 'FastEthernet0/30',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:1e',
                        IFLASTCHANGE     => '(785572) 2:10:55.72',
                        IFINOCTETS       => '189882779',
                        IFINERRORS       => '198',
                        IFOUTOCTETS      => '1817390113',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10031',
                        IFNAME           => 'FastEthernet0/31',
                        IFDESCR          => 'FastEthernet0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:1f',
                        IFLASTCHANGE     => '(4094) 0:00:40.94',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10032',
                        IFNAME           => 'FastEthernet0/32',
                        IFDESCR          => 'FastEthernet0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:20',
                        IFLASTCHANGE     => '(37007231) 4 days, 6:47:52.31',
                        IFINOCTETS       => '6932449',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '108639740',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10033',
                        IFNAME           => 'FastEthernet0/33',
                        IFDESCR          => 'FastEthernet0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:21',
                        IFLASTCHANGE     => '(735646) 2:02:36.46',
                        IFINOCTETS       => '68568863',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '750136193',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10034',
                        IFNAME           => 'FastEthernet0/34',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:22',
                        IFLASTCHANGE     => '(4094) 0:00:40.94',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10035',
                        IFNAME           => 'FastEthernet0/35',
                        IFDESCR          => 'FastEthernet0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:23',
                        IFLASTCHANGE     => '(4094) 0:00:40.94',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '28',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10036',
                        IFNAME           => 'FastEthernet0/36',
                        IFDESCR          => 'FastEthernet0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:24',
                        IFLASTCHANGE     => '(63540286) 7 days, 8:30:02.86',
                        IFINOCTETS       => '50578752',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '485644142',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10037',
                        IFNAME           => 'FastEthernet0/37',
                        IFDESCR          => 'FastEthernet0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:25',
                        IFLASTCHANGE     => '(4095) 0:00:40.95',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10038',
                        IFNAME           => 'FastEthernet0/38',
                        IFDESCR          => 'FastEthernet0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:26',
                        IFLASTCHANGE     => '(4095) 0:00:40.95',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10039',
                        IFNAME           => 'FastEthernet0/39',
                        IFDESCR          => 'FastEthernet0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:27',
                        IFLASTCHANGE     => '(68243810) 7 days, 21:33:58.10',
                        IFINOCTETS       => '76692457',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '318157013',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10040',
                        IFNAME           => 'FastEthernet0/40',
                        IFDESCR          => 'FastEthernet0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:28',
                        IFLASTCHANGE     => '(4095) 0:00:40.95',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10041',
                        IFNAME           => 'FastEthernet0/41',
                        IFDESCR          => 'FastEthernet0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:29',
                        IFLASTCHANGE     => '(4095) 0:00:40.95',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10042',
                        IFNAME           => 'FastEthernet0/42',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:2a',
                        IFLASTCHANGE     => '(796874) 2:12:48.74',
                        IFINOCTETS       => '149910350',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1121153068',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10043',
                        IFNAME           => 'FastEthernet0/43',
                        IFDESCR          => 'FastEthernet0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:2b',
                        IFLASTCHANGE     => '(71436134) 8 days, 6:26:01.34',
                        IFINOCTETS       => '112096126',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '508696340',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10044',
                        IFNAME           => 'FastEthernet0/44',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:2c',
                        IFLASTCHANGE     => '(45330644) 5 days, 5:55:06.44',
                        IFINOCTETS       => '26357827',
                        IFINERRORS       => '2172',
                        IFOUTOCTETS      => '397895750',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10045',
                        IFNAME           => 'FastEthernet0/45',
                        IFDESCR          => 'FastEthernet0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:2d',
                        IFLASTCHANGE     => '(70794781) 8 days, 4:39:07.81',
                        IFINOCTETS       => '76860575',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '580114711',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10046',
                        IFNAME           => 'FastEthernet0/46',
                        IFDESCR          => 'FastEthernet0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:2e',
                        IFLASTCHANGE     => '(71039024) 8 days, 5:19:50.24',
                        IFINOCTETS       => '4563813',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '56826608',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '33',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10047',
                        IFNAME           => 'FastEthernet0/47',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:2f',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10048',
                        IFNAME           => 'FastEthernet0/48',
                        IFDESCR          => 'FastEthernet0/48',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:30',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:31',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet0/2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6c:32',
                        IFLASTCHANGE     => '(187467) 0:31:14.67',
                        IFINOCTETS       => '2035232519',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3071486535',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0/9',
                                SYSNAME  => 'AP-Switch-51.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.51',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.35.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CP-138.example.com',
            MAC          => 'c4:0a:cb:ba:6e:80',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CP-138.example.com',
            MAC          => 'c4:0a:cb:ba:6e:80',
            MODELSNMP    => 'Networking2416',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => undef,
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                NAME         => 'CP-138.example.com',
                MEMORY       => '20',
                CPU          => '89',
                RAM          => '60',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:c0',
                        IFLASTCHANGE     => '(27650) 0:04:36.50',
                        IFINOCTETS       => '303984672',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '166297533',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'FastEthernet0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:81',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'FastEthernet0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:82',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'FastEthernet0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:83',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'FastEthernet0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:84',
                        IFLASTCHANGE     => '(74303921) 8 days, 14:23:59.21',
                        IFINOCTETS       => '1567',
                        IFINERRORS       => '9',
                        IFOUTOCTETS      => '8164',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'FastEthernet0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:85',
                        IFLASTCHANGE     => '(25410380) 2 days, 22:35:03.80',
                        IFINOCTETS       => '9605270',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '144881846',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '3',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'FastEthernet0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:86',
                        IFLASTCHANGE     => '(155288548) 17 days, 23:21:25.48',
                        IFINOCTETS       => '83024961',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '840720064',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'FastEthernet0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:87',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '17',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'FastEthernet0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:88',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10009',
                        IFNAME           => 'FastEthernet0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:89',
                        IFLASTCHANGE     => '(737161) 2:02:51.61',
                        IFINOCTETS       => '18024168',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '612976902',
                        IFOUTERRORS      => '4',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10010',
                        IFNAME           => 'FastEthernet0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:8a',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10011',
                        IFNAME           => 'FastEthernet0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:8b',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10012',
                        IFNAME           => 'FastEthernet0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:8c',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10013',
                        IFNAME           => 'FastEthernet0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:8d',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10014',
                        IFNAME           => 'FastEthernet0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:8e',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10015',
                        IFNAME           => 'FastEthernet0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:8f',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10016',
                        IFNAME           => 'FastEthernet0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:90',
                        IFLASTCHANGE     => '(56846) 0:09:28.46',
                        IFINOCTETS       => '1996365421',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2953355851',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10017',
                        IFNAME           => 'FastEthernet0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:91',
                        IFLASTCHANGE     => '(4097) 0:00:40.97',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '10',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10018',
                        IFNAME           => 'FastEthernet0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:92',
                        IFLASTCHANGE     => '(4097) 0:00:40.97',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '17',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10019',
                        IFNAME           => 'FastEthernet0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:93',
                        IFLASTCHANGE     => '(4097) 0:00:40.97',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10020',
                        IFNAME           => 'FastEthernet0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:94',
                        IFLASTCHANGE     => '(17536643) 2 days, 0:42:46.43',
                        IFINOCTETS       => '3722663305',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '216745396',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10021',
                        IFNAME           => 'FastEthernet0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:95',
                        IFLASTCHANGE     => '(605618) 1:40:56.18',
                        IFINOCTETS       => '438974108',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '46574638',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10022',
                        IFNAME           => 'FastEthernet0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:96',
                        IFLASTCHANGE     => '(155053926) 17 days, 22:42:19.26',
                        IFINOCTETS       => '323761022',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1286935100',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10023',
                        IFNAME           => 'FastEthernet0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:97',
                        IFLASTCHANGE     => '(91637) 0:15:16.37',
                        IFINOCTETS       => '2089262099',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '724058817',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10024',
                        IFNAME           => 'FastEthernet0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:98',
                        IFLASTCHANGE     => '(146401629) 16 days, 22:40:16.29',
                        IFINOCTETS       => '63656455',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '910962138',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10025',
                        IFNAME           => 'FastEthernet0/25',
                        IFDESCR          => 'FastEthernet0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:99',
                        IFLASTCHANGE     => '(89253) 0:14:52.53',
                        IFINOCTETS       => '1199538826',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '273047875',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10026',
                        IFNAME           => 'FastEthernet0/26',
                        IFDESCR          => 'FastEthernet0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:9a',
                        IFLASTCHANGE     => '(4098) 0:00:40.98',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10027',
                        IFNAME           => 'FastEthernet0/27',
                        IFDESCR          => 'FastEthernet0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:9b',
                        IFLASTCHANGE     => '(4098) 0:00:40.98',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '1',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10028',
                        IFNAME           => 'FastEthernet0/28',
                        IFDESCR          => 'FastEthernet0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:9c',
                        IFLASTCHANGE     => '(38687) 0:06:26.87',
                        IFINOCTETS       => '25004481',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '573755015',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10029',
                        IFNAME           => 'FastEthernet0/29',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:9d',
                        IFLASTCHANGE     => '(4098) 0:00:40.98',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10030',
                        IFNAME           => 'FastEthernet0/30',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:9e',
                        IFLASTCHANGE     => '(147846818) 17 days, 2:41:08.18',
                        IFINOCTETS       => '182373565',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1676447716',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10031',
                        IFNAME           => 'FastEthernet0/31',
                        IFDESCR          => 'FastEthernet0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:9f',
                        IFLASTCHANGE     => '(4098) 0:00:40.98',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10032',
                        IFNAME           => 'FastEthernet0/32',
                        IFDESCR          => 'FastEthernet0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:a0',
                        IFLASTCHANGE     => '(36132) 0:06:01.32',
                        IFINOCTETS       => '374269884',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2167847608',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10033',
                        IFNAME           => 'FastEthernet0/33',
                        IFDESCR          => 'FastEthernet0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:a1',
                        IFLASTCHANGE     => '(4099) 0:00:40.99',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10034',
                        IFNAME           => 'FastEthernet0/34',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:a2',
                        IFLASTCHANGE     => '(4071) 0:00:40.71',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10035',
                        IFNAME           => 'FastEthernet0/35',
                        IFDESCR          => 'FastEthernet0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:a3',
                        IFLASTCHANGE     => '(4099) 0:00:40.99',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10036',
                        IFNAME           => 'FastEthernet0/36',
                        IFDESCR          => 'FastEthernet0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:a4',
                        IFLASTCHANGE     => '(32650) 0:05:26.50',
                        IFINOCTETS       => '542617952',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1581335281',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10037',
                        IFNAME           => 'FastEthernet0/37',
                        IFDESCR          => 'FastEthernet0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:a5',
                        IFLASTCHANGE     => '(4099) 0:00:40.99',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10038',
                        IFNAME           => 'FastEthernet0/38',
                        IFDESCR          => 'FastEthernet0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:a6',
                        IFLASTCHANGE     => '(156293986) 18 days, 2:08:59.86',
                        IFINOCTETS       => '433267145',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2151514332',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10039',
                        IFNAME           => 'FastEthernet0/39',
                        IFDESCR          => 'FastEthernet0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:a7',
                        IFLASTCHANGE     => '(4099) 0:00:40.99',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10040',
                        IFNAME           => 'FastEthernet0/40',
                        IFDESCR          => 'FastEthernet0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:a8',
                        IFLASTCHANGE     => '(4099) 0:00:40.99',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10041',
                        IFNAME           => 'FastEthernet0/41',
                        IFDESCR          => 'FastEthernet0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:a9',
                        IFLASTCHANGE     => '(4100) 0:00:41.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10042',
                        IFNAME           => 'FastEthernet0/42',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:aa',
                        IFLASTCHANGE     => '(4100) 0:00:41.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10043',
                        IFNAME           => 'FastEthernet0/43',
                        IFDESCR          => 'FastEthernet0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:ab',
                        IFLASTCHANGE     => '(4100) 0:00:41.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10044',
                        IFNAME           => 'FastEthernet0/44',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:ac',
                        IFLASTCHANGE     => '(27041) 0:04:30.41',
                        IFINOCTETS       => '15301257',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '987991758',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10045',
                        IFNAME           => 'FastEthernet0/45',
                        IFDESCR          => 'FastEthernet0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:ad',
                        IFLASTCHANGE     => '(4100) 0:00:41.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10046',
                        IFNAME           => 'FastEthernet0/46',
                        IFDESCR          => 'FastEthernet0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:ae',
                        IFLASTCHANGE     => '(156383003) 18 days, 2:23:50.03',
                        IFINOCTETS       => '173968322',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1331270132',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10047',
                        IFNAME           => 'FastEthernet0/47',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:af',
                        IFLASTCHANGE     => '(4100) 0:00:41.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10048',
                        IFNAME           => 'FastEthernet0/48',
                        IFDESCR          => 'FastEthernet0/48',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:b0',
                        IFLASTCHANGE     => '(4100) 0:00:41.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:b1',
                        IFLASTCHANGE     => '(741847) 2:03:38.47',
                        IFINOCTETS       => '2499737889',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3095839272',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'cp-c202-117.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE4, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.117',
                                MODEL    => 'cisco WS-C2960-8TC-S',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet0/2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:ba:6e:b2',
                        IFLASTCHANGE     => '(27649) 0:04:36.49',
                        IFINOCTETS       => '496411095',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '1605672412',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0/1',
                                SYSNAME  => 'CP-Switch-101.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.101',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960.45.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CB-242.example.com',
            MAC          => 'c4:0a:cb:cd:73:00',
            MODEL        => 'Catalyst 2960-48TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CB-242.example.com',
            MAC          => 'c4:0a:cb:cd:73:00',
            MODELSNMP    => 'Networking2416',
            MODEL        => 'Catalyst 2960-48TC',
            FIRMWARE     => undef,
            SERIAL       => undef,
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960-48TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                NAME         => 'CB-242.example.com',
                MEMORY       => '20',
                CPU          => '85',
                RAM          => '60',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:40',
                        IFLASTCHANGE     => '(22766) 0:03:47.66',
                        IFINOCTETS       => '300080287',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '172208712',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'FastEthernet0/1',
                        IFDESCR          => 'FastEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:01',
                        IFLASTCHANGE     => '(139444383) 16 days, 3:20:43.83',
                        IFINOCTETS       => '453610701',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '629265435',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'FastEthernet0/2',
                        IFDESCR          => 'FastEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:02',
                        IFLASTCHANGE     => '(131891494) 15 days, 6:21:54.94',
                        IFINOCTETS       => '100658373',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1671955162',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'FastEthernet0/3',
                        IFDESCR          => 'FastEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:03',
                        IFLASTCHANGE     => '(139325168) 16 days, 3:00:51.68',
                        IFINOCTETS       => '81635731',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '721368132',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'FastEthernet0/4',
                        IFDESCR          => 'FastEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:04',
                        IFLASTCHANGE     => '(78971488) 9 days, 3:21:54.88',
                        IFINOCTETS       => '442614632',
                        IFINERRORS       => '6914',
                        IFOUTOCTETS      => '964540942',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'FastEthernet0/5',
                        IFDESCR          => 'FastEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:05',
                        IFLASTCHANGE     => '(138456745) 16 days, 0:36:07.45',
                        IFINOCTETS       => '6206231',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '196349687',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '12',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'FastEthernet0/6',
                        IFDESCR          => 'FastEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:06',
                        IFLASTCHANGE     => '(4100) 0:00:41.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'FastEthernet0/7',
                        IFDESCR          => 'FastEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:07',
                        IFLASTCHANGE     => '(4100) 0:00:41.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'FastEthernet0/8',
                        IFDESCR          => 'FastEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:08',
                        IFLASTCHANGE     => '(4101) 0:00:41.01',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10009',
                        IFNAME           => 'FastEthernet0/9',
                        IFDESCR          => 'FastEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:09',
                        IFLASTCHANGE     => '(139408772) 16 days, 3:14:47.72',
                        IFINOCTETS       => '48714255',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '477652625',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10010',
                        IFNAME           => 'FastEthernet0/10',
                        IFDESCR          => 'FastEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:0a',
                        IFLASTCHANGE     => '(4101) 0:00:41.01',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10011',
                        IFNAME           => 'FastEthernet0/11',
                        IFDESCR          => 'FastEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:0b',
                        IFLASTCHANGE     => '(4101) 0:00:41.01',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10012',
                        IFNAME           => 'FastEthernet0/12',
                        IFDESCR          => 'FastEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:0c',
                        IFLASTCHANGE     => '(67800) 0:11:18.00',
                        IFINOCTETS       => '44859074',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2064157133',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10013',
                        IFNAME           => 'FastEthernet0/13',
                        IFDESCR          => 'FastEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:0d',
                        IFLASTCHANGE     => '(18714) 0:03:07.14',
                        IFINOCTETS       => '116089383',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '964695197',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10014',
                        IFNAME           => 'FastEthernet0/14',
                        IFDESCR          => 'FastEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:0e',
                        IFLASTCHANGE     => '(139092906) 16 days, 2:22:09.06',
                        IFINOCTETS       => '17508052',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1729384683',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10015',
                        IFNAME           => 'FastEthernet0/15',
                        IFDESCR          => 'FastEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:0f',
                        IFLASTCHANGE     => '(139462818) 16 days, 3:23:48.18',
                        IFINOCTETS       => '3871580',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '168350925',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10016',
                        IFNAME           => 'FastEthernet0/16',
                        IFDESCR          => 'FastEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:10',
                        IFLASTCHANGE     => '(69354) 0:11:33.54',
                        IFINOCTETS       => '218976080',
                        IFINERRORS       => '167',
                        IFOUTOCTETS      => '2576771140',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10017',
                        IFNAME           => 'FastEthernet0/17',
                        IFDESCR          => 'FastEthernet0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:11',
                        IFLASTCHANGE     => '(20313) 0:03:23.13',
                        IFINOCTETS       => '141788121',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1264175906',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10018',
                        IFNAME           => 'FastEthernet0/18',
                        IFDESCR          => 'FastEthernet0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:12',
                        IFLASTCHANGE     => '(7449813) 20:41:38.13',
                        IFINOCTETS       => '16996497',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '92629868',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10019',
                        IFNAME           => 'FastEthernet0/19',
                        IFDESCR          => 'FastEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:13',
                        IFLASTCHANGE     => '(139323602) 16 days, 3:00:36.02',
                        IFINOCTETS       => '105439303',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '607798846',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10020',
                        IFNAME           => 'FastEthernet0/20',
                        IFDESCR          => 'FastEthernet0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:14',
                        IFLASTCHANGE     => '(72188) 0:12:01.88',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1600939431',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10021',
                        IFNAME           => 'FastEthernet0/21',
                        IFDESCR          => 'FastEthernet0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:15',
                        IFLASTCHANGE     => '(139440727) 16 days, 3:20:07.27',
                        IFINOCTETS       => '12315440',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '120816864',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10022',
                        IFNAME           => 'FastEthernet0/22',
                        IFDESCR          => 'FastEthernet0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:16',
                        IFLASTCHANGE     => '(4102) 0:00:41.02',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10023',
                        IFNAME           => 'FastEthernet0/23',
                        IFDESCR          => 'FastEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:17',
                        IFLASTCHANGE     => '(139254244) 16 days, 2:49:02.44',
                        IFINOCTETS       => '85734537',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '265281199',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10024',
                        IFNAME           => 'FastEthernet0/24',
                        IFDESCR          => 'FastEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:18',
                        IFLASTCHANGE     => '(4102) 0:00:41.02',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10025',
                        IFNAME           => 'FastEthernet0/25',
                        IFDESCR          => 'FastEthernet0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:19',
                        IFLASTCHANGE     => '(139666397) 16 days, 3:57:43.97',
                        IFINOCTETS       => '82610105',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '763921883',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10026',
                        IFNAME           => 'FastEthernet0/26',
                        IFDESCR          => 'FastEthernet0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:1a',
                        IFLASTCHANGE     => '(4102) 0:00:41.02',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10027',
                        IFNAME           => 'FastEthernet0/27',
                        IFDESCR          => 'FastEthernet0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:1b',
                        IFLASTCHANGE     => '(139106452) 16 days, 2:24:24.52',
                        IFINOCTETS       => '856010',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '175717781',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10028',
                        IFNAME           => 'FastEthernet0/28',
                        IFDESCR          => 'FastEthernet0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:1c',
                        IFLASTCHANGE     => '(79590) 0:13:15.90',
                        IFINOCTETS       => '312293972',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2541056794',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10029',
                        IFNAME           => 'FastEthernet0/29',
                        IFDESCR          => 'FastEthernet0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:1d',
                        IFLASTCHANGE     => '(130439269) 15 days, 2:19:52.69',
                        IFINOCTETS       => '10798153',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '197359629',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10030',
                        IFNAME           => 'FastEthernet0/30',
                        IFDESCR          => 'FastEthernet0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:1e',
                        IFLASTCHANGE     => '(4102) 0:00:41.02',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10031',
                        IFNAME           => 'FastEthernet0/31',
                        IFDESCR          => 'FastEthernet0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:1f',
                        IFLASTCHANGE     => '(138800437) 16 days, 1:33:24.37',
                        IFINOCTETS       => '617539036',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2442221119',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10032',
                        IFNAME           => 'FastEthernet0/32',
                        IFDESCR          => 'FastEthernet0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:20',
                        IFLASTCHANGE     => '(7474315) 20:45:43.15',
                        IFINOCTETS       => '3197737525',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '359750722',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10033',
                        IFNAME           => 'FastEthernet0/33',
                        IFDESCR          => 'FastEthernet0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:21',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10034',
                        IFNAME           => 'FastEthernet0/34',
                        IFDESCR          => 'FastEthernet0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:22',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10035',
                        IFNAME           => 'FastEthernet0/35',
                        IFDESCR          => 'FastEthernet0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:23',
                        IFLASTCHANGE     => '(130297867) 15 days, 1:56:18.67',
                        IFINOCTETS       => '253432783',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2591364469',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10036',
                        IFNAME           => 'FastEthernet0/36',
                        IFDESCR          => 'FastEthernet0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:24',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10037',
                        IFNAME           => 'FastEthernet0/37',
                        IFDESCR          => 'FastEthernet0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:25',
                        IFLASTCHANGE     => '(114468309) 13 days, 5:58:03.09',
                        IFINOCTETS       => '10237437',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '467768677',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10038',
                        IFNAME           => 'FastEthernet0/38',
                        IFDESCR          => 'FastEthernet0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:26',
                        IFLASTCHANGE     => '(76485) 0:12:44.85',
                        IFINOCTETS       => '3268485606',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1987657403',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10039',
                        IFNAME           => 'FastEthernet0/39',
                        IFDESCR          => 'FastEthernet0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:27',
                        IFLASTCHANGE     => '(136478837) 15 days, 19:06:28.37',
                        IFINOCTETS       => '132713426',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '752647438',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10040',
                        IFNAME           => 'FastEthernet0/40',
                        IFDESCR          => 'FastEthernet0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:28',
                        IFLASTCHANGE     => '(74130) 0:12:21.30',
                        IFINOCTETS       => '280970614',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2308082524',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10041',
                        IFNAME           => 'FastEthernet0/41',
                        IFDESCR          => 'FastEthernet0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:29',
                        IFLASTCHANGE     => '(21973) 0:03:39.73',
                        IFINOCTETS       => '161291696',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2383663130',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10042',
                        IFNAME           => 'FastEthernet0/42',
                        IFDESCR          => 'FastEthernet0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:2a',
                        IFLASTCHANGE     => '(136582137) 15 days, 19:23:41.37',
                        IFINOCTETS       => '17192636',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '415598941',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10043',
                        IFNAME           => 'FastEthernet0/43',
                        IFDESCR          => 'FastEthernet0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:2b',
                        IFLASTCHANGE     => '(4104) 0:00:41.04',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '12',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10044',
                        IFNAME           => 'FastEthernet0/44',
                        IFDESCR          => 'FastEthernet0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:2c',
                        IFLASTCHANGE     => '(4104) 0:00:41.04',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10045',
                        IFNAME           => 'FastEthernet0/45',
                        IFDESCR          => 'FastEthernet0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:2d',
                        IFLASTCHANGE     => '(111862391) 12 days, 22:43:43.91',
                        IFINOCTETS       => '4971345',
                        IFINERRORS       => '4',
                        IFOUTOCTETS      => '115887726',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '55',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10046',
                        IFNAME           => 'FastEthernet0/46',
                        IFDESCR          => 'FastEthernet0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:2e',
                        IFLASTCHANGE     => '(4104) 0:00:41.04',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '49',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10047',
                        IFNAME           => 'FastEthernet0/47',
                        IFDESCR          => 'FastEthernet0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:2f',
                        IFLASTCHANGE     => '(4104) 0:00:41.04',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10048',
                        IFNAME           => 'FastEthernet0/48',
                        IFDESCR          => 'FastEthernet0/48',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:30',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:31',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet0/2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:0a:cb:cd:73:32',
                        IFLASTCHANGE     => '(22765) 0:03:47.65',
                        IFINOCTETS       => '1476778337',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '1630085818',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0/3',
                                SYSNAME  => 'CB-Switch-201.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.201',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960G.1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(50)SE1, RELEASE SOFTWARE (fc2)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Mon 06-Apr-09 08:36 by amvarma',
            MAC          => '00:1a:6c:13:94:00',
            MODEL        => 'Catalyst 2960G-24TC',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(50)SE1, RELEASE SOFTWARE (fc2)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Mon 06-Apr-09 08:36 by amvarma',
            MAC          => '00:1a:6c:13:94:00',
            MODELSNMP    => 'Networking1956',
            MODEL        => 'Catalyst 2960G-24TC',
            FIRMWARE     => undef,
            SERIAL       => 'FOC1047X36T',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960G-24TC',
                COMMENTS     => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(50)SE1, RELEASE SOFTWARE (fc2)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Mon 06-Apr-09 08:36 by amvarma',
                LOCATION     => 'Recherche0-loctecS',
                SERIAL       => 'FOC1047X36T',
                MAC          => '00:1a:6c:13:94:00',
                UPTIME       => '(294615309) 34 days, 2:22:33.09',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:40',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(5258) 0:00:52.58',
                        IFINOCTETS       => '3516',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '615',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:41',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6325) 0:01:03.25',
                        IFINOCTETS       => '2164293856',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '227240568',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'Gi0/1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFALIAS          => 'R01-E003A',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(294508798) 34 days, 2:04:47.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2591710683',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2029296839',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'Gi0/2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFALIAS          => 'R02-E004A',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:02',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5882) 0:00:58.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '363087857',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10103',
                        IFNAME           => 'Gi0/3',
                        IFDESCR          => 'GigabitEthernet0/3',
                        IFALIAS          => 'R03-E006A',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:03',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5980) 0:00:59.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '363087793',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10104',
                        IFNAME           => 'Gi0/4',
                        IFDESCR          => 'GigabitEthernet0/4',
                        IFALIAS          => 'R04-E010A',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:04',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5407) 0:00:54.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10105',
                        IFNAME           => 'Gi0/5',
                        IFDESCR          => 'GigabitEthernet0/5',
                        IFALIAS          => 'R04-E011A-Josiane',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:05',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(278697554) 32 days, 6:09:35.54',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '13345168',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '124712098',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10106',
                        IFNAME           => 'Gi0/6',
                        IFDESCR          => 'GigabitEthernet0/6',
                        IFALIAS          => 'R24-E053A',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:06',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(294503586) 34 days, 2:03:55.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '193160964',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1401545205',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10107',
                        IFNAME           => 'Gi0/7',
                        IFDESCR          => 'GigabitEthernet0/7',
                        IFALIAS          => 'R25-E055A',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:07',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(294309067) 34 days, 1:31:30.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2145547247',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3823107710',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10108',
                        IFNAME           => 'Gi0/8',
                        IFDESCR          => 'GigabitEthernet0/8',
                        IFALIAS          => 'R26-E057A-Arnaud',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:08',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(245563644) 28 days, 10:07:16.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1217534858',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '226122185',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10109',
                        IFNAME           => 'Gi0/9',
                        IFDESCR          => 'GigabitEthernet0/9',
                        IFALIAS          => 'R27-E059A',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:09',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(288828626) 33 days, 10:18:06.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '283390276',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3243848367',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10110',
                        IFNAME           => 'Gi0/10',
                        IFDESCR          => 'GigabitEthernet0/10',
                        IFALIAS          => 'R28-E061A',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:0a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(226125260) 26 days, 4:07:32.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '173766105',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3293395262',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10111',
                        IFNAME           => 'Gi0/11',
                        IFDESCR          => 'GigabitEthernet0/11',
                        IFALIAS          => 'IMP',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:0b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5408) 0:00:54.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10112',
                        IFNAME           => 'Gi0/12',
                        IFDESCR          => 'GigabitEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:0c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5408) 0:00:54.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10113',
                        IFNAME           => 'Gi0/13',
                        IFDESCR          => 'GigabitEthernet0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:0d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(246237477) 28 days, 11:59:34.77',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '6761805',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '54595720',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10114',
                        IFNAME           => 'Gi0/14',
                        IFDESCR          => 'GigabitEthernet0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:0e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5408) 0:00:54.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10115',
                        IFNAME           => 'Gi0/15',
                        IFDESCR          => 'GigabitEthernet0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:0f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(262711736) 30 days, 9:45:17.36',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '957747',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '472801466',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10116',
                        IFNAME           => 'Gi0/16',
                        IFDESCR          => 'GigabitEthernet0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:10',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5408) 0:00:54.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10117',
                        IFNAME           => 'Gi0/17',
                        IFDESCR          => 'GigabitEthernet0/17',
                        IFALIAS          => 'RI_E082A',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:11',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(115532) 0:19:15.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1379913345',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10118',
                        IFNAME           => 'Gi0/18',
                        IFDESCR          => 'GigabitEthernet0/18',
                        IFALIAS          => 'RI_E089A',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:12',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5408) 0:00:54.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10119',
                        IFNAME           => 'Gi0/19',
                        IFDESCR          => 'GigabitEthernet0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:13',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(287449536) 33 days, 6:28:15.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '154006443',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '341806349',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10120',
                        IFNAME           => 'Gi0/20',
                        IFDESCR          => 'GigabitEthernet0/20',
                        IFALIAS          => 'icdrrc221.ens-lsh.fr',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:14',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5408) 0:00:54.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10121',
                        IFNAME           => 'Gi0/21',
                        IFDESCR          => 'GigabitEthernet0/21',
                        IFALIAS          => 'C4503-01L2-004',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:15',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6175) 0:01:01.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4068735084',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3077962672',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1b:21:2c:75:79',
                                    '00:1b:21:2c:75:7d',
                                    '00:1b:21:2c:76:65',
                                    '00:1b:21:2c:76:61',
                                    '00:1e:7a:f5:0a:06',
                                    'c4:64:13:11:31:81',
                                    'c4:64:13:11:31:60',
                                    'c4:64:13:2b:f2:25',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10122',
                        IFNAME           => 'Gi0/22',
                        IFDESCR          => 'GigabitEthernet0/22',
                        IFALIAS          => 'margaritas',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:16',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5408) 0:00:54.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10123',
                        IFNAME           => 'Gi0/23',
                        IFDESCR          => 'GigabitEthernet0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:17',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5408) 0:00:54.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10124',
                        IFNAME           => 'Gi0/24',
                        IFDESCR          => 'GigabitEthernet0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '00:1a:6c:13:94:18',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5408) 0:00:54.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10501',
                        IFNAME           => 'Nu0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C2960S.1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 03:03 by prod_rel_team',
            SNMPHOSTNAME => 'SALSERV-INTERUFR-149.example.com',
            MAC          => '18:33:9d:e7:15:00',
            MODEL        => 'Catalyst 2960S Software',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 03:03 by prod_rel_team',
            SNMPHOSTNAME => 'SALSERV-INTERUFR-149.example.com',
            MAC          => '18:33:9d:e7:15:00',
            MODELSNMP    => 'Networking2147',
            MODEL        => 'Catalyst 2960S Software',
            FIRMWARE     => undef,
            SERIAL       => 'FOC1622Y2ME',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960S Software',
                COMMENTS     => 'Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 03:03 by prod_rel_team',
                NAME         => 'SALSERV-INTERUFR-149.example.com',
                MEMORY       => '34',
                SERIAL       => 'FOC1622Y2ME',
                FIRMWARE     => '12.2(58)SE1',
                MAC          => '18:33:9d:e7:15:00',
                CPU          => '73',
                RAM          => '128',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:40',
                        IFLASTCHANGE     => '(10244) 0:01:42.44',
                        IFINOCTETS       => '398583684',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5137',
                        IFDESCR          => 'StackPort1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '0',
                        IFLASTCHANGE     => '(9407) 0:01:34.07',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5138',
                        IFDESCR          => 'StackSub-St1-1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                    {
                        IFNUMBER         => '5139',
                        IFDESCR          => 'StackSub-St1-2',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFDESCR          => 'GigabitEthernet1/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:01',
                        IFLASTCHANGE     => '(1104746783) 127 days, 20:44:27.83',
                        IFINOCTETS       => '3721685913',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2392162814',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'e4:11:5b:b0:2a:04',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10102',
                        IFDESCR          => 'GigabitEthernet1/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:02',
                        IFLASTCHANGE     => '(1104746787) 127 days, 20:44:27.87',
                        IFINOCTETS       => '3748004083',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2397581446',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'e4:11:5b:b0:2a:02',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10103',
                        IFDESCR          => 'GigabitEthernet1/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:03',
                        IFLASTCHANGE     => '(1104746779) 127 days, 20:44:27.79',
                        IFINOCTETS       => '3523074278',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2393229184',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'e4:11:5b:b0:2a:00',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10104',
                        IFDESCR          => 'GigabitEthernet1/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:04',
                        IFLASTCHANGE     => '(1104746771) 127 days, 20:44:27.71',
                        IFINOCTETS       => '23396375',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2306109186',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'e4:11:5b:b0:29:fe',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10105',
                        IFDESCR          => 'GigabitEthernet1/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:05',
                        IFLASTCHANGE     => '(373533695) 43 days, 5:35:36.95',
                        IFINOCTETS       => '522870153',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2983152425',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10106',
                        IFDESCR          => 'GigabitEthernet1/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:06',
                        IFLASTCHANGE     => '(380945737) 44 days, 2:10:57.37',
                        IFINOCTETS       => '536122690',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '788830719',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10107',
                        IFDESCR          => 'GigabitEthernet1/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:07',
                        IFLASTCHANGE     => '(373780695) 43 days, 6:16:46.95',
                        IFINOCTETS       => '506922626',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '872891421',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10108',
                        IFDESCR          => 'GigabitEthernet1/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:08',
                        IFLASTCHANGE     => '(1055146030) 122 days, 2:57:40.30',
                        IFINOCTETS       => '771500355',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3183168193',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:25:b3:aa:d6:b6',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10109',
                        IFDESCR          => 'GigabitEthernet1/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:09',
                        IFLASTCHANGE     => '(1081986747) 125 days, 5:31:07.47',
                        IFINOCTETS       => '3891929713',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2400347595',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'b4:99:ba:c0:eb:aa',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10110',
                        IFDESCR          => 'GigabitEthernet1/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:0a',
                        IFLASTCHANGE     => '(1081986740) 125 days, 5:31:07.40',
                        IFINOCTETS       => '3952228784',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1919933645',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'b4:99:ba:c0:eb:a4',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10111',
                        IFDESCR          => 'GigabitEthernet1/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:0b',
                        IFLASTCHANGE     => '(1081986791) 125 days, 5:31:07.91',
                        IFINOCTETS       => '7357088',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2403692200',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'b4:99:ba:c0:eb:a8',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10112',
                        IFDESCR          => 'GigabitEthernet1/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:0c',
                        IFLASTCHANGE     => '(1081986735) 125 days, 5:31:07.35',
                        IFINOCTETS       => '15273278',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2411515445',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'b4:99:ba:c0:eb:a6',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10113',
                        IFDESCR          => 'GigabitEthernet1/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:0d',
                        IFLASTCHANGE     => '(1080518701) 125 days, 1:26:27.01',
                        IFINOCTETS       => '256594457',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2398571120',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '78:e3:b5:12:97:da',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10114',
                        IFDESCR          => 'GigabitEthernet1/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:0e',
                        IFLASTCHANGE     => '(1080518705) 125 days, 1:26:27.05',
                        IFINOCTETS       => '1092127028',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2387872550',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '78:e3:b5:12:a7:08',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10115',
                        IFDESCR          => 'GigabitEthernet1/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:0f',
                        IFLASTCHANGE     => '(1080518709) 125 days, 1:26:27.09',
                        IFINOCTETS       => '162643760',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4044110657',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '78:e3:b5:12:97:d8',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10116',
                        IFDESCR          => 'GigabitEthernet1/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:10',
                        IFLASTCHANGE     => '(1080518709) 125 days, 1:26:27.09',
                        IFINOCTETS       => '178724675',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2368363908',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '78:e3:b5:12:a7:0a',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10117',
                        IFDESCR          => 'GigabitEthernet1/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:11',
                        IFLASTCHANGE     => '(1045238489) 120 days, 23:26:24.89',
                        IFINOCTETS       => '3269925864',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3705223239',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:24:81:a5:ad:82',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10118',
                        IFDESCR          => 'GigabitEthernet1/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:12',
                        IFLASTCHANGE     => '(1045136906) 120 days, 23:09:29.06',
                        IFINOCTETS       => '4294631',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2364252031',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:24:81:a5:8c:9a',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10119',
                        IFDESCR          => 'GigabitEthernet1/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:13',
                        IFLASTCHANGE     => '(1045238529) 120 days, 23:26:25.29',
                        IFINOCTETS       => '2967336894',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2335181126',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:24:81:a5:ad:84',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10120',
                        IFDESCR          => 'GigabitEthernet1/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:14',
                        IFLASTCHANGE     => '(1045136858) 120 days, 23:09:28.58',
                        IFINOCTETS       => '423040005',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '585549480',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:24:81:a5:8c:99',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10121',
                        IFDESCR          => 'GigabitEthernet1/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:15',
                        IFLASTCHANGE     => '(1045135806) 120 days, 23:09:18.06',
                        IFINOCTETS       => '3589075783',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2388067209',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:15:60:a8:c8:a5',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10122',
                        IFDESCR          => 'GigabitEthernet1/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:16',
                        IFLASTCHANGE     => '(1045084012) 120 days, 23:00:40.12',
                        IFINOCTETS       => '2959412562',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '203015691',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:15:60:a8:9a:32',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10123',
                        IFDESCR          => 'GigabitEthernet1/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:17',
                        IFLASTCHANGE     => '(1045135682) 120 days, 23:09:16.82',
                        IFINOCTETS       => '3737853875',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '3740651309',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:15:60:a8:c8:a6',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10124',
                        IFDESCR          => 'GigabitEthernet1/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:18',
                        IFLASTCHANGE     => '(1045084138) 120 days, 23:00:41.38',
                        IFINOCTETS       => '2365558700',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2337013749',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:15:60:a8:9a:31',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10125',
                        IFDESCR          => 'GigabitEthernet1/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:19',
                        IFLASTCHANGE     => '(9409) 0:01:34.09',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10126',
                        IFDESCR          => 'GigabitEthernet1/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:1a',
                        IFLASTCHANGE     => '(1148414732) 132 days, 22:02:27.32',
                        IFINOCTETS       => '381223375',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3173019806',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:01:02:bf:f6:1f',
                                    '00:0a:5e:5f:54:86',
                                    '00:0a:5e:5f:54:ae',
                                    '00:0a:5e:5f:55:67',
                                    '00:0a:5e:5f:55:6a',
                                    '00:0a:5e:5f:55:ab',
                                    '00:0a:5e:5f:55:17',
                                    '00:10:5a:1b:c5:be',
                                    '00:10:5a:09:8f:2a',
                                    '00:d0:b7:45:80:30',
                                    '00:18:f3:f0:0c:0e',
                                    '00:19:d1:82:ab:f6',
                                    '00:1b:2f:b3:c0:d5',
                                    '00:1c:c0:bd:d2:82',
                                    '00:1c:c0:bd:d6:f1',
                                    '00:1c:c0:bd:d7:6d',
                                    '00:1c:c0:bd:d7:79',
                                    '00:1c:c0:bd:d7:a2',
                                    '00:1c:c0:bd:d7:54',
                                    '00:1c:c0:bd:d8:e0',
                                    '00:1c:c0:bd:d9:1b',
                                    '00:1c:c0:bd:d9:3f',
                                    '00:1c:c0:dc:69:8f',
                                    '00:1c:c0:dc:69:92',
                                    '00:1c:c0:dc:69:23',
                                    '00:1c:c0:dc:6a:4f',
                                    '00:1c:c0:dc:6b:a0',
                                    '00:1c:c0:dc:6b:fa',
                                    '00:1c:c0:dc:6d:47',
                                    '00:1c:c0:dc:7a:b3',
                                    '00:1c:c0:dc:7a:ea',
                                    '00:1c:c0:dc:7b:17',
                                    '00:1c:c0:dc:7d:7f',
                                    '00:1c:c0:df:37:09',
                                    '00:1c:c0:df:39:b2',
                                    '00:1c:c0:df:39:c2',
                                    '00:1c:c0:df:39:ee',
                                    '00:1c:c0:df:39:ef',
                                    '00:1c:c0:df:39:f6',
                                    '00:1c:c0:df:3a:88',
                                    '00:1c:c0:df:3a:8a',
                                    '00:1c:c0:df:3a:8b',
                                    '00:1c:c0:df:3a:1f',
                                    '00:1c:c0:df:3a:55',
                                    '00:1c:c0:df:3a:5a',
                                    '00:03:22:01:9b:19',
                                    '00:27:0e:1e:b4:64',
                                    '00:27:0e:1e:b4:6d',
                                    '00:27:0e:1e:b4:72',
                                    '00:27:0e:1e:b4:73',
                                    '00:27:0e:1e:b4:7d',
                                    '00:27:0e:1e:b4:82',
                                    '00:27:0e:1e:b4:d1',
                                    '00:27:0e:1e:b4:de',
                                    '00:27:0e:1e:b4:52',
                                    '00:27:0e:1e:b4:57',
                                    '00:27:0e:1e:b4:5c',
                                    '00:27:0e:2d:f8:64',
                                    '00:27:0e:2d:f9:60',
                                    '00:40:0d:8a:8b:47',
                                    '00:50:da:d8:4e:47',
                                    '00:50:04:82:ce:89',
                                    '00:50:04:50:54:e8',
                                    '00:60:08:64:12:81',
                                    '00:60:08:64:15:f0',
                                    '00:60:08:64:16:8d',
                                    '00:60:08:64:16:05',
                                    '00:60:08:64:16:3f',
                                    '00:60:08:64:23:dd',
                                    '00:60:08:64:23:e5',
                                    '00:60:08:72:78:cb',
                                    '00:60:08:78:4c:52',
                                    '00:60:08:9f:35:75',
                                    '00:60:08:9f:35:83',
                                    '00:60:08:63:fa:63',
                                    '78:e7:d1:a9:3c:2b',
                                    '78:fe:3d:d5:0e:db',
                                    'c8:9c:dc:f3:e7:71',
                                    'c8:9c:dc:f4:eb:b0',
                                    'f8:0f:41:2c:43:7f',
                                    'f8:0f:41:36:13:75',
                                    'f8:0f:41:36:46:93',
                                    'f8:0f:41:36:47:a9',
                                    'f8:0f:41:36:47:e6',
                                    'f8:0f:41:36:47:eb',
                                    'f8:0f:41:36:48:18',
                                    'f8:0f:41:36:49:6b',
                                    'f8:0f:41:36:49:72',
                                    'f8:0f:41:3b:13:6f',
                                    'f8:0f:41:3d:38:66',
                                    'f8:0f:41:3d:38:a0',
                                    'f8:0f:41:3d:38:d7',
                                    'f8:0f:41:3d:38:da',
                                    'f8:0f:41:3d:38:26',
                                    'f8:0f:41:3d:39:85',
                                    'f8:0f:41:3d:39:30',
                                    'f8:0f:41:3d:39:35',
                                    'f8:0f:41:3d:43:64',
                                    'f8:0f:41:3d:43:66',
                                    'f8:0f:41:3d:43:69',
                                    'f8:0f:41:3d:43:8b',
                                    'f8:0f:41:3d:47:00',
                                    'f8:0f:41:3d:48:95',
                                    'f8:0f:41:3d:48:c4',
                                    'f8:0f:41:3d:48:ca',
                                    'f8:0f:41:3d:48:59',
                                    'f8:0f:41:3e:0a:c9',
                                    'f8:0f:41:3e:0a:29',
                                    'f8:0f:41:3e:0b:a8',
                                    'f8:0f:41:3e:0b:c5',
                                    'f8:0f:41:3e:0b:d2',
                                    'f8:0f:41:3e:0c:bd',
                                    'f8:0f:41:3e:0c:4e',
                                    'f8:0f:41:3e:07:37',
                                    'f8:0f:41:3e:09:e6',
                                    'f8:0f:41:3e:09:2e',
                                    '20:cf:30:f0:82:d8',
                                    '20:cf:30:f0:82:e6',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10201',
                        IFDESCR          => 'TenGigabitEthernet1/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:1b',
                        IFLASTCHANGE     => '(12761) 0:02:07.61',
                        IFINOCTETS       => '2403147337',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '861764751',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'TenGigabitEthernet1/0/1',
                                SYSNAME  => 'SALSERV-INTERUFR-150.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.150',
                                MODEL    => 'cisco WS-C2960S-24TD-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10202',
                        IFDESCR          => 'TenGigabitEthernet1/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:1c',
                        IFLASTCHANGE     => '(11779) 0:01:57.79',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                },
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '12001',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12002',
                        IFDESCR          => 'FastEthernet0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '18:33:9d:e7:15:39',
                        IFLASTCHANGE     => '(11520) 0:01:55.20',
                        IFINOCTETS       => '1978888964',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1282126124',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet1/0/3',
                                SYSNAME  => 'SALSERV-160.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.160',
                                MODEL    => 'cisco WS-C2960S-24TD-L',
                            }
                        }
                    },
                ]
            },
        }
    ],
    'cisco/C2960S.2.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 03:03 by prod_rel_team',
            SNMPHOSTNAME => 'CB-C005-202.example.com',
            MAC          => 'b4:14:89:38:2d:80',
            MODEL        => 'Catalyst 2960S Software',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 03:03 by prod_rel_team',
            SNMPHOSTNAME => 'CB-C005-202.example.com',
            MAC          => 'b4:14:89:38:2d:80',
            MODELSNMP    => 'Networking2147',
            MODEL        => 'Catalyst 2960S Software',
            FIRMWARE     => undef,
            SERIAL       => 'FOC1440Z0HG',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960S Software',
                COMMENTS     => 'Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 03:03 by prod_rel_team',
                NAME         => 'CB-C005-202.example.com',
                MEMORY       => '33',
                SERIAL       => 'FOC1440Z0HG',
                FIRMWARE     => '12.2(58)SE1',
                IPS          => {
                    IP => [
                        '192.168.1.202',
                    ],
                },
                MAC          => 'b4:14:89:38:2d:80',
                UPTIME       => '(1038728684) 120 days, 5:21:26.84',
                CPU          => '75',
                RAM          => '128',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vl1',
                        IFDESCR          => 'Vlan1',
                        IFALIAS          => 'MNGT',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.1.202',
                        MAC              => 'b4:14:89:38:2d:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17290) 0:02:52.90',
                        IFINOCTETS       => '1809150271',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1363105400',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5137',
                        IFNAME           => 'StackPort1',
                        IFDESCR          => 'StackPort1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(16110) 0:02:41.10',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5138',
                        IFNAME           => 'StackSub-St1-1',
                        IFDESCR          => 'StackSub-St1-1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                    {
                        IFNUMBER         => '5139',
                        IFNAME           => 'StackSub-St1-2',
                        IFDESCR          => 'StackSub-St1-2',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'Gi1/0/1',
                        IFDESCR          => 'GigabitEthernet1/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:81',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(16998) 0:02:49.98',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'Gi1/0/2',
                        IFDESCR          => 'GigabitEthernet1/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:82',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10103',
                        IFNAME           => 'Gi1/0/3',
                        IFDESCR          => 'GigabitEthernet1/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:83',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10104',
                        IFNAME           => 'Gi1/0/4',
                        IFDESCR          => 'GigabitEthernet1/0/4',
                        IFALIAS          => 'sport-F04',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:84',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan25',
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10105',
                        IFNAME           => 'Gi1/0/5',
                        IFDESCR          => 'GigabitEthernet1/0/5',
                        IFALIAS          => 'sport-F06',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:85',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan25',
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10106',
                        IFNAME           => 'Gi1/0/6',
                        IFDESCR          => 'GigabitEthernet1/0/6',
                        IFALIAS          => 'sport-F07',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:86',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan25',
                                    NUMBER => '30',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10107',
                        IFNAME           => 'Gi1/0/7',
                        IFDESCR          => 'GigabitEthernet1/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan50',
                                    NUMBER => '55',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10108',
                        IFNAME           => 'Gi1/0/8',
                        IFDESCR          => 'GigabitEthernet1/0/8',
                        IFALIAS          => 'C012-D16 securite',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1035006831) 119 days, 19:01:08.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2000020446',
                        IFINERRORS       => '7',
                        IFOUTOCTETS      => '3785939163',
                        IFOUTERRORS      => '10196',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10109',
                        IFNAME           => 'Gi1/0/9',
                        IFDESCR          => 'GigabitEthernet1/0/9',
                        IFALIAS          => 'C012-D17 securite',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:89',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10110',
                        IFNAME           => 'Gi1/0/10',
                        IFDESCR          => 'GigabitEthernet1/0/10',
                        IFALIAS          => 'C012-D18 securite',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10111',
                        IFNAME           => 'Gi1/0/11',
                        IFDESCR          => 'GigabitEthernet1/0/11',
                        IFALIAS          => 'C006-C13 alumni imp',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:8b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17000) 0:02:50.00',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan50',
                                    NUMBER => '55',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10112',
                        IFNAME           => 'Gi1/0/12',
                        IFDESCR          => 'GigabitEthernet1/0/12',
                        IFALIAS          => 'C006-C10 alumni',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:8c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17000) 0:02:50.00',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10113',
                        IFNAME           => 'Gi1/0/13',
                        IFDESCR          => 'GigabitEthernet1/0/13',
                        IFALIAS          => 'C008-C19 alumni',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:8d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17000) 0:02:50.00',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10114',
                        IFNAME           => 'Gi1/0/14',
                        IFDESCR          => 'GigabitEthernet1/0/14',
                        IFALIAS          => 'C008-C20 alumni',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:8e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17000) 0:02:50.00',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10115',
                        IFNAME           => 'Gi1/0/15',
                        IFDESCR          => 'GigabitEthernet1/0/15',
                        IFALIAS          => 'C010-C23 alumni',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:8f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17000) 0:02:50.00',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10116',
                        IFNAME           => 'Gi1/0/16',
                        IFDESCR          => 'GigabitEthernet1/0/16',
                        IFALIAS          => 'C010-D09 alumni',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17000) 0:02:50.00',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10117',
                        IFNAME           => 'Gi1/0/17',
                        IFDESCR          => 'GigabitEthernet1/0/17',
                        IFALIAS          => 'wifi-espaceOne-205 prise C005#H15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:91',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(412923121) 47 days, 19:00:31.21',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '1875470774',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '616408260',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10118',
                        IFNAME           => 'Gi1/0/18',
                        IFDESCR          => 'GigabitEthernet1/0/18',
                        IFALIAS          => 'wifi-55.xxx',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:92',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17000) 0:02:50.00',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10119',
                        IFNAME           => 'Gi1/0/19',
                        IFDESCR          => 'GigabitEthernet1/0/19',
                        IFALIAS          => 'VERS CB-C005-127 192.168.1.127 !',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:93',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17347) 0:02:53.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '239963405',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '481681887',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0',
                                SYSNAME  => 'wifi-P416-47.wifi-mngt.dauphine.fr',
                                SYSDESCR => '"Cisco IOS Software, C1140 Software (C1140-K9W7-M), Version 12.4(21a)JA1, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.55.47',
                                MODEL    => 'cisco AIR-AP1142N-E-K9    ',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10120',
                        IFNAME           => 'Gi1/0/20',
                        IFDESCR          => 'GigabitEthernet1/0/20',
                        IFALIAS          => 'VERS C005-P053-232a 192.168.1.232 ! ',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:94',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17348) 0:02:53.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '456792940',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2470821375',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '64:87:88:b0:39:c1',
                                    '64:87:88:b0:3a:81',
                                    '64:87:88:b0:44:81',
                                    'e8:e7:32:4b:7b:b4',
                                    'e8:e7:32:4b:86:db',
                                    'e8:e7:32:4b:8a:cc',
                                    'e8:e7:32:4b:9b:d8',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10121',
                        IFNAME           => 'Gi1/0/21',
                        IFDESCR          => 'GigabitEthernet1/0/21',
                        IFALIAS          => 'VERS CB-C005-207 192.168.1.207 !',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:95',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17651) 0:02:56.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '344390677',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2696731730',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CB-C005-207.Dauphine',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.207',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10122',
                        IFNAME           => 'Gi1/0/22',
                        IFDESCR          => 'GigabitEthernet1/0/22',
                        IFALIAS          => 'VERS CB-C005-206 192.168.1.206 !',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:96',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17348) 0:02:53.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3638606372',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2995779946',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CB-C005-206.Dauphine',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.206',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10123',
                        IFNAME           => 'Gi1/0/23',
                        IFDESCR          => 'GigabitEthernet1/0/23',
                        IFALIAS          => 'VERS CB-C005-208 192.168.1.208 !',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:97',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17348) 0:02:53.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1930398362',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2602167926',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CB-C005-208.Dauphine',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.208',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10124',
                        IFNAME           => 'Gi1/0/24',
                        IFDESCR          => 'GigabitEthernet1/0/24',
                        IFALIAS          => 'VERS CB-C005-205 192.168.1.205 !',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:98',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17348) 0:02:53.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1156483157',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1997977582',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CB-C005-205.Dauphine',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.205',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10125',
                        IFNAME           => 'Gi1/0/25',
                        IFDESCR          => 'GigabitEthernet1/0/25',
                        IFALIAS          => 'uplink-CB-DIVERS-217',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:99',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(18797) 0:03:07.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1598430128',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4219364696',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CB-DIVERS-217.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.217',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10126',
                        IFNAME           => 'Gi1/0/26',
                        IFDESCR          => 'GigabitEthernet1/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(16113) 0:02:41.13',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10201',
                        IFNAME           => 'Te1/0/1',
                        IFDESCR          => 'TenGigabitEthernet1/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:9b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(18496) 0:03:04.96',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10202',
                        IFNAME           => 'Te1/0/2',
                        IFDESCR          => 'TenGigabitEthernet1/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:9c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17001) 0:02:50.01',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '12001',
                        IFNAME           => 'Nu0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12002',
                        IFNAME           => 'Fa0',
                        IFDESCR          => 'FastEthernet0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => 'b4:14:89:38:2d:b9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(16930) 0:02:49.30',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C3550.1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco Internetwork Operating System Software 
IOS (tm) C3550 Software (C3550-I5Q3L2-M), Version 12.1(20)EA1a, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2004 by cisco Systems, Inc.
Compiled Mon 19-Apr-04 21:50 by yenanh',
            SNMPHOSTNAME => 'CB-Federateur.example.com',
            MAC          => '00:0b:5f:cc:d8:80',
            MODEL        => 'Catalyst 3550-12G',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco Internetwork Operating System Software 
IOS (tm) C3550 Software (C3550-I5Q3L2-M), Version 12.1(20)EA1a, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2004 by cisco Systems, Inc.
Compiled Mon 19-Apr-04 21:50 by yenanh',
            SNMPHOSTNAME => 'CB-Federateur.example.com',
            MAC          => '00:0b:5f:cc:d8:80',
            MODELSNMP    => 'Networking2034',
            MODEL        => 'Catalyst 3550-12G',
            FIRMWARE     => undef,
            SERIAL       => 'CAT0647X118',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 3550-12G',
                COMMENTS     => 'Cisco Internetwork Operating System Software 
IOS (tm) C3550 Software (C3550-I5Q3L2-M), Version 12.1(20)EA1a, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2004 by cisco Systems, Inc.
Compiled Mon 19-Apr-04 21:50 by yenanh',
                NAME         => 'CB-Federateur.example.com',
                MEMORY       => '42',
                SERIAL       => 'CAT0647X118',
                FIRMWARE     => 'CW_VERSION$12.1(20)EA1a$',
                CPU          => '97',
                RAM          => '63',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:81',
                        IFLASTCHANGE     => '(484116314) 56 days, 0:46:03.14',
                        IFINOCTETS       => '180537907',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1011556546',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CB-Switch-201.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.201',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:82',
                        IFLASTCHANGE     => '(2549311166) 295 days, 1:25:11.66',
                        IFINOCTETS       => '3867512040',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '290573111',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '3',
                        IFDESCR          => 'GigabitEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:83',
                        IFLASTCHANGE     => '(3567778147) 412 days, 22:29:41.47',
                        IFINOCTETS       => '4201293261',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '943956504',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'AP-Switch-51.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.51',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '4',
                        IFDESCR          => 'GigabitEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:84',
                        IFLASTCHANGE     => '(3092449227) 357 days, 22:08:12.27',
                        IFINOCTETS       => '3886274843',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3120044741',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CP-Switch-101.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.101',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '5',
                        IFDESCR          => 'GigabitEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:85',
                        IFLASTCHANGE     => '(2512038666) 290 days, 17:53:06.66',
                        IFINOCTETS       => '2830133767',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4249428806',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/2',
                                SYSNAME  => 'CB6-BU-221.example.com',
                                SYSDESCR => '"Cisco IOS Software, C3560 Software (C3560-IPBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.221',
                                MODEL    => 'cisco WS-C3560-24PS',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '6',
                        IFDESCR          => 'GigabitEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:86',
                        IFLASTCHANGE     => '(2156630557) 249 days, 14:38:25.57',
                        IFINOCTETS       => '1115997810',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1893127079',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CB-C125-218.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.218',
                                MODEL    => 'cisco WS-C2960-24TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '7',
                        IFDESCR          => 'GigabitEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:87',
                        IFLASTCHANGE     => '(2549322052) 295 days, 1:27:00.52',
                        IFINOCTETS       => '3445477068',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '574739419',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet1/0/25',
                                SYSNAME  => 'SALSERV-160.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.160',
                                MODEL    => 'cisco WS-C2960S-24TD-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '8',
                        IFDESCR          => 'GigabitEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:88',
                        IFLASTCHANGE     => '(2549310972) 295 days, 1:25:09.72',
                        IFINOCTETS       => '2984968729',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '561349813',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/2',
                                SYSNAME  => 'SALSERV-152.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(25)SEE2, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.152',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '9',
                        IFDESCR          => 'GigabitEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:89',
                        IFLASTCHANGE     => '(3568000911) 412 days, 23:06:49.11',
                        IFINOCTETS       => '588728158',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1525029225',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'AB-Switch-1.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.1',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10',
                        IFDESCR          => 'GigabitEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:8a',
                        IFLASTCHANGE     => '(2392354398) 276 days, 21:25:43.98',
                        IFINOCTETS       => '98138483',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2340502692',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '11',
                        IFDESCR          => 'GigabitEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:8b',
                        IFLASTCHANGE     => '(4164697427) 482 days, 0:36:14.27',
                        IFINOCTETS       => '4141947452',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4106000860',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '12',
                        IFDESCR          => 'GigabitEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:8c',
                        IFLASTCHANGE     => '(476695464) 55 days, 4:09:14.64',
                        IFINOCTETS       => '1426737530',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1037515211',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CB-27.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.27',
                                MODEL    => 'cisco WS-C2960-24TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '13',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '14',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9438) 0:01:34.38',
                        IFINOCTETS       => '1525083978',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3784751394',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '15',
                        IFDESCR          => 'Vlan2',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9438) 0:01:34.38',
                        IFINOCTETS       => '2925658248',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '921408266',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '16',
                        IFDESCR          => 'Vlan3',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(2359259786) 273 days, 1:29:57.86',
                        IFINOCTETS       => '308107072',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3275196',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '17',
                        IFDESCR          => 'Vlan4',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9438) 0:01:34.38',
                        IFINOCTETS       => '1300929099',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '461030167',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '18',
                        IFDESCR          => 'Vlan5',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9440) 0:01:34.40',
                        IFINOCTETS       => '3666146863',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '293335971',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '19',
                        IFDESCR          => 'Vlan6',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9440) 0:01:34.40',
                        IFINOCTETS       => '731125063',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '727637538',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '20',
                        IFDESCR          => 'Vlan7',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9440) 0:01:34.40',
                        IFINOCTETS       => '3589275562',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '21',
                        IFDESCR          => 'Vlan8',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9440) 0:01:34.40',
                        IFINOCTETS       => '1996045557',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '201358471',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '22',
                        IFDESCR          => 'Vlan9',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(906522342) 104 days, 22:07:03.42',
                        IFINOCTETS       => '24800747',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '69531603',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '23',
                        IFDESCR          => 'Vlan10',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9445) 0:01:34.45',
                        IFINOCTETS       => '969764756',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '505094134',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '24',
                        IFDESCR          => 'Vlan11',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9445) 0:01:34.45',
                        IFINOCTETS       => '912202175',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '406405478',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '25',
                        IFDESCR          => 'Vlan12',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9445) 0:01:34.45',
                        IFINOCTETS       => '18107654',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '22156322',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '26',
                        IFDESCR          => 'Vlan13',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9445) 0:01:34.45',
                        IFINOCTETS       => '2935779928',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '554925716',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '27',
                        IFDESCR          => 'Vlan14',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9445) 0:01:34.45',
                        IFINOCTETS       => '1262482289',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '156743587',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '28',
                        IFDESCR          => 'Vlan15',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9445) 0:01:34.45',
                        IFINOCTETS       => '285431783',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '204443724',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '29',
                        IFDESCR          => 'Vlan16',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9445) 0:01:34.45',
                        IFINOCTETS       => '3270804562',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '151588827',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '30',
                        IFDESCR          => 'Vlan17',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9446) 0:01:34.46',
                        IFINOCTETS       => '2697229546',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1552869729',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '31',
                        IFDESCR          => 'Vlan18',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9446) 0:01:34.46',
                        IFINOCTETS       => '714313794',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '315908357',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '32',
                        IFDESCR          => 'Vlan19',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9446) 0:01:34.46',
                        IFINOCTETS       => '2789987500',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '82700994',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '33',
                        IFDESCR          => 'Vlan20',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(6726) 0:01:07.26',
                        IFINOCTETS       => '3486144',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '34',
                        IFDESCR          => 'Vlan21',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(837346286) 96 days, 21:57:42.86',
                        IFINOCTETS       => '2343680',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '17687616',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '35',
                        IFDESCR          => 'Vlan22',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9446) 0:01:34.46',
                        IFINOCTETS       => '1844712773',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1164425501',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '36',
                        IFDESCR          => 'Vlan23',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9446) 0:01:34.46',
                        IFINOCTETS       => '1283464573',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '346380743',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '37',
                        IFDESCR          => 'Vlan24',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9446) 0:01:34.46',
                        IFINOCTETS       => '26920726',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '36318863',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '38',
                        IFDESCR          => 'Vlan25',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9446) 0:01:34.46',
                        IFINOCTETS       => '3064833469',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1918653057',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '39',
                        IFDESCR          => 'Vlan26',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '338752885',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '448530768',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '40',
                        IFDESCR          => 'Vlan27',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '2992067052',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '109842849',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '41',
                        IFDESCR          => 'Vlan28',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '2439400107',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '953579070',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '42',
                        IFDESCR          => 'Vlan29',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '2687627494',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '85231534',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '43',
                        IFDESCR          => 'Vlan30',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '812488624',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1354851503',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '44',
                        IFDESCR          => 'Vlan31',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '72258689',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '211309587',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '45',
                        IFDESCR          => 'Vlan32',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '397017901',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2116392197',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '46',
                        IFDESCR          => 'Vlan33',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '1418291283',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '48133885',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '47',
                        IFDESCR          => 'Vlan34',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9449) 0:01:34.49',
                        IFINOCTETS       => '994774647',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '159813169',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '48',
                        IFDESCR          => 'Vlan35',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9449) 0:01:34.49',
                        IFINOCTETS       => '444116144',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '343719204',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '49',
                        IFDESCR          => 'Vlan36',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9449) 0:01:34.49',
                        IFINOCTETS       => '26090918',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '26386466',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '50',
                        IFDESCR          => 'Vlan37',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9449) 0:01:34.49',
                        IFINOCTETS       => '1159745060',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '635832012',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '51',
                        IFDESCR          => 'Vlan38',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9449) 0:01:34.49',
                        IFINOCTETS       => '1012869239',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1105831805',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '52',
                        IFDESCR          => 'Vlan39',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9456) 0:01:34.56',
                        IFINOCTETS       => '483228390',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1086401212',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '53',
                        IFDESCR          => 'Vlan40',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9456) 0:01:34.56',
                        IFINOCTETS       => '1372343872',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '54',
                        IFDESCR          => 'Vlan41',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9456) 0:01:34.56',
                        IFINOCTETS       => '53271806',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '55',
                        IFDESCR          => 'Vlan42',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9456) 0:01:34.56',
                        IFINOCTETS       => '3788625476',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '788748238',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '56',
                        IFDESCR          => 'Vlan43',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(12414) 0:02:04.14',
                        IFINOCTETS       => '175265926',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '12227352',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '57',
                        IFDESCR          => 'Vlan44',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(6809) 0:01:08.09',
                        IFINOCTETS       => '84633088',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '58',
                        IFDESCR          => 'Vlan45',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9456) 0:01:34.56',
                        IFINOCTETS       => '13189',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '14842536',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '59',
                        IFDESCR          => 'Vlan46',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '629694788',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '551119289',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '60',
                        IFDESCR          => 'Vlan47',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '169895626',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '12975579',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '61',
                        IFDESCR          => 'Vlan48',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '23318539',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '35099834',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '62',
                        IFDESCR          => 'Vlan49',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '3910338505',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '717521964',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '64',
                        IFDESCR          => 'Vlan51',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '2179932368',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1827534135',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '65',
                        IFDESCR          => 'Vlan52',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '758660474',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1424172185',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '66',
                        IFDESCR          => 'Vlan53',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '1288973768',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '849506917',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '67',
                        IFDESCR          => 'Vlan54',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '373855909',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '109926504',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '68',
                        IFDESCR          => 'Vlan55',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(3092517394) 357 days, 22:19:33.94',
                        IFINOCTETS       => '51239906',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '32529615',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '69',
                        IFDESCR          => 'Vlan56',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(1823189271) 211 days, 0:24:52.71',
                        IFINOCTETS       => '1483788292',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1282343630',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '70',
                        IFDESCR          => 'Vlan57',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(12415) 0:02:04.15',
                        IFINOCTETS       => '204459822',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '164584478',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '74',
                        IFDESCR          => 'Vlan99',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '49771490',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '49456970',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '75',
                        IFDESCR          => 'Vlan58',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(1980745831) 229 days, 6:04:18.31',
                        IFINOCTETS       => '836890474',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '40488',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '77',
                        IFDESCR          => 'Vlan60',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(1565251543) 181 days, 3:55:15.43',
                        IFINOCTETS       => '108352',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '79',
                        IFDESCR          => 'Vlan63',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(3300554327) 382 days, 0:12:23.27',
                        IFINOCTETS       => '890729714',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '354728196',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '80',
                        IFDESCR          => 'Vlan64',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(3791708590) 438 days, 20:31:25.90',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '30300',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C3550.2.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco Internetwork Operating System Software 
IOS (tm) C3550 Software (C3550-I5Q3L2-M), Version 12.1(20)EA1a, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2004 by cisco Systems, Inc.
Compiled Mon 19-Apr-04 21:50 by yenanh',
            SNMPHOSTNAME => 'CB-Federateur.example.com',
            MAC          => '00:0b:5f:cc:d8:80',
            MODEL        => 'Catalyst 3550-12G',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco Internetwork Operating System Software 
IOS (tm) C3550 Software (C3550-I5Q3L2-M), Version 12.1(20)EA1a, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2004 by cisco Systems, Inc.
Compiled Mon 19-Apr-04 21:50 by yenanh',
            SNMPHOSTNAME => 'CB-Federateur.example.com',
            MAC          => '00:0b:5f:cc:d8:80',
            MODELSNMP    => 'Networking2034',
            MODEL        => 'Catalyst 3550-12G',
            FIRMWARE     => undef,
            SERIAL       => 'CAT0647X118',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 3550-12G',
                COMMENTS     => 'Cisco Internetwork Operating System Software 
IOS (tm) C3550 Software (C3550-I5Q3L2-M), Version 12.1(20)EA1a, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2004 by cisco Systems, Inc.
Compiled Mon 19-Apr-04 21:50 by yenanh',
                NAME         => 'CB-Federateur.example.com',
                MEMORY       => '42',
                SERIAL       => 'CAT0647X118',
                FIRMWARE     => 'CW_VERSION$12.1(20)EA1a$',
                CPU          => '97',
                RAM          => '63',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:81',
                        IFLASTCHANGE     => '(484116314) 56 days, 0:46:03.14',
                        IFINOCTETS       => '45816609',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '411569365',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CB-Switch-201.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.201',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '2',
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:82',
                        IFLASTCHANGE     => '(2549311166) 295 days, 1:25:11.66',
                        IFINOCTETS       => '3858273141',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '281217309',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '3',
                        IFDESCR          => 'GigabitEthernet0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:83',
                        IFLASTCHANGE     => '(3567778147) 412 days, 22:29:41.47',
                        IFINOCTETS       => '622220740',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '538499752',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'AP-Switch-51.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.51',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '4',
                        IFDESCR          => 'GigabitEthernet0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:84',
                        IFLASTCHANGE     => '(3092449227) 357 days, 22:08:12.27',
                        IFINOCTETS       => '3510726368',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2683827189',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CP-Switch-101.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.101',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '5',
                        IFDESCR          => 'GigabitEthernet0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:85',
                        IFLASTCHANGE     => '(2512038666) 290 days, 17:53:06.66',
                        IFINOCTETS       => '2774799775',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2915510749',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/2',
                                SYSNAME  => 'CB6-BU-221.example.com',
                                SYSDESCR => '"Cisco IOS Software, C3560 Software (C3560-IPBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.221',
                                MODEL    => 'cisco WS-C3560-24PS',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '6',
                        IFDESCR          => 'GigabitEthernet0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:86',
                        IFLASTCHANGE     => '(2156630557) 249 days, 14:38:25.57',
                        IFINOCTETS       => '1115388661',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1885777963',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CB-C125-218.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.218',
                                MODEL    => 'cisco WS-C2960-24TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '7',
                        IFDESCR          => 'GigabitEthernet0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:87',
                        IFLASTCHANGE     => '(2549322052) 295 days, 1:27:00.52',
                        IFINOCTETS       => '467916358',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3565993718',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet1/0/25',
                                SYSNAME  => 'SALSERV-160.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.160',
                                MODEL    => 'cisco WS-C2960S-24TD-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '8',
                        IFDESCR          => 'GigabitEthernet0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:88',
                        IFLASTCHANGE     => '(2549310972) 295 days, 1:25:09.72',
                        IFINOCTETS       => '2977706573',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '552271083',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/2',
                                SYSNAME  => 'SALSERV-152.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(25)SEE2, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.152',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '9',
                        IFDESCR          => 'GigabitEthernet0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:89',
                        IFLASTCHANGE     => '(3568000911) 412 days, 23:06:49.11',
                        IFINOCTETS       => '108504863',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '664679833',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'AB-Switch-1.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                IP       => '192.168.1.1',
                                MODEL    => 'cisco WS-C2960-48TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10',
                        IFDESCR          => 'GigabitEthernet0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:8a',
                        IFLASTCHANGE     => '(2392354398) 276 days, 21:25:43.98',
                        IFINOCTETS       => '98137127',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2340388452',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '11',
                        IFDESCR          => 'GigabitEthernet0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:8b',
                        IFLASTCHANGE     => '(4164697427) 482 days, 0:36:14.27',
                        IFINOCTETS       => '1710916739',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3176277119',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '12',
                        IFDESCR          => 'GigabitEthernet0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:8c',
                        IFLASTCHANGE     => '(476695464) 55 days, 4:09:14.64',
                        IFINOCTETS       => '1402074638',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1004750980',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet0/1',
                                SYSNAME  => 'CB-27.example.com',
                                SYSDESCR => '"Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.1.27',
                                MODEL    => 'cisco WS-C2960-24TC-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '13',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '14',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9438) 0:01:34.38',
                        IFINOCTETS       => '1524951264',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3784205374',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '15',
                        IFDESCR          => 'Vlan2',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9438) 0:01:34.38',
                        IFINOCTETS       => '2925654574',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '921361583',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '16',
                        IFDESCR          => 'Vlan3',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(2359259786) 273 days, 1:29:57.86',
                        IFINOCTETS       => '308095168',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3275196',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '17',
                        IFDESCR          => 'Vlan4',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9438) 0:01:34.38',
                        IFINOCTETS       => '1300841453',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '461023207',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '18',
                        IFDESCR          => 'Vlan5',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9440) 0:01:34.40',
                        IFINOCTETS       => '3665968605',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '293334951',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '19',
                        IFDESCR          => 'Vlan6',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9440) 0:01:34.40',
                        IFINOCTETS       => '731097984',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '727629138',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '20',
                        IFDESCR          => 'Vlan7',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9440) 0:01:34.40',
                        IFINOCTETS       => '3588580968',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '21',
                        IFDESCR          => 'Vlan8',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9440) 0:01:34.40',
                        IFINOCTETS       => '1995879669',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '201355359',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '22',
                        IFDESCR          => 'Vlan9',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(906522342) 104 days, 22:07:03.42',
                        IFINOCTETS       => '24796203',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '69531423',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '23',
                        IFDESCR          => 'Vlan10',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9445) 0:01:34.45',
                        IFINOCTETS       => '969754878',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '505089052',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '24',
                        IFDESCR          => 'Vlan11',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9445) 0:01:34.45',
                        IFINOCTETS       => '912171837',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '406399358',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '25',
                        IFDESCR          => 'Vlan12',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9445) 0:01:34.45',
                        IFINOCTETS       => '18107654',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '22156322',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '26',
                        IFDESCR          => 'Vlan13',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9445) 0:01:34.45',
                        IFINOCTETS       => '2935774824',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '554925596',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '27',
                        IFDESCR          => 'Vlan14',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9445) 0:01:34.45',
                        IFINOCTETS       => '1262480508',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '156743227',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '28',
                        IFDESCR          => 'Vlan15',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9445) 0:01:34.45',
                        IFINOCTETS       => '285430619',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '204442164',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '29',
                        IFDESCR          => 'Vlan16',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9445) 0:01:34.45',
                        IFINOCTETS       => '3270744749',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '151574275',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '30',
                        IFDESCR          => 'Vlan17',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9446) 0:01:34.46',
                        IFINOCTETS       => '2697199273',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1552861989',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '31',
                        IFDESCR          => 'Vlan18',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9446) 0:01:34.46',
                        IFINOCTETS       => '714290691',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '315901869',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '32',
                        IFDESCR          => 'Vlan19',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9446) 0:01:34.46',
                        IFINOCTETS       => '2789966222',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '82699614',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '33',
                        IFDESCR          => 'Vlan20',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(6726) 0:01:07.26',
                        IFINOCTETS       => '3486144',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '34',
                        IFDESCR          => 'Vlan21',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(837346286) 96 days, 21:57:42.86',
                        IFINOCTETS       => '2343616',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '17687616',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '35',
                        IFDESCR          => 'Vlan22',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9446) 0:01:34.46',
                        IFINOCTETS       => '1844682199',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1164417941',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '36',
                        IFDESCR          => 'Vlan23',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9446) 0:01:34.46',
                        IFINOCTETS       => '1283399497',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '346379183',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '37',
                        IFDESCR          => 'Vlan24',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9446) 0:01:34.46',
                        IFINOCTETS       => '26909654',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '36318443',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '38',
                        IFDESCR          => 'Vlan25',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9446) 0:01:34.46',
                        IFINOCTETS       => '3064803582',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1918629277',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '39',
                        IFDESCR          => 'Vlan26',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '338750811',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '448529958',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '40',
                        IFDESCR          => 'Vlan27',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '2992035941',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '109841469',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '41',
                        IFDESCR          => 'Vlan28',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '2439367484',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '953575220',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '42',
                        IFDESCR          => 'Vlan29',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '2687600589',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '85230814',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '43',
                        IFDESCR          => 'Vlan30',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '812404160',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1354835843',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '44',
                        IFDESCR          => 'Vlan31',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '72258689',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '211308147',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '45',
                        IFDESCR          => 'Vlan32',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '384143318',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2103712769',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '46',
                        IFDESCR          => 'Vlan33',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9448) 0:01:34.48',
                        IFINOCTETS       => '1418227791',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '48133765',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '47',
                        IFDESCR          => 'Vlan34',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9449) 0:01:34.49',
                        IFINOCTETS       => '994741394',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '159811369',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '48',
                        IFDESCR          => 'Vlan35',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9449) 0:01:34.49',
                        IFINOCTETS       => '444115092',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '343716384',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '49',
                        IFDESCR          => 'Vlan36',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9449) 0:01:34.49',
                        IFINOCTETS       => '26090918',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '26386466',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '50',
                        IFDESCR          => 'Vlan37',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9449) 0:01:34.49',
                        IFINOCTETS       => '1159731765',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '635822850',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '51',
                        IFDESCR          => 'Vlan38',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9449) 0:01:34.49',
                        IFINOCTETS       => '1012860431',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1105812410',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '52',
                        IFDESCR          => 'Vlan39',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9456) 0:01:34.56',
                        IFINOCTETS       => '483221910',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1086390992',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '53',
                        IFDESCR          => 'Vlan40',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9456) 0:01:34.56',
                        IFINOCTETS       => '1372294888',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '54',
                        IFDESCR          => 'Vlan41',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9456) 0:01:34.56',
                        IFINOCTETS       => '53271678',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '55',
                        IFDESCR          => 'Vlan42',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9456) 0:01:34.56',
                        IFINOCTETS       => '3788610984',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '788740888',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '56',
                        IFDESCR          => 'Vlan43',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(12414) 0:02:04.14',
                        IFINOCTETS       => '175265926',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '12227212',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '57',
                        IFDESCR          => 'Vlan44',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(6809) 0:01:08.09',
                        IFINOCTETS       => '84632128',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '58',
                        IFDESCR          => 'Vlan45',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9456) 0:01:34.56',
                        IFINOCTETS       => '13189',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '14842476',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '59',
                        IFDESCR          => 'Vlan46',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '629688708',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '551114293',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '60',
                        IFDESCR          => 'Vlan47',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '169895626',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '12975579',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '61',
                        IFDESCR          => 'Vlan48',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '23318539',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '35099834',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '62',
                        IFDESCR          => 'Vlan49',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '3910236074',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '717502962',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '64',
                        IFDESCR          => 'Vlan51',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '2179892942',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1827466661',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '65',
                        IFDESCR          => 'Vlan52',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '758642986',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1424152021',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '66',
                        IFDESCR          => 'Vlan53',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '1288949915',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '849499777',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '67',
                        IFDESCR          => 'Vlan54',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '373853733',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '109925764',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '68',
                        IFDESCR          => 'Vlan55',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(3092517394) 357 days, 22:19:33.94',
                        IFINOCTETS       => '51236994',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '32528595',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '69',
                        IFDESCR          => 'Vlan56',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(1823189271) 211 days, 0:24:52.71',
                        IFINOCTETS       => '1483759603',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1282294180',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '70',
                        IFDESCR          => 'Vlan57',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(12415) 0:02:04.15',
                        IFINOCTETS       => '204458057',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '164583998',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '74',
                        IFDESCR          => 'Vlan99',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(9457) 0:01:34.57',
                        IFINOCTETS       => '49770978',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '49456490',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '75',
                        IFDESCR          => 'Vlan58',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(1980745831) 229 days, 6:04:18.31',
                        IFINOCTETS       => '836890474',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '40488',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '77',
                        IFDESCR          => 'Vlan60',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(1565251543) 181 days, 3:55:15.43',
                        IFINOCTETS       => '108352',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '79',
                        IFDESCR          => 'Vlan63',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(3300554327) 382 days, 0:12:23.27',
                        IFINOCTETS       => '890715195',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '354716286',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '80',
                        IFDESCR          => 'Vlan64',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0b:5f:cc:d8:80',
                        IFLASTCHANGE     => '(3791708590) 438 days, 20:31:25.90',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '30300',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C3750.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C3750 Software (C3750-IPBASE-M), Version 12.2(25)SEB4, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2005 by Cisco Systems, Inc.
Compiled Tue 30-Aug-05 15:47 by yenanh',
            SNMPHOSTNAME => 'c37hgcr5C2r01',
            MAC          => '00:0f:90:75:48:00',
            MODEL        => 'Catalyst 3750-24/48',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C3750 Software (C3750-IPBASE-M), Version 12.2(25)SEB4, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2005 by Cisco Systems, Inc.
Compiled Tue 30-Aug-05 15:47 by yenanh',
            SNMPHOSTNAME => 'c37hgcr5C2r01',
            MAC          => '00:0f:90:75:48:00',
            MODELSNMP    => 'Networking2055',
            MODEL        => 'Catalyst 3750-24/48',
            FIRMWARE     => undef,
            SERIAL       => 'CAT0813Y2AL',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 3750-24/48',
                COMMENTS     => 'Cisco IOS Software, C3750 Software (C3750-IPBASE-M), Version 12.2(25)SEB4, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2005 by Cisco Systems, Inc.
Compiled Tue 30-Aug-05 15:47 by yenanh',
                NAME         => 'c37hgcr5C2r01',
                MEMORY       => '66',
                LOCATION     => 'HGCR RACK01',
                SERIAL       => 'CAT0813Y2AL',
                FIRMWARE     => 'CW_VERSION$12.2(25)SEB4$',
                IPS          => {
                    IP => [
                        '10.36.16.51',
                    ],
                },
                MAC          => '00:0f:90:75:48:00',
                UPTIME       => '(149654295) 17 days, 7:42:22.95',
                CPU          => '56',
                RAM          => '116',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vl1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:40',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(6545) 0:01:05.45',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '16',
                        IFNAME           => 'Vl16',
                        IFDESCR          => 'Vlan16',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.36.16.51',
                        MAC              => '00:0f:90:75:48:41',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7373) 0:01:13.73',
                        IFINOCTETS       => '381753208',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '413290860',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10001',
                        IFNAME           => 'Fa1/0/1',
                        IFDESCR          => 'FastEthernet1/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6603) 0:01:06.03',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10002',
                        IFNAME           => 'Fa1/0/2',
                        IFDESCR          => 'FastEthernet1/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:04',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6603) 0:01:06.03',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10003',
                        IFNAME           => 'Fa1/0/3',
                        IFDESCR          => 'FastEthernet1/0/3',
                        IFALIAS          => 'uh5a_ykonos01',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:05',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6603) 0:01:06.03',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10004',
                        IFNAME           => 'Fa1/0/4',
                        IFDESCR          => 'FastEthernet1/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:06',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6603) 0:01:06.03',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10005',
                        IFNAME           => 'Fa1/0/5',
                        IFDESCR          => 'FastEthernet1/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:07',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6604) 0:01:06.04',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10006',
                        IFNAME           => 'Fa1/0/6',
                        IFDESCR          => 'FastEthernet1/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:08',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6604) 0:01:06.04',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10007',
                        IFNAME           => 'Fa1/0/7',
                        IFDESCR          => 'FastEthernet1/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:09',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6604) 0:01:06.04',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10008',
                        IFNAME           => 'Fa1/0/8',
                        IFDESCR          => 'FastEthernet1/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:0a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6604) 0:01:06.04',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10009',
                        IFNAME           => 'Fa1/0/9',
                        IFDESCR          => 'FastEthernet1/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:0b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6604) 0:01:06.04',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10010',
                        IFNAME           => 'Fa1/0/10',
                        IFDESCR          => 'FastEthernet1/0/10',
                        IFALIAS          => 'habitacion 115',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:0c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6604) 0:01:06.04',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10011',
                        IFNAME           => 'Fa1/0/11',
                        IFDESCR          => 'FastEthernet1/0/11',
                        IFALIAS          => 'conexion Access Point Prewimax',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:0d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(128705854) 14 days, 21:30:58.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13248',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '67419327',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'PREWIMAX',
                                    NUMBER => '5',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10012',
                        IFNAME           => 'Fa1/0/12',
                        IFDESCR          => 'FastEthernet1/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:0e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6605) 0:01:06.05',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10013',
                        IFNAME           => 'Fa1/0/13',
                        IFDESCR          => 'FastEthernet1/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:0f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6605) 0:01:06.05',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10014',
                        IFNAME           => 'Fa1/0/14',
                        IFDESCR          => 'FastEthernet1/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:10',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6605) 0:01:06.05',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10015',
                        IFNAME           => 'Fa1/0/15',
                        IFDESCR          => 'FastEthernet1/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:11',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6605) 0:01:06.05',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10016',
                        IFNAME           => 'Fa1/0/16',
                        IFDESCR          => 'FastEthernet1/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:12',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6605) 0:01:06.05',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10017',
                        IFNAME           => 'Fa1/0/17',
                        IFDESCR          => 'FastEthernet1/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:13',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6605) 0:01:06.05',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10018',
                        IFNAME           => 'Fa1/0/18',
                        IFDESCR          => 'FastEthernet1/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:14',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6605) 0:01:06.05',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10019',
                        IFNAME           => 'Fa1/0/19',
                        IFDESCR          => 'FastEthernet1/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:15',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10020',
                        IFNAME           => 'Fa1/0/20',
                        IFDESCR          => 'FastEthernet1/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:16',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10021',
                        IFNAME           => 'Fa1/0/21',
                        IFDESCR          => 'FastEthernet1/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:17',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10022',
                        IFNAME           => 'Fa1/0/22',
                        IFDESCR          => 'FastEthernet1/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:18',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10023',
                        IFNAME           => 'Fa1/0/23',
                        IFDESCR          => 'FastEthernet1/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:19',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10024',
                        IFNAME           => 'Fa1/0/24',
                        IFDESCR          => 'FastEthernet1/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:1a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10025',
                        IFNAME           => 'Fa1/0/25',
                        IFDESCR          => 'FastEthernet1/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:1d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10026',
                        IFNAME           => 'Fa1/0/26',
                        IFDESCR          => 'FastEthernet1/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:1e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10027',
                        IFNAME           => 'Fa1/0/27',
                        IFDESCR          => 'FastEthernet1/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:1f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10028',
                        IFNAME           => 'Fa1/0/28',
                        IFDESCR          => 'FastEthernet1/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:20',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10029',
                        IFNAME           => 'Fa1/0/29',
                        IFDESCR          => 'FastEthernet1/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:21',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10030',
                        IFNAME           => 'Fa1/0/30',
                        IFDESCR          => 'FastEthernet1/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:22',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10031',
                        IFNAME           => 'Fa1/0/31',
                        IFDESCR          => 'FastEthernet1/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:23',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10032',
                        IFNAME           => 'Fa1/0/32',
                        IFDESCR          => 'FastEthernet1/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:24',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10033',
                        IFNAME           => 'Fa1/0/33',
                        IFDESCR          => 'FastEthernet1/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:25',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6606) 0:01:06.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10034',
                        IFNAME           => 'Fa1/0/34',
                        IFDESCR          => 'FastEthernet1/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:26',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6607) 0:01:06.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10035',
                        IFNAME           => 'Fa1/0/35',
                        IFDESCR          => 'FastEthernet1/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:27',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6607) 0:01:06.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10036',
                        IFNAME           => 'Fa1/0/36',
                        IFDESCR          => 'FastEthernet1/0/36',
                        IFALIAS          => 'habitacion 115',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:28',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6607) 0:01:06.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10037',
                        IFNAME           => 'Fa1/0/37',
                        IFDESCR          => 'FastEthernet1/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:29',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6607) 0:01:06.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10038',
                        IFNAME           => 'Fa1/0/38',
                        IFDESCR          => 'FastEthernet1/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:2a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6607) 0:01:06.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10039',
                        IFNAME           => 'Fa1/0/39',
                        IFDESCR          => 'FastEthernet1/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:2b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6607) 0:01:06.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10040',
                        IFNAME           => 'Fa1/0/40',
                        IFDESCR          => 'FastEthernet1/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:2c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6607) 0:01:06.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10041',
                        IFNAME           => 'Fa1/0/41',
                        IFDESCR          => 'FastEthernet1/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:2d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6608) 0:01:06.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10042',
                        IFNAME           => 'Fa1/0/42',
                        IFDESCR          => 'FastEthernet1/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:2e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6608) 0:01:06.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'OFIMATICA4',
                                    NUMBER => '4',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '10043',
                        IFNAME           => 'Fa1/0/43',
                        IFDESCR          => 'FastEthernet1/0/43',
                        IFALIAS          => 'ap11hgcr-p(6)-002-ir01',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:2f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7366) 0:01:13.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '63483644',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1375074943',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0',
                                SYSNAME  => 'ap11hgcr-p(6)-002-i',
                                SYSDESCR => '"Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)',
                                IP       => '10.36.21.21',
                                MODEL    => 'cisco AIR-AP1131AG-E-K9   ',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10044',
                        IFNAME           => 'Fa1/0/44',
                        IFDESCR          => 'FastEthernet1/0/44',
                        IFALIAS          => 'ap11hgcr-p(6)-001-ir01',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:30',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6608) 0:01:06.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10045',
                        IFNAME           => 'Fa1/0/45',
                        IFDESCR          => 'FastEthernet1/0/45',
                        IFALIAS          => 'ap11hgcr-p(5)-001-ir01',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:31',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6608) 0:01:06.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10046',
                        IFNAME           => 'Fa1/0/46',
                        IFDESCR          => 'FastEthernet1/0/46',
                        IFALIAS          => 'ap11hgcr-p(5)-002-ir01',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:32',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7331) 0:01:13.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '74287104',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1375207826',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0',
                                SYSNAME  => 'ap11hgcr-p(5)-002-i',
                                SYSDESCR => '"Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)',
                                IP       => '10.36.21.2',
                                MODEL    => 'cisco AIR-AP1131AG-E-K9   ',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10047',
                        IFNAME           => 'Fa1/0/47',
                        IFDESCR          => 'FastEthernet1/0/47',
                        IFALIAS          => 'ap11hgcr-p(5)-004-ir01',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:33',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7366) 0:01:13.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '70672373',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1375677749',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0',
                                SYSNAME  => 'ap11hgcr-p(5)-004-i',
                                SYSDESCR => '"Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)',
                                IP       => '10.36.21.4',
                                MODEL    => 'cisco AIR-AP1131AG-E-K9   ',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10048',
                        IFNAME           => 'Fa1/0/48',
                        IFDESCR          => 'FastEthernet1/0/48',
                        IFALIAS          => 'ap11hgcr-p(5)-003-ir01',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:34',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7371) 0:01:13.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '69677228',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1375656343',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'FastEthernet0',
                                SYSNAME  => 'ap11hgcr-p(5)-003-i',
                                SYSDESCR => '"Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)',
                                IP       => '10.36.21.3',
                                MODEL    => 'cisco AIR-AP1131AG-E-K9   ',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'Gi1/0/1',
                        IFDESCR          => 'GigabitEthernet1/0/1',
                        IFALIAS          => 'ENLACE c65hgcr1 1/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:01',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6603) 0:01:06.03',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'Gi1/0/2',
                        IFDESCR          => 'GigabitEthernet1/0/2',
                        IFALIAS          => 'ENLACE c65hgcr2 1/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:02',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6603) 0:01:06.03',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10103',
                        IFNAME           => 'Gi1/0/3',
                        IFDESCR          => 'GigabitEthernet1/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:1b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7292) 0:01:12.92',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3966197882',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2193031247',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet1/1',
                                SYSNAME  => 'c65hgcr2.sescam.jclm.es',
                                SYSDESCR => '"Cisco Internetwork Operating System Software ',
                                IP       => '10.36.2.3',
                                MODEL    => 'cisco WS-C6509-E',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10104',
                        IFNAME           => 'Gi1/0/4',
                        IFDESCR          => 'GigabitEthernet1/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:0f:90:75:48:1c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10141359) 1 day, 4:10:13.59',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1134098222',
                        IFINERRORS       => '1329377',
                        IFOUTOCTETS      => '13814163',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        VLANS          => {
                            VLAN => [
                                {
                                    NAME   => 'default',
                                    NUMBER => '1',
                                }
                            ]
                        },
                    },
                    {
                        IFNUMBER         => '14501',
                        IFNAME           => 'Nu0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/C6509.01.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, s72033_rp Software (s72033_rp-IPSERVICESK9_WAN-VM), Version 12.2(33)SXI5, RELEASE SOFTWARE (fc2)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Sat 23-Oct-10 17:57 by prod',
            SNMPHOSTNAME => 'swcore-1SRV-1.net-admin.saclay.inria.fr',
            MAC          => '00:18:74:6e:94:00',
            MODEL        => 'Catalyst 6509VSS',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, s72033_rp Software (s72033_rp-IPSERVICESK9_WAN-VM), Version 12.2(33)SXI5, RELEASE SOFTWARE (fc2)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Sat 23-Oct-10 17:57 by prod',
            SNMPHOSTNAME => 'swcore-1SRV-1.net-admin.saclay.inria.fr',
            MAC          => '00:18:74:6e:94:00',
            MODEL        => 'Catalyst 6509VSS',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 6509VSS',
                COMMENTS     => 'Cisco IOS Software, s72033_rp Software (s72033_rp-IPSERVICESK9_WAN-VM), Version 12.2(33)SXI5, RELEASE SOFTWARE (fc2)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Sat 23-Oct-10 17:57 by prod',
                CONTACT      => 'SMI <smi-saclay@inria.fr>',
                NAME         => 'swcore-1SRV-1.net-admin.saclay.inria.fr',
                LOCATION     => 'VSS INRIA Palaiseau - Salle serveurs',
                IPS          => {
                    IP => [
                        '10.200.11.254',
                        '10.200.12.254',
                        '10.200.18.254',
                        '10.200.23.254',
                        '10.202.11.254',
                        '10.202.12.254',
                        '127.0.0.61',
                        '129.175.144.17',
                        '172.18.209.254',
                        '172.18.211.254',
                        '172.18.213.254',
                        '172.20.1.254',
                        '172.21.1.254',
                        '172.22.1.254',
                        '192.168.1.254',
                        '192.168.100.254',
                        '192.168.200.126',
                        '192.168.200.129',
                        '192.168.250.254',
                        '193.55.177.254',
                        '193.55.250.126',
                        '193.55.250.254',
                        '193.55.250.30',
                        '195.83.212.126',
                        '195.83.212.190',
                        '195.83.213.190',
                        '195.83.213.254',
                        '195.83.213.62',
                    ],
                },
                UPTIME       => '(344892502) 39 days, 22:02:05.02',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '178',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7669) 0:01:16.69',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '179',
                        IFNAME           => 'EOBC0/0',
                        IFDESCR          => 'EOBC0/0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        IP               => '127.0.0.61',
                        MAC              => '00:00:16:00:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(102314860) 11 days, 20:12:28.60',
                        IFINOCTETS       => '4162459306',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3786856898',
                        IFOUTERRORS      => '11',
                    },
                    {
                        IFNUMBER         => '180',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '181',
                        IFNAME           => 'SPAN RP Interface',
                        IFDESCR          => 'SPAN RP Interface',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '182',
                        IFNAME           => 'SPAN SP Interface',
                        IFDESCR          => 'SPAN SP Interface',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '183',
                        IFNAME           => 'Control Plane Interface',
                        IFDESCR          => 'Control Plane Interface',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '0',
                        MAC              => '00:00:00:00:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8225) 0:01:22.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '184',
                        IFNAME           => 'unrouted VLAN 1',
                        IFDESCR          => 'unrouted VLAN 1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8297) 0:01:22.97',
                        IFINOCTETS       => '172442161',
                        IFOUTOCTETS      => '172442507',
                    },
                    {
                        IFNUMBER         => '185',
                        IFNAME           => 'unrouted VLAN 1002',
                        IFDESCR          => 'unrouted VLAN 1002',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:97:ea',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8304) 0:01:23.04',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '186',
                        IFNAME           => 'unrouted VLAN 1004',
                        IFDESCR          => 'unrouted VLAN 1004',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:97:ec',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8304) 0:01:23.04',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '187',
                        IFNAME           => 'unrouted VLAN 1005',
                        IFDESCR          => 'unrouted VLAN 1005',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '4472',
                        MAC              => '00:18:74:6e:97:ed',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8308) 0:01:23.08',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '188',
                        IFNAME           => 'unrouted VLAN 1003',
                        IFDESCR          => 'unrouted VLAN 1003',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '4472',
                        MAC              => '00:18:74:6e:97:eb',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8308) 0:01:23.08',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '189',
                        IFNAME           => 'Vlan101',
                        IFDESCR          => 'Vlan101',
                        IFALIAS          => 'NET-ADMIN-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.200.126',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(58441) 0:09:44.41',
                        IFINOCTETS       => '457632218',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '77903604',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '194',
                        IFNAME           => 'Port-channel6',
                        IFDESCR          => 'Port-channel6',
                        IFALIAS          => 'port-channel pour ors-nas2',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:00:00:00:00:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7894) 0:01:18.94',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '195',
                        IFNAME           => 'Port-channel7',
                        IFDESCR          => 'Port-channel7',
                        IFALIAS          => 'port-channel pour ors-nas1',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:00:00:00:00:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7894) 0:01:18.94',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '206',
                        IFNAME           => 'Vlan100',
                        IFDESCR          => 'Vlan100',
                        IFALIAS          => 'IPMI-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.100.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150346) 0:25:03.46',
                        IFINOCTETS       => '80885954',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '36887262',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '207',
                        IFNAME           => 'Vlan102',
                        IFDESCR          => 'Vlan102',
                        IFALIAS          => 'INTRANET-INTERCO',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.200.129',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150355) 0:25:03.55',
                        IFINOCTETS       => '190108161',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1189329239',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '208',
                        IFNAME           => 'Vlan103',
                        IFDESCR          => 'Vlan103',
                        IFALIAS          => 'MULTICAST-INTERCO',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '129.175.144.17',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150378) 0:25:03.78',
                        IFINOCTETS       => '24686388',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '25526804',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '210',
                        IFNAME           => 'Vlan121',
                        IFDESCR          => 'Vlan121',
                        IFALIAS          => 'ILOIA32-LEO-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.1.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150380) 0:25:03.80',
                        IFINOCTETS       => '1047336617',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '419042488',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '213',
                        IFNAME           => 'Vlan210',
                        IFDESCR          => 'Vlan210',
                        IFALIAS          => 'SERVICES1-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '195.83.213.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(58442) 0:09:44.42',
                        IFINOCTETS       => '2167234777',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3154827953',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '214',
                        IFNAME           => 'Vlan211',
                        IFDESCR          => 'Vlan211',
                        IFALIAS          => 'SLB-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.200.11.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150382) 0:25:03.82',
                        IFINOCTETS       => '3403813458',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1430608197',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '215',
                        IFNAME           => 'Vlan212',
                        IFDESCR          => 'Vlan212',
                        IFALIAS          => 'SYS-ADMIN-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.200.12.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150383) 0:25:03.83',
                        IFINOCTETS       => '3671080638',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3003780094',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '216',
                        IFNAME           => 'Vlan213',
                        IFDESCR          => 'Vlan213',
                        IFALIAS          => 'IMPRESSION-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '172.18.213.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150384) 0:25:03.84',
                        IFINOCTETS       => '2999972208',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3135393913',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '219',
                        IFNAME           => 'Vlan220',
                        IFDESCR          => 'Vlan220',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(247741792) 28 days, 16:10:17.92',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '220',
                        IFNAME           => 'Vlan222',
                        IFDESCR          => 'Vlan222',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(247741797) 28 days, 16:10:17.97',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '221',
                        IFNAME           => 'Vlan229',
                        IFDESCR          => 'Vlan229',
                        IFALIAS          => 'PHONIE-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '172.18.211.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(58443) 0:09:44.43',
                        IFINOCTETS       => '1801141036',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '827559384',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '222',
                        IFNAME           => 'Vlan350',
                        IFDESCR          => 'Vlan350',
                        IFALIAS          => 'CLUSTER-LEO-CALCUL-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '172.20.1.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(13908952) 1 day, 14:38:09.52',
                        IFINOCTETS       => '1769079647',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '633643440',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '223',
                        IFNAME           => 'Vlan351',
                        IFDESCR          => 'Vlan351',
                        IFALIAS          => 'LEO-ADMIN-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '172.21.1.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(13908959) 1 day, 14:38:09.59',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '192',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '224',
                        IFNAME           => 'Vlan352',
                        IFDESCR          => 'Vlan352',
                        IFALIAS          => 'LEO-IPMI-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '172.22.1.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(13908960) 1 day, 14:38:09.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '320',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '230',
                        IFNAME           => 'unrouted VLAN 12',
                        IFDESCR          => 'unrouted VLAN 12',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:0c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258058264) 29 days, 20:49:42.64',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '231',
                        IFNAME           => 'unrouted VLAN 13',
                        IFDESCR          => 'unrouted VLAN 13',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:0d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258059852) 29 days, 20:49:58.52',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '232',
                        IFNAME           => 'unrouted VLAN 14',
                        IFDESCR          => 'unrouted VLAN 14',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:0e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258065708) 29 days, 20:50:57.08',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '233',
                        IFNAME           => 'unrouted VLAN 17',
                        IFDESCR          => 'unrouted VLAN 17',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:11',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258615782) 29 days, 22:22:37.82',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '234',
                        IFNAME           => 'unrouted VLAN 100',
                        IFDESCR          => 'unrouted VLAN 100',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:64',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9062) 0:01:30.62',
                        IFINOCTETS       => '53157100',
                        IFOUTOCTETS      => '63486966',
                    },
                    {
                        IFNUMBER         => '235',
                        IFNAME           => 'unrouted VLAN 101',
                        IFDESCR          => 'unrouted VLAN 101',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:65',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9063) 0:01:30.63',
                        IFINOCTETS       => '1412093089',
                        IFOUTOCTETS      => '1397677548',
                    },
                    {
                        IFNUMBER         => '236',
                        IFNAME           => 'unrouted VLAN 102',
                        IFDESCR          => 'unrouted VLAN 102',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:66',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9064) 0:01:30.64',
                        IFINOCTETS       => '3832595459',
                        IFOUTOCTETS      => '3433338786',
                    },
                    {
                        IFNUMBER         => '237',
                        IFNAME           => 'unrouted VLAN 103',
                        IFDESCR          => 'unrouted VLAN 103',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:67',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9064) 0:01:30.64',
                        IFINOCTETS       => '5471282',
                        IFOUTOCTETS      => '5471282',
                    },
                    {
                        IFNUMBER         => '240',
                        IFNAME           => 'unrouted VLAN 121',
                        IFDESCR          => 'unrouted VLAN 121',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:79',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9072) 0:01:30.72',
                        IFINOCTETS       => '255325001',
                        IFOUTOCTETS      => '643086665',
                    },
                    {
                        IFNUMBER         => '243',
                        IFNAME           => 'unrouted VLAN 210',
                        IFDESCR          => 'unrouted VLAN 210',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:d2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9074) 0:01:30.74',
                        IFINOCTETS       => '132233604',
                        IFOUTOCTETS      => '2852122795',
                    },
                    {
                        IFNUMBER         => '244',
                        IFNAME           => 'unrouted VLAN 211',
                        IFDESCR          => 'unrouted VLAN 211',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:d3',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9074) 0:01:30.74',
                        IFINOCTETS       => '1471351432',
                        IFOUTOCTETS      => '249545537',
                    },
                    {
                        IFNUMBER         => '245',
                        IFNAME           => 'unrouted VLAN 212',
                        IFDESCR          => 'unrouted VLAN 212',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:d4',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9076) 0:01:30.76',
                        IFINOCTETS       => '2008616018',
                        IFOUTOCTETS      => '2522166810',
                    },
                    {
                        IFNUMBER         => '246',
                        IFNAME           => 'unrouted VLAN 213',
                        IFDESCR          => 'unrouted VLAN 213',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:d5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9076) 0:01:30.76',
                        IFINOCTETS       => '2292906965',
                        IFOUTOCTETS      => '2546090810',
                    },
                    {
                        IFNUMBER         => '247',
                        IFNAME           => 'unrouted VLAN 215',
                        IFDESCR          => 'unrouted VLAN 215',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:d7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9076) 0:01:30.76',
                        IFINOCTETS       => '3988736097',
                        IFOUTOCTETS      => '3988736097',
                    },
                    {
                        IFNUMBER         => '248',
                        IFNAME           => 'unrouted VLAN 216',
                        IFDESCR          => 'unrouted VLAN 216',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:d8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9080) 0:01:30.80',
                        IFINOCTETS       => '2882532651',
                        IFOUTOCTETS      => '2882532651',
                    },
                    {
                        IFNUMBER         => '249',
                        IFNAME           => 'unrouted VLAN 217',
                        IFDESCR          => 'unrouted VLAN 217',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:d9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9080) 0:01:30.80',
                        IFINOCTETS       => '773279283',
                        IFOUTOCTETS      => '773279283',
                    },
                    {
                        IFNUMBER         => '252',
                        IFNAME           => 'unrouted VLAN 220',
                        IFDESCR          => 'unrouted VLAN 220',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:dc',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9085) 0:01:30.85',
                        IFINOCTETS       => '2783568499',
                        IFOUTOCTETS      => '2783568499',
                    },
                    {
                        IFNUMBER         => '253',
                        IFNAME           => 'Vlan221',
                        IFDESCR          => 'Vlan221',
                        IFALIAS          => 'WIFI-INRIA-SACLAY',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.200.23.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(151053) 0:25:10.53',
                        IFINOCTETS       => '1207097158',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1548856121',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '254',
                        IFNAME           => 'unrouted VLAN 221',
                        IFDESCR          => 'unrouted VLAN 221',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:dd',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9086) 0:01:30.86',
                        IFINOCTETS       => '3407055392',
                        IFOUTOCTETS      => '1013728881',
                    },
                    {
                        IFNUMBER         => '255',
                        IFNAME           => 'unrouted VLAN 222',
                        IFDESCR          => 'unrouted VLAN 222',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:de',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9086) 0:01:30.86',
                        IFINOCTETS       => '8704',
                        IFOUTOCTETS      => '8704',
                    },
                    {
                        IFNUMBER         => '256',
                        IFNAME           => 'unrouted VLAN 223',
                        IFDESCR          => 'unrouted VLAN 223',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:df',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9086) 0:01:30.86',
                        IFINOCTETS       => '3523224575',
                        IFOUTOCTETS      => '3523224575',
                    },
                    {
                        IFNUMBER         => '257',
                        IFNAME           => 'unrouted VLAN 229',
                        IFDESCR          => 'unrouted VLAN 229',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:e5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9087) 0:01:30.87',
                        IFINOCTETS       => '3539341058',
                        IFOUTOCTETS      => '2956961687',
                    },
                    {
                        IFNUMBER         => '258',
                        IFNAME           => 'unrouted VLAN 350',
                        IFDESCR          => 'unrouted VLAN 350',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:95:5e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9088) 0:01:30.88',
                        IFINOCTETS       => '2469157223',
                        IFOUTOCTETS      => '4233859062',
                    },
                    {
                        IFNUMBER         => '259',
                        IFNAME           => 'unrouted VLAN 351',
                        IFDESCR          => 'unrouted VLAN 351',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:95:5f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9089) 0:01:30.89',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '260',
                        IFNAME           => 'unrouted VLAN 352',
                        IFDESCR          => 'unrouted VLAN 352',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:95:60',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9090) 0:01:30.90',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '261',
                        IFNAME           => 'unrouted VLAN 710',
                        IFDESCR          => 'unrouted VLAN 710',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:96:c6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9090) 0:01:30.90',
                        IFINOCTETS       => '3359713527',
                        IFOUTOCTETS      => '3696256',
                    },
                    {
                        IFNUMBER         => '264',
                        IFNAME           => 'unrouted VLAN 750',
                        IFDESCR          => 'unrouted VLAN 750',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:96:ee',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9093) 0:01:30.93',
                        IFINOCTETS       => '1078091517',
                        IFOUTOCTETS      => '2371019538',
                    },
                    {
                        IFNUMBER         => '265',
                        IFNAME           => 'unrouted VLAN 940',
                        IFDESCR          => 'unrouted VLAN 940',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:97:ac',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9098) 0:01:30.98',
                        IFINOCTETS       => '188500',
                        IFOUTOCTETS      => '188500',
                    },
                    {
                        IFNUMBER         => '266',
                        IFNAME           => 'unrouted VLAN 949',
                        IFDESCR          => 'unrouted VLAN 949',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:97:b5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9098) 0:01:30.98',
                        IFINOCTETS       => '3204488827',
                        IFOUTOCTETS      => '3204488827',
                    },
                    {
                        IFNUMBER         => '267',
                        IFNAME           => 'unrouted VLAN 1000',
                        IFDESCR          => 'unrouted VLAN 1000',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:97:e8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9098) 0:01:30.98',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '272',
                        IFNAME           => 'TenGigabitEthernet1/1/1',
                        IFDESCR          => 'TenGigabitEthernet1/1/1',
                        IFALIAS          => 'Lien VSS - switch 1 - baie 11',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '9216',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(158693) 0:26:26.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2679391005',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '931941796',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '273',
                        IFNAME           => 'TenGigabitEthernet1/1/2',
                        IFDESCR          => 'TenGigabitEthernet1/1/2',
                        IFALIAS          => 'Lien 1 vers VSS-PSUD-PCRI',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:26:cb:b2:12:11',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(58307) 0:09:43.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3528788345',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2088161242',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '274',
                        IFNAME           => 'TenGigabitEthernet1/1/3',
                        IFDESCR          => 'TenGigabitEthernet1/1/3',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4486) 0:00:44.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '275',
                        IFNAME           => 'TenGigabitEthernet1/1/4',
                        IFDESCR          => 'TenGigabitEthernet1/1/4',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4487) 0:00:44.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '276',
                        IFNAME           => 'TenGigabitEthernet1/1/5',
                        IFDESCR          => 'TenGigabitEthernet1/1/5',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4488) 0:00:44.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '277',
                        IFNAME           => 'TenGigabitEthernet1/1/6',
                        IFDESCR          => 'TenGigabitEthernet1/1/6',
                        IFALIAS          => 'INTERCO nx5596-1SRV-b9 swcoreB',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:26:cb:b2:12:15',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(196790108) 22 days, 18:38:21.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '817724535',
                        IFINERRORS       => '224',
                        IFOUTOCTETS      => '4268498835',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '278',
                        IFNAME           => 'TenGigabitEthernet1/1/7',
                        IFDESCR          => 'TenGigabitEthernet1/1/7',
                        IFALIAS          => 'INTERCO nx5548-1SRV-b2 swcoreB',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:26:cb:b2:12:16',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(261214639) 30 days, 5:35:46.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3528379380',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '520134916',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '279',
                        IFNAME           => 'TenGigabitEthernet1/1/8',
                        IFDESCR          => 'TenGigabitEthernet1/1/8',
                        IFALIAS          => 'INTERCO swcoreB st-1SRV-b8',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:26:cb:b2:12:17',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(13907863) 1 day, 14:37:58.63',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3053092005',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '2255718387',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '280',
                        IFNAME           => 'GigabitEthernet1/2/1',
                        IFDESCR          => 'GigabitEthernet1/2/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259194480) 29 days, 23:59:04.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '281',
                        IFNAME           => 'GigabitEthernet1/2/2',
                        IFDESCR          => 'GigabitEthernet1/2/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259194526) 29 days, 23:59:05.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '282',
                        IFNAME           => 'GigabitEthernet1/2/3',
                        IFDESCR          => 'GigabitEthernet1/2/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259194571) 29 days, 23:59:05.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '283',
                        IFNAME           => 'GigabitEthernet1/2/4',
                        IFDESCR          => 'GigabitEthernet1/2/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4517) 0:00:45.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '284',
                        IFNAME           => 'GigabitEthernet1/2/5',
                        IFDESCR          => 'GigabitEthernet1/2/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4525) 0:00:45.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '285',
                        IFNAME           => 'GigabitEthernet1/2/6',
                        IFDESCR          => 'GigabitEthernet1/2/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259194619) 29 days, 23:59:06.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '286',
                        IFNAME           => 'GigabitEthernet1/2/7',
                        IFDESCR          => 'GigabitEthernet1/2/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259194664) 29 days, 23:59:06.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '287',
                        IFNAME           => 'GigabitEthernet1/2/8',
                        IFDESCR          => 'GigabitEthernet1/2/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4531) 0:00:45.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '288',
                        IFNAME           => 'GigabitEthernet1/2/9',
                        IFDESCR          => 'GigabitEthernet1/2/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259194710) 29 days, 23:59:07.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '289',
                        IFNAME           => 'GigabitEthernet1/2/10',
                        IFDESCR          => 'GigabitEthernet1/2/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4538) 0:00:45.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '290',
                        IFNAME           => 'GigabitEthernet1/2/11',
                        IFDESCR          => 'GigabitEthernet1/2/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4535) 0:00:45.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '291',
                        IFNAME           => 'GigabitEthernet1/2/12',
                        IFDESCR          => 'GigabitEthernet1/2/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259205688) 30 days, 0:00:56.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '292',
                        IFNAME           => 'GigabitEthernet1/2/13',
                        IFDESCR          => 'GigabitEthernet1/2/13',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4544) 0:00:45.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '293',
                        IFNAME           => 'GigabitEthernet1/2/14',
                        IFDESCR          => 'GigabitEthernet1/2/14',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4547) 0:00:45.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '294',
                        IFNAME           => 'GigabitEthernet1/2/15',
                        IFDESCR          => 'GigabitEthernet1/2/15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4550) 0:00:45.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '295',
                        IFNAME           => 'GigabitEthernet1/2/16',
                        IFDESCR          => 'GigabitEthernet1/2/16',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4554) 0:00:45.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '296',
                        IFNAME           => 'GigabitEthernet1/2/17',
                        IFDESCR          => 'GigabitEthernet1/2/17',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4559) 0:00:45.59',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '297',
                        IFNAME           => 'GigabitEthernet1/2/18',
                        IFDESCR          => 'GigabitEthernet1/2/18',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4563) 0:00:45.63',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '298',
                        IFNAME           => 'GigabitEthernet1/2/19',
                        IFDESCR          => 'GigabitEthernet1/2/19',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4567) 0:00:45.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '299',
                        IFNAME           => 'GigabitEthernet1/2/20',
                        IFDESCR          => 'GigabitEthernet1/2/20',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4574) 0:00:45.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '300',
                        IFNAME           => 'GigabitEthernet1/2/21',
                        IFDESCR          => 'GigabitEthernet1/2/21',
                        IFALIAS          => 'INTERCO st-1LTP-1 swcoreB',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:c4:5e:50',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(94015576) 10 days, 21:09:15.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '77290803',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3957112169',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '301',
                        IFNAME           => 'GigabitEthernet1/2/22',
                        IFDESCR          => 'GigabitEthernet1/2/22',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259252817) 30 days, 0:08:48.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '302',
                        IFNAME           => 'GigabitEthernet1/2/23',
                        IFDESCR          => 'GigabitEthernet1/2/23',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4581) 0:00:45.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '303',
                        IFNAME           => 'GigabitEthernet1/2/24',
                        IFDESCR          => 'GigabitEthernet1/2/24',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4586) 0:00:45.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '304',
                        IFNAME           => 'GigabitEthernet1/3/1',
                        IFDESCR          => 'GigabitEthernet1/3/1',
                        IFALIAS          => 'Ctrl1-Wifi',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:b0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5799453) 16:06:34.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3641578451',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2546602171',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '305',
                        IFNAME           => 'GigabitEthernet1/3/2',
                        IFDESCR          => 'GigabitEthernet1/3/2',
                        IFALIAS          => 'Ctrl2-Wifi',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:b1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5809629) 16:08:16.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '19395459',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1526586165',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '306',
                        IFNAME           => 'GigabitEthernet1/3/3',
                        IFDESCR          => 'GigabitEthernet1/3/3',
                        IFALIAS          => 'Interco Cisco 7200 - Po 254',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:b2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(265910724) 30 days, 18:38:27.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '811279135',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '80855624',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '307',
                        IFNAME           => 'GigabitEthernet1/3/4',
                        IFDESCR          => 'GigabitEthernet1/3/4',
                        IFALIAS          => 'gwvoix-1SRV-1',
                        IFTYPE           => '6',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:b3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(257594197) 29 days, 19:32:21.97',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '308',
                        IFNAME           => 'GigabitEthernet1/3/5',
                        IFDESCR          => 'GigabitEthernet1/3/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21745) 0:03:37.45',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '309',
                        IFNAME           => 'GigabitEthernet1/3/6',
                        IFDESCR          => 'GigabitEthernet1/3/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258764026) 29 days, 22:47:20.26',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '310',
                        IFNAME           => 'GigabitEthernet1/3/7',
                        IFDESCR          => 'GigabitEthernet1/3/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21774) 0:03:37.74',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '311',
                        IFNAME           => 'GigabitEthernet1/3/8',
                        IFDESCR          => 'GigabitEthernet1/3/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259102540) 29 days, 23:43:45.40',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '312',
                        IFNAME           => 'GigabitEthernet1/3/9',
                        IFDESCR          => 'GigabitEthernet1/3/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258730769) 29 days, 22:41:47.69',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '313',
                        IFNAME           => 'GigabitEthernet1/3/10',
                        IFDESCR          => 'GigabitEthernet1/3/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4614) 0:00:46.14',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '314',
                        IFNAME           => 'GigabitEthernet1/3/11',
                        IFDESCR          => 'GigabitEthernet1/3/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21834) 0:03:38.34',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '315',
                        IFNAME           => 'GigabitEthernet1/3/12',
                        IFDESCR          => 'GigabitEthernet1/3/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259092716) 29 days, 23:42:07.16',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '316',
                        IFNAME           => 'GigabitEthernet1/3/13',
                        IFDESCR          => 'GigabitEthernet1/3/13',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258618519) 29 days, 22:23:05.19',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '317',
                        IFNAME           => 'GigabitEthernet1/3/14',
                        IFDESCR          => 'GigabitEthernet1/3/14',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259088696) 29 days, 23:41:26.96',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '318',
                        IFNAME           => 'GigabitEthernet1/3/15',
                        IFDESCR          => 'GigabitEthernet1/3/15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259149167) 29 days, 23:51:31.67',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '319',
                        IFNAME           => 'GigabitEthernet1/3/16',
                        IFDESCR          => 'GigabitEthernet1/3/16',
                        IFALIAS          => 'ors-nas1 e0b',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:bf',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21903) 0:03:39.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '320',
                        IFNAME           => 'GigabitEthernet1/3/17',
                        IFDESCR          => 'GigabitEthernet1/3/17',
                        IFALIAS          => 'acacia eth1 (bonding avec 3/22)',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:c0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(258802410) 29 days, 22:53:44.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '321',
                        IFNAME           => 'GigabitEthernet1/3/18',
                        IFDESCR          => 'GigabitEthernet1/3/18',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4656) 0:00:46.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '322',
                        IFNAME           => 'GigabitEthernet1/3/19',
                        IFDESCR          => 'GigabitEthernet1/3/19',
                        IFALIAS          => 'INTERCO swcoreB st-1SRV-b5-b7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:c2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(13908666) 1 day, 14:38:06.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2569095503',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '539443432',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '323',
                        IFNAME           => 'GigabitEthernet1/3/20',
                        IFDESCR          => 'GigabitEthernet1/3/20',
                        IFALIAS          => 'INTERCO swcoreB st-1SRV-b5-b7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:c3',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(13908639) 1 day, 14:38:06.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3362865870',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2879453463',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '324',
                        IFNAME           => 'GigabitEthernet1/3/21',
                        IFDESCR          => 'GigabitEthernet1/3/21',
                        IFALIAS          => 'soleil',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:c4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21949) 0:03:39.49',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '325',
                        IFNAME           => 'GigabitEthernet1/3/22',
                        IFDESCR          => 'GigabitEthernet1/3/22',
                        IFALIAS          => 'acacia eth0 (bonding avec 3/17)',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:c5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(258802451) 29 days, 22:53:44.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '326',
                        IFNAME           => 'GigabitEthernet1/3/23',
                        IFDESCR          => 'GigabitEthernet1/3/23',
                        IFALIAS          => 'INTERCO swcoreB st-1SRV-b1-b3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:c6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(59017595) 6 days, 19:56:15.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1511825162',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2844206900',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '327',
                        IFNAME           => 'GigabitEthernet1/3/24',
                        IFDESCR          => 'GigabitEthernet1/3/24',
                        IFALIAS          => 'INTERCO swcoreB st-1SRV-b1-b3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:c7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(59017606) 6 days, 19:56:16.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '310480870',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2186052863',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '328',
                        IFNAME           => 'GigabitEthernet1/3/25',
                        IFDESCR          => 'GigabitEthernet1/3/25',
                        IFALIAS          => 'titan admin w2k8R2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:c8',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21985) 0:03:39.85',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '329',
                        IFNAME           => 'GigabitEthernet1/3/26',
                        IFDESCR          => 'GigabitEthernet1/3/26',
                        IFALIAS          => 'castanea eth0 (Dom0 et IPMI)',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:c9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21999) 0:03:39.99',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '330',
                        IFNAME           => 'GigabitEthernet1/3/27',
                        IFDESCR          => 'GigabitEthernet1/3/27',
                        IFALIAS          => 'magenta eth1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:ca',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259330522) 30 days, 0:21:45.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '331',
                        IFNAME           => 'GigabitEthernet1/3/28',
                        IFDESCR          => 'GigabitEthernet1/3/28',
                        IFALIAS          => 'magnolia eth0 (Dom0 et IMPI)',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:cb',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(22024) 0:03:40.24',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '332',
                        IFNAME           => 'GigabitEthernet1/3/29',
                        IFDESCR          => 'GigabitEthernet1/3/29',
                        IFALIAS          => 'castanea eth1 (bonding avec 4/45)',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:cc',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259331392) 30 days, 0:21:53.92',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '333',
                        IFNAME           => 'GigabitEthernet1/3/30',
                        IFDESCR          => 'GigabitEthernet1/3/30',
                        IFALIAS          => 'magnolia eth1 (bonding avec 4/46)',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:cd',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259332141) 30 days, 0:22:01.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '334',
                        IFNAME           => 'GigabitEthernet1/3/31',
                        IFDESCR          => 'GigabitEthernet1/3/31',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(22062) 0:03:40.62',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '335',
                        IFNAME           => 'GigabitEthernet1/3/32',
                        IFDESCR          => 'GigabitEthernet1/3/32',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(22078) 0:03:40.78',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '336',
                        IFNAME           => 'GigabitEthernet1/3/33',
                        IFDESCR          => 'GigabitEthernet1/3/33',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259155119) 29 days, 23:52:31.19',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '337',
                        IFNAME           => 'GigabitEthernet1/3/34',
                        IFDESCR          => 'GigabitEthernet1/3/34',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258653674) 29 days, 22:28:56.74',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '338',
                        IFNAME           => 'GigabitEthernet1/3/35',
                        IFDESCR          => 'GigabitEthernet1/3/35',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4736) 0:00:47.36',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '339',
                        IFNAME           => 'GigabitEthernet1/3/36',
                        IFDESCR          => 'GigabitEthernet1/3/36',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:d3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4744) 0:00:47.44',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '340',
                        IFNAME           => 'GigabitEthernet1/3/37',
                        IFDESCR          => 'GigabitEthernet1/3/37',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259158887) 29 days, 23:53:08.87',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '341',
                        IFNAME           => 'GigabitEthernet1/3/38',
                        IFDESCR          => 'GigabitEthernet1/3/38',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259161967) 29 days, 23:53:39.67',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '342',
                        IFNAME           => 'GigabitEthernet1/3/39',
                        IFDESCR          => 'GigabitEthernet1/3/39',
                        IFALIAS          => 'ors-nas2 e0a',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:d6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(22200) 0:03:42.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '343',
                        IFNAME           => 'GigabitEthernet1/3/40',
                        IFDESCR          => 'GigabitEthernet1/3/40',
                        IFALIAS          => 'ors-nas2 e0c',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:d7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(22222) 0:03:42.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '344',
                        IFNAME           => 'GigabitEthernet1/3/41',
                        IFDESCR          => 'GigabitEthernet1/3/41',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258657908) 29 days, 22:29:39.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '345',
                        IFNAME           => 'GigabitEthernet1/3/42',
                        IFDESCR          => 'GigabitEthernet1/3/42',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(22252) 0:03:42.52',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '346',
                        IFNAME           => 'GigabitEthernet1/3/43',
                        IFDESCR          => 'GigabitEthernet1/3/43',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258775192) 29 days, 22:49:11.92',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '347',
                        IFNAME           => 'GigabitEthernet1/3/44',
                        IFDESCR          => 'GigabitEthernet1/3/44',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259165008) 29 days, 23:54:10.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '348',
                        IFNAME           => 'GigabitEthernet1/3/45',
                        IFDESCR          => 'GigabitEthernet1/3/45',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258478521) 29 days, 21:59:45.21',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '349',
                        IFNAME           => 'GigabitEthernet1/3/46',
                        IFDESCR          => 'GigabitEthernet1/3/46',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258483449) 29 days, 22:00:34.49',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '350',
                        IFNAME           => 'GigabitEthernet1/3/47',
                        IFDESCR          => 'GigabitEthernet1/3/47',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(22327) 0:03:43.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '351',
                        IFNAME           => 'GigabitEthernet1/3/48',
                        IFDESCR          => 'GigabitEthernet1/3/48',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258660442) 29 days, 22:30:04.42',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '352',
                        IFNAME           => 'GigabitEthernet1/4/1',
                        IFDESCR          => 'GigabitEthernet1/4/1',
                        IFALIAS          => 'Ctrl1-Wifi',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5800918) 16:06:49.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2456585990',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3528248072',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '353',
                        IFNAME           => 'GigabitEthernet1/4/2',
                        IFDESCR          => 'GigabitEthernet1/4/2',
                        IFALIAS          => 'Ctrl2-Wifi',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:89',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5809761) 16:08:17.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '37523783',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '357217384',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '354',
                        IFNAME           => 'GigabitEthernet1/4/3',
                        IFDESCR          => 'GigabitEthernet1/4/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259094286) 29 days, 23:42:22.86',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '355',
                        IFNAME           => 'GigabitEthernet1/4/4',
                        IFDESCR          => 'GigabitEthernet1/4/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258731624) 29 days, 22:41:56.24',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '356',
                        IFNAME           => 'GigabitEthernet1/4/5',
                        IFDESCR          => 'GigabitEthernet1/4/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25078) 0:04:10.78',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '357',
                        IFNAME           => 'GigabitEthernet1/4/6',
                        IFDESCR          => 'GigabitEthernet1/4/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258732438) 29 days, 22:42:04.38',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '358',
                        IFNAME           => 'GigabitEthernet1/4/7',
                        IFDESCR          => 'GigabitEthernet1/4/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258733501) 29 days, 22:42:15.01',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '359',
                        IFNAME           => 'GigabitEthernet1/4/8',
                        IFDESCR          => 'GigabitEthernet1/4/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259095872) 29 days, 23:42:38.72',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '360',
                        IFNAME           => 'GigabitEthernet1/4/9',
                        IFDESCR          => 'GigabitEthernet1/4/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259096620) 29 days, 23:42:46.20',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '361',
                        IFNAME           => 'GigabitEthernet1/4/10',
                        IFDESCR          => 'GigabitEthernet1/4/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259097308) 29 days, 23:42:53.08',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '362',
                        IFNAME           => 'GigabitEthernet1/4/11',
                        IFDESCR          => 'GigabitEthernet1/4/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258734409) 29 days, 22:42:24.09',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '363',
                        IFNAME           => 'GigabitEthernet1/4/12',
                        IFDESCR          => 'GigabitEthernet1/4/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:93',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4839) 0:00:48.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '364',
                        IFNAME           => 'GigabitEthernet1/4/13',
                        IFDESCR          => 'GigabitEthernet1/4/13',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258696433) 29 days, 22:36:04.33',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '365',
                        IFNAME           => 'GigabitEthernet1/4/14',
                        IFDESCR          => 'GigabitEthernet1/4/14',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258740617) 29 days, 22:43:26.17',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '366',
                        IFNAME           => 'GigabitEthernet1/4/15',
                        IFDESCR          => 'GigabitEthernet1/4/15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258741413) 29 days, 22:43:34.13',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '367',
                        IFNAME           => 'GigabitEthernet1/4/16',
                        IFDESCR          => 'GigabitEthernet1/4/16',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25217) 0:04:12.17',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '368',
                        IFNAME           => 'GigabitEthernet1/4/17',
                        IFDESCR          => 'GigabitEthernet1/4/17',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25230) 0:04:12.30',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '369',
                        IFNAME           => 'GigabitEthernet1/4/18',
                        IFDESCR          => 'GigabitEthernet1/4/18',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25244) 0:04:12.44',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '370',
                        IFNAME           => 'GigabitEthernet1/4/19',
                        IFDESCR          => 'GigabitEthernet1/4/19',
                        IFALIAS          => 'INTERCO swcoreB st-1SRV-b5-b7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:9a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(13917531) 1 day, 14:39:35.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1221041277',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '423336485',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '371',
                        IFNAME           => 'GigabitEthernet1/4/20',
                        IFDESCR          => 'GigabitEthernet1/4/20',
                        IFALIAS          => 'INTERCO swcoreB st-1SRV-b5-b7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:9b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(13917543) 1 day, 14:39:35.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4141945055',
                        IFINERRORS       => '2',
                        IFOUTOCTETS      => '2885687968',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '372',
                        IFNAME           => 'GigabitEthernet1/4/21',
                        IFDESCR          => 'GigabitEthernet1/4/21',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259098074) 29 days, 23:43:00.74',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '373',
                        IFNAME           => 'GigabitEthernet1/4/22',
                        IFDESCR          => 'GigabitEthernet1/4/22',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258744837) 29 days, 22:44:08.37',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '374',
                        IFNAME           => 'GigabitEthernet1/4/23',
                        IFDESCR          => 'GigabitEthernet1/4/23',
                        IFALIAS          => 'INTERCO swcoreB st-1SRV-b1-b3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:9e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5837632) 16:12:56.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2603072641',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1071402478',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '375',
                        IFNAME           => 'GigabitEthernet1/4/24',
                        IFDESCR          => 'GigabitEthernet1/4/24',
                        IFALIAS          => 'INTERCO swcoreB st-1SRV-b1-b3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:9f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5838064) 16:13:00.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1539032601',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '912697450',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '376',
                        IFNAME           => 'GigabitEthernet1/4/25',
                        IFDESCR          => 'GigabitEthernet1/4/25',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25331) 0:04:13.31',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '377',
                        IFNAME           => 'GigabitEthernet1/4/26',
                        IFDESCR          => 'GigabitEthernet1/4/26',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258663015) 29 days, 22:30:30.15',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '378',
                        IFNAME           => 'GigabitEthernet1/4/27',
                        IFDESCR          => 'GigabitEthernet1/4/27',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25364) 0:04:13.64',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '379',
                        IFNAME           => 'GigabitEthernet1/4/28',
                        IFDESCR          => 'GigabitEthernet1/4/28',
                        IFALIAS          => 'baobab eth0 (bonding avec 4/30)',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:a3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(258830083) 29 days, 22:58:20.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '380',
                        IFNAME           => 'GigabitEthernet1/4/29',
                        IFDESCR          => 'GigabitEthernet1/4/29',
                        IFALIAS          => 'titan srv w2k8R2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:a4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259329669) 30 days, 0:21:36.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '381',
                        IFNAME           => 'GigabitEthernet1/4/30',
                        IFDESCR          => 'GigabitEthernet1/4/30',
                        IFALIAS          => 'baobab eth1 (bonding avec 4/28)',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:a5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(258830125) 29 days, 22:58:21.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '382',
                        IFNAME           => 'GigabitEthernet1/4/31',
                        IFDESCR          => 'GigabitEthernet1/4/31',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259115829) 29 days, 23:45:58.29',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '383',
                        IFNAME           => 'GigabitEthernet1/4/32',
                        IFDESCR          => 'GigabitEthernet1/4/32',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258756081) 29 days, 22:46:00.81',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '384',
                        IFNAME           => 'GigabitEthernet1/4/33',
                        IFDESCR          => 'GigabitEthernet1/4/33',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25440) 0:04:14.40',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '385',
                        IFNAME           => 'GigabitEthernet1/4/34',
                        IFDESCR          => 'GigabitEthernet1/4/34',
                        IFALIAS          => 'ors-nas1 e0d',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:a9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25452) 0:04:14.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '386',
                        IFNAME           => 'GigabitEthernet1/4/35',
                        IFDESCR          => 'GigabitEthernet1/4/35',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258745565) 29 days, 22:44:15.65',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '387',
                        IFNAME           => 'GigabitEthernet1/4/36',
                        IFDESCR          => 'GigabitEthernet1/4/36',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258765477) 29 days, 22:47:34.77',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '388',
                        IFNAME           => 'GigabitEthernet1/4/37',
                        IFDESCR          => 'GigabitEthernet1/4/37',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25493) 0:04:14.93',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '389',
                        IFNAME           => 'GigabitEthernet1/4/38',
                        IFDESCR          => 'GigabitEthernet1/4/38',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258749187) 29 days, 22:44:51.87',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '390',
                        IFNAME           => 'GigabitEthernet1/4/39',
                        IFDESCR          => 'GigabitEthernet1/4/39',
                        IFALIAS          => 'sequoia eth0 (bonding avec 4/40)',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:ae',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(258799916) 29 days, 22:53:19.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '391',
                        IFNAME           => 'GigabitEthernet1/4/40',
                        IFDESCR          => 'GigabitEthernet1/4/40',
                        IFALIAS          => 'sequoia eth1 (bonding avec 4/39)',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:af',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(258799956) 29 days, 22:53:19.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '392',
                        IFNAME           => 'GigabitEthernet1/4/41',
                        IFDESCR          => 'GigabitEthernet1/4/41',
                        IFALIAS          => 'ors-nas2 e0b',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:b0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25541) 0:04:15.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '393',
                        IFNAME           => 'GigabitEthernet1/4/42',
                        IFDESCR          => 'GigabitEthernet1/4/42',
                        IFALIAS          => 'ors-nas2 e0d',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:b1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25552) 0:04:15.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '394',
                        IFNAME           => 'GigabitEthernet1/4/43',
                        IFDESCR          => 'GigabitEthernet1/4/43',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4963) 0:00:49.63',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '395',
                        IFNAME           => 'GigabitEthernet1/4/44',
                        IFDESCR          => 'GigabitEthernet1/4/44',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25566) 0:04:15.66',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '396',
                        IFNAME           => 'GigabitEthernet1/4/45',
                        IFDESCR          => 'GigabitEthernet1/4/45',
                        IFALIAS          => 'castanea eth2 (bonding avec 3/29)',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:b4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259331433) 30 days, 0:21:54.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '397',
                        IFNAME           => 'GigabitEthernet1/4/46',
                        IFDESCR          => 'GigabitEthernet1/4/46',
                        IFALIAS          => 'magnolia eth2 (bonding avec 3/30)',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:b5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259332182) 30 days, 0:22:01.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '398',
                        IFNAME           => 'GigabitEthernet1/4/47',
                        IFDESCR          => 'GigabitEthernet1/4/47',
                        IFALIAS          => 'ors-nas1 e0a',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:b6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25608) 0:04:16.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '399',
                        IFNAME           => 'GigabitEthernet1/4/48',
                        IFDESCR          => 'GigabitEthernet1/4/48',
                        IFALIAS          => '*** passerelle voix  ***',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:b7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25630) 0:04:16.30',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '400',
                        IFNAME           => 'GigabitEthernet1/6/1',
                        IFDESCR          => 'GigabitEthernet1/6/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4989) 0:00:49.89',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '401',
                        IFNAME           => 'GigabitEthernet1/6/2',
                        IFDESCR          => 'GigabitEthernet1/6/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4990) 0:00:49.90',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '402',
                        IFNAME           => 'GigabitEthernet1/6/3',
                        IFDESCR          => 'GigabitEthernet1/6/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(4990) 0:00:49.90',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '403',
                        IFNAME           => 'TenGigabitEthernet1/6/4',
                        IFDESCR          => 'TenGigabitEthernet1/6/4',
                        IFALIAS          => 'Lien VSS vers BAT I - sw1-core-I',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '9216',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(131017) 0:21:50.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3119966385',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '401493978',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '404',
                        IFNAME           => 'TenGigabitEthernet1/6/5',
                        IFDESCR          => 'TenGigabitEthernet1/6/5',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(5169) 0:00:51.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '454',
                        IFNAME           => 'Port-channel100',
                        IFDESCR          => 'Port-channel100',
                        IFALIAS          => 'Lien VSS - switch 1',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '9216',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(131021) 0:21:50.21',
                        IFINOCTETS       => '1503194580',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1330843800',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '456',
                        IFNAME           => 'unrouted VLAN 104',
                        IFDESCR          => 'unrouted VLAN 104',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:68',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9064) 0:01:30.64',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '459',
                        IFNAME           => 'unrouted VLAN 712',
                        IFDESCR          => 'unrouted VLAN 712',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:96:c8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9091) 0:01:30.91',
                        IFINOCTETS       => '244556564',
                        IFOUTOCTETS      => '3919312064',
                    },
                    {
                        IFNUMBER         => '461',
                        IFNAME           => 'unrouted VLAN 714',
                        IFDESCR          => 'unrouted VLAN 714',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:96:ca',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9092) 0:01:30.92',
                        IFINOCTETS       => '1233593176',
                        IFOUTOCTETS      => '2703424945',
                    },
                    {
                        IFNUMBER         => '465',
                        IFNAME           => 'Vlan710',
                        IFDESCR          => 'Vlan710',
                        IFALIAS          => 'SERVICES2-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '193.55.250.30',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150386) 0:25:03.86',
                        IFINOCTETS       => '2077362989',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3453222238',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '467',
                        IFNAME           => 'Vlan714',
                        IFDESCR          => 'Vlan714',
                        IFALIAS          => 'CHERCHEURS-MSR-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '193.55.250.126',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150388) 0:25:03.88',
                        IFINOCTETS       => '3991147287',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '261799740',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '470',
                        IFNAME           => 'Vlan750',
                        IFDESCR          => 'Vlan750',
                        IFALIAS          => 'MSR-CALCUL-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.250.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(13908961) 1 day, 14:38:09.61',
                        IFINOCTETS       => '414121485',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3598390610',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '472',
                        IFNAME           => 'Vlan711',
                        IFDESCR          => 'Vlan711',
                        IFALIAS          => 'SLB-SERVICE-MSR',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.202.11.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7940) 0:01:19.40',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '473',
                        IFNAME           => 'Vlan712',
                        IFDESCR          => 'Vlan712',
                        IFALIAS          => 'SYS-USER-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.202.12.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150387) 0:25:03.87',
                        IFINOCTETS       => '2981326791',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '19002719',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '483',
                        IFNAME           => 'GigabitEthernet2/1/1',
                        IFDESCR          => 'GigabitEthernet2/1/1',
                        IFALIAS          => 'Ctrl1-Wifi',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:97:09:86:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(152023) 0:25:20.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '405811398',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2920447897',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '484',
                        IFNAME           => 'GigabitEthernet2/1/2',
                        IFDESCR          => 'GigabitEthernet2/1/2',
                        IFALIAS          => 'Ctrl2-Wifi',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:97:09:86:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(152050) 0:25:20.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '185155412',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '455172771',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '485',
                        IFNAME           => 'GigabitEthernet2/1/3',
                        IFDESCR          => 'GigabitEthernet2/1/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7290) 0:01:12.90',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '486',
                        IFNAME           => 'GigabitEthernet2/1/4',
                        IFDESCR          => 'GigabitEthernet2/1/4',
                        IFALIAS          => 'gwvoix-1SRV-1',
                        IFTYPE           => '6',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:97:09:86:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(257730288) 29 days, 19:55:02.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '623217652',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '899621813',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '487',
                        IFNAME           => 'GigabitEthernet2/1/5',
                        IFDESCR          => 'GigabitEthernet2/1/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258046651) 29 days, 20:47:46.51',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '488',
                        IFNAME           => 'GigabitEthernet2/1/6',
                        IFDESCR          => 'GigabitEthernet2/1/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258049131) 29 days, 20:48:11.31',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '489',
                        IFNAME           => 'GigabitEthernet2/1/7',
                        IFDESCR          => 'GigabitEthernet2/1/7',
                        IFALIAS          => 'etoile eth0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:97:09:86:86',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(151572) 0:25:15.72',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '490',
                        IFNAME           => 'GigabitEthernet2/1/8',
                        IFDESCR          => 'GigabitEthernet2/1/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7326) 0:01:13.26',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '491',
                        IFNAME           => 'GigabitEthernet2/1/9',
                        IFDESCR          => 'GigabitEthernet2/1/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7327) 0:01:13.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '492',
                        IFNAME           => 'GigabitEthernet2/1/10',
                        IFDESCR          => 'GigabitEthernet2/1/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258769357) 29 days, 22:48:13.57',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '493',
                        IFNAME           => 'GigabitEthernet2/1/11',
                        IFDESCR          => 'GigabitEthernet2/1/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259119394) 29 days, 23:46:33.94',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '494',
                        IFNAME           => 'GigabitEthernet2/1/12',
                        IFDESCR          => 'GigabitEthernet2/1/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258793419) 29 days, 22:52:14.19',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '495',
                        IFNAME           => 'GigabitEthernet2/1/13',
                        IFDESCR          => 'GigabitEthernet2/1/13',
                        IFALIAS          => 'SW-HP BYMOORE IA32',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:97:09:86:8c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(152528) 0:25:25.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1153362824',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2834079301',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '496',
                        IFNAME           => 'GigabitEthernet2/1/14',
                        IFDESCR          => 'GigabitEthernet2/1/14',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7359) 0:01:13.59',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '497',
                        IFNAME           => 'GigabitEthernet2/1/15',
                        IFDESCR          => 'GigabitEthernet2/1/15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7360) 0:01:13.60',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '498',
                        IFNAME           => 'GigabitEthernet2/1/16',
                        IFDESCR          => 'GigabitEthernet2/1/16',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7362) 0:01:13.62',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '499',
                        IFNAME           => 'GigabitEthernet2/1/17',
                        IFDESCR          => 'GigabitEthernet2/1/17',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7364) 0:01:13.64',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '500',
                        IFNAME           => 'GigabitEthernet2/1/18',
                        IFDESCR          => 'GigabitEthernet2/1/18',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7366) 0:01:13.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'GigabitEthernet2/1/19',
                        IFDESCR          => 'GigabitEthernet2/1/19',
                        IFALIAS          => 'INTERCO swcoreA st-1SRV-b5-1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:97:09:86:92',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(13908619) 1 day, 14:38:06.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '465168544',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3274093212',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'GigabitEthernet2/1/20',
                        IFDESCR          => 'GigabitEthernet2/1/20',
                        IFALIAS          => 'INTERCO swcoreA st-1SRV-b5-1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:97:09:86:93',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(189901268) 21 days, 23:30:12.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '775618181',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '421718499',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'GigabitEthernet2/1/21',
                        IFDESCR          => 'GigabitEthernet2/1/21',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258482425) 29 days, 22:00:24.25',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'GigabitEthernet2/1/22',
                        IFDESCR          => 'GigabitEthernet2/1/22',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259098764) 29 days, 23:43:07.64',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'GigabitEthernet2/1/23',
                        IFDESCR          => 'GigabitEthernet2/1/23',
                        IFALIAS          => 'INTERCO swcoreA st-1SRV-b3-2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:97:09:86:96',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(153053) 0:25:30.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4122219573',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2309558971',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'GigabitEthernet2/1/24',
                        IFDESCR          => 'GigabitEthernet2/1/24',
                        IFALIAS          => 'INTERCO swcoreA st-1SRV-b1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:97:09:86:97',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(59017547) 6 days, 19:56:15.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1728011716',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '433359778',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'GigabitEthernet2/1/25',
                        IFDESCR          => 'GigabitEthernet2/1/25',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259107330) 29 days, 23:44:33.30',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'GigabitEthernet2/1/26',
                        IFDESCR          => 'GigabitEthernet2/1/26',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7410) 0:01:14.10',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'GigabitEthernet2/1/27',
                        IFDESCR          => 'GigabitEthernet2/1/27',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7419) 0:01:14.19',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'GigabitEthernet2/1/28',
                        IFDESCR          => 'GigabitEthernet2/1/28',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(152172) 0:25:21.72',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'GigabitEthernet2/1/29',
                        IFDESCR          => 'GigabitEthernet2/1/29',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259122234) 29 days, 23:47:02.34',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'GigabitEthernet2/1/30',
                        IFDESCR          => 'GigabitEthernet2/1/30',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7432) 0:01:14.32',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'GigabitEthernet2/1/31',
                        IFDESCR          => 'GigabitEthernet2/1/31',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(259145607) 29 days, 23:50:56.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'GigabitEthernet2/1/32',
                        IFDESCR          => 'GigabitEthernet2/1/32',
                        IFALIAS          => 'prunus srv',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:97:09:86:9f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(259355060) 30 days, 0:25:50.60',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'GigabitEthernet2/1/33',
                        IFDESCR          => 'GigabitEthernet2/1/33',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7453) 0:01:14.53',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'GigabitEthernet2/1/34',
                        IFDESCR          => 'GigabitEthernet2/1/34',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7453) 0:01:14.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '517',
                        IFNAME           => 'GigabitEthernet2/1/35',
                        IFDESCR          => 'GigabitEthernet2/1/35',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7450) 0:01:14.50',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '546490207',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '139288067',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'GigabitEthernet2/1/36',
                        IFDESCR          => 'GigabitEthernet2/1/36',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7458) 0:01:14.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '718603574',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4041727189',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '519',
                        IFNAME           => 'GigabitEthernet2/1/37',
                        IFDESCR          => 'GigabitEthernet2/1/37',
                        IFALIAS          => 'RSX - gestion PDUs',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:97:09:86:a4',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(307909122) 35 days, 15:18:11.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8472093',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '33368761',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'GigabitEthernet2/1/38',
                        IFDESCR          => 'GigabitEthernet2/1/38',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7471) 0:01:14.71',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'GigabitEthernet2/1/39',
                        IFDESCR          => 'GigabitEthernet2/1/39',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7472) 0:01:14.72',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'GigabitEthernet2/1/40',
                        IFDESCR          => 'GigabitEthernet2/1/40',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7473) 0:01:14.73',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'GigabitEthernet2/1/41',
                        IFDESCR          => 'GigabitEthernet2/1/41',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7474) 0:01:14.74',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'GigabitEthernet2/1/42',
                        IFDESCR          => 'GigabitEthernet2/1/42',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7475) 0:01:14.75',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'GigabitEthernet2/1/43',
                        IFDESCR          => 'GigabitEthernet2/1/43',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7477) 0:01:14.77',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'GigabitEthernet2/1/44',
                        IFDESCR          => 'GigabitEthernet2/1/44',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7479) 0:01:14.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '527',
                        IFNAME           => 'GigabitEthernet2/1/45',
                        IFDESCR          => 'GigabitEthernet2/1/45',
                        IFALIAS          => 'RSX- telephone SRV',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:97:09:86:ac',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(266717618) 30 days, 20:52:56.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '6747553',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '151211334',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '528',
                        IFNAME           => 'GigabitEthernet2/1/46',
                        IFDESCR          => 'GigabitEthernet2/1/46',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(266680631) 30 days, 20:46:46.31',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '28361054',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '914332562',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '529',
                        IFNAME           => 'GigabitEthernet2/1/47',
                        IFDESCR          => 'GigabitEthernet2/1/47',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258739220) 29 days, 22:43:12.20',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '12249631',
                        IFINERRORS       => '4',
                        IFOUTOCTETS      => '289394379',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '530',
                        IFNAME           => 'GigabitEthernet2/1/48',
                        IFDESCR          => 'GigabitEthernet2/1/48',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258728517) 29 days, 22:41:25.17',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '579',
                        IFNAME           => 'GigabitEthernet2/3/1',
                        IFDESCR          => 'GigabitEthernet2/3/1',
                        IFALIAS          => 'Ctrl1-Wifi',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:5f:cb:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(149622) 0:24:56.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3689357544',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3207917086',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '580',
                        IFNAME           => 'GigabitEthernet2/3/2',
                        IFDESCR          => 'GigabitEthernet2/3/2',
                        IFALIAS          => 'Ctrl2-Wifi',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:5f:cb:a9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(149689) 0:24:56.89',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '63704095',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '175288591',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '581',
                        IFNAME           => 'GigabitEthernet2/3/3',
                        IFDESCR          => 'GigabitEthernet2/3/3',
                        IFALIAS          => 'Interco Cisco 7200 - Po 254',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:5f:cb:aa',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7216740) 20:02:47.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4036333417',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3684020736',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '582',
                        IFNAME           => 'GigabitEthernet2/3/4',
                        IFDESCR          => 'GigabitEthernet2/3/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(241115271) 27 days, 21:45:52.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '583',
                        IFNAME           => 'GigabitEthernet2/3/5',
                        IFDESCR          => 'GigabitEthernet2/3/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7571) 0:01:15.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '584',
                        IFNAME           => 'GigabitEthernet2/3/6',
                        IFDESCR          => 'GigabitEthernet2/3/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(241124619) 27 days, 21:47:26.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '585',
                        IFNAME           => 'GigabitEthernet2/3/7',
                        IFDESCR          => 'GigabitEthernet2/3/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(241112204) 27 days, 21:45:22.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '586',
                        IFNAME           => 'GigabitEthernet2/3/8',
                        IFDESCR          => 'GigabitEthernet2/3/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7583) 0:01:15.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '587',
                        IFNAME           => 'GigabitEthernet2/3/9',
                        IFDESCR          => 'GigabitEthernet2/3/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7584) 0:01:15.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '588',
                        IFNAME           => 'GigabitEthernet2/3/10',
                        IFDESCR          => 'GigabitEthernet2/3/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7584) 0:01:15.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '589',
                        IFNAME           => 'GigabitEthernet2/3/11',
                        IFDESCR          => 'GigabitEthernet2/3/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7586) 0:01:15.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '590',
                        IFNAME           => 'GigabitEthernet2/3/12',
                        IFDESCR          => 'GigabitEthernet2/3/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7587) 0:01:15.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '591',
                        IFNAME           => 'GigabitEthernet2/3/13',
                        IFDESCR          => 'GigabitEthernet2/3/13',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7588) 0:01:15.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '592',
                        IFNAME           => 'GigabitEthernet2/3/14',
                        IFDESCR          => 'GigabitEthernet2/3/14',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7589) 0:01:15.89',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '593',
                        IFNAME           => 'GigabitEthernet2/3/15',
                        IFDESCR          => 'GigabitEthernet2/3/15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7590) 0:01:15.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '594',
                        IFNAME           => 'GigabitEthernet2/3/16',
                        IFDESCR          => 'GigabitEthernet2/3/16',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7591) 0:01:15.91',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '595',
                        IFNAME           => 'GigabitEthernet2/3/17',
                        IFDESCR          => 'GigabitEthernet2/3/17',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7593) 0:01:15.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '596',
                        IFNAME           => 'GigabitEthernet2/3/18',
                        IFDESCR          => 'GigabitEthernet2/3/18',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7596) 0:01:15.96',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '597',
                        IFNAME           => 'GigabitEthernet2/3/19',
                        IFDESCR          => 'GigabitEthernet2/3/19',
                        IFALIAS          => 'INTERCO swcoreA st-1SRV-b7-1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:5f:cb:ba',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(13917515) 1 day, 14:39:35.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3902856864',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '48525098',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '598',
                        IFNAME           => 'GigabitEthernet2/3/20',
                        IFDESCR          => 'GigabitEthernet2/3/20',
                        IFALIAS          => 'INTERCO swcoreA st-1SRV-b7-2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:5f:cb:bb',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(13917522) 1 day, 14:39:35.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2053277816',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3231918990',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '599',
                        IFNAME           => 'GigabitEthernet2/3/21',
                        IFDESCR          => 'GigabitEthernet2/3/21',
                        IFALIAS          => 'INTERCO st-1LTP-1 swcoreA',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:5f:cb:bc',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(118080154) 13 days, 16:00:01.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '245081678',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1520751088',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '600',
                        IFNAME           => 'GigabitEthernet2/3/22',
                        IFDESCR          => 'GigabitEthernet2/3/22',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7610) 0:01:16.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '601',
                        IFNAME           => 'GigabitEthernet2/3/23',
                        IFDESCR          => 'GigabitEthernet2/3/23',
                        IFALIAS          => 'INTERCO swcoreA st-1SRV-b1-2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:5f:cb:be',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(59017612) 6 days, 19:56:16.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1571032793',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3577542287',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '602',
                        IFNAME           => 'GigabitEthernet2/3/24',
                        IFDESCR          => 'GigabitEthernet2/3/24',
                        IFALIAS          => 'INTERCO swcoreA st-1SRV-b3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:5f:cb:bf',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150392) 0:25:03.92',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '662082822',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2586311894',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '603',
                        IFNAME           => 'TenGigabitEthernet2/4/1',
                        IFDESCR          => 'TenGigabitEthernet2/4/1',
                        IFALIAS          => 'Lien VSS vers BAT H  - sw1-core-H',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '9216',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(158694) 0:26:26.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '931870117',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2680005816',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '604',
                        IFNAME           => 'TenGigabitEthernet2/4/2',
                        IFDESCR          => 'TenGigabitEthernet2/4/2',
                        IFALIAS          => 'Lien 2 vers VSS-PSUD-PCRI 6500 au 650',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:68:22:49',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(157234) 0:26:12.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2772474663',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1545904223',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '605',
                        IFNAME           => 'TenGigabitEthernet2/4/3',
                        IFDESCR          => 'TenGigabitEthernet2/4/3',
                        IFALIAS          => 'Lien 1 vers DIGITEO CEA Saclay',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:68:22:4a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(301716576) 34 days, 22:06:05.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1801584214',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '613977430',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '606',
                        IFNAME           => 'TenGigabitEthernet2/4/4',
                        IFDESCR          => 'TenGigabitEthernet2/4/4',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7632) 0:01:16.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '607',
                        IFNAME           => 'TenGigabitEthernet2/4/5',
                        IFDESCR          => 'TenGigabitEthernet2/4/5',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7634) 0:01:16.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '608',
                        IFNAME           => 'TenGigabitEthernet2/4/6',
                        IFDESCR          => 'TenGigabitEthernet2/4/6',
                        IFALIAS          => 'INTERCO nx5548-1SRV-b9 swcoreA',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:68:22:4d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(196790100) 22 days, 18:38:21.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '66298697',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1797770831',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '609',
                        IFNAME           => 'TenGigabitEthernet2/4/7',
                        IFDESCR          => 'TenGigabitEthernet2/4/7',
                        IFALIAS          => 'INTERCO nx5548-1SRV-b2 swcoreA',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:68:22:4e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(260829556) 30 days, 4:31:35.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1725032444',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '937942531',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '610',
                        IFNAME           => 'TenGigabitEthernet2/4/8',
                        IFDESCR          => 'TenGigabitEthernet2/4/8',
                        IFALIAS          => 'INTERCO swcoreA st-1SRV-b8',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:68:22:4f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(157355) 0:26:13.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2828428373',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4161217581',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '611',
                        IFNAME           => 'GigabitEthernet2/5/1',
                        IFDESCR          => 'GigabitEthernet2/5/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7654) 0:01:16.54',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '612',
                        IFNAME           => 'GigabitEthernet2/5/2',
                        IFDESCR          => 'GigabitEthernet2/5/2',
                        IFALIAS          => 'INTERCO-INTERNE',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1e:4a:7e:82:01',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(130928) 0:21:49.28',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '613',
                        IFNAME           => 'GigabitEthernet2/5/3',
                        IFDESCR          => 'GigabitEthernet2/5/3',
                        IFALIAS          => 'INTERCO vers exterieur',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:1e:4a:7e:82:02',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(130971) 0:21:49.71',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '614',
                        IFNAME           => 'TenGigabitEthernet2/5/4',
                        IFDESCR          => 'TenGigabitEthernet2/5/4',
                        IFALIAS          => 'Lien VSS vers BAT H  - sw1-core-H',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '9216',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(131020) 0:21:50.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '401357972',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3120473374',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '615',
                        IFNAME           => 'TenGigabitEthernet2/5/5',
                        IFDESCR          => 'TenGigabitEthernet2/5/5',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7668) 0:01:16.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '616',
                        IFNAME           => 'Port-channel99',
                        IFDESCR          => 'Port-channel99',
                        IFALIAS          => 'Lien VSS - switch 2',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '9216',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(131021) 0:21:50.21',
                        IFINOCTETS       => '1331759808',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1499283500',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '620',
                        IFNAME           => 'Port-channel254',
                        IFDESCR          => 'Port-channel254',
                        IFALIAS          => 'Interco Cisco 7200 - Po 254',
                        IFTYPE           => '53',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:5f:cb:aa',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(353903) 0:58:59.03',
                        IFINOCTETS       => '532537053',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '3754284301',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1c:f6:c5:64:1b',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '621',
                        IFNAME           => 'unrouted VLAN 202',
                        IFDESCR          => 'unrouted VLAN 202',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:ca',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9073) 0:01:30.73',
                        IFINOCTETS       => '3757595103',
                        IFOUTOCTETS      => '2420391652',
                    },
                    {
                        IFNUMBER         => '622',
                        IFNAME           => 'Vlan202',
                        IFDESCR          => 'Vlan202',
                        IFALIAS          => 'ADMINISTRATIFS-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '195.83.213.62',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150380) 0:25:03.80',
                        IFINOCTETS       => '2861513567',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2152512219',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '623',
                        IFNAME           => 'unrouted VLAN 822',
                        IFDESCR          => 'unrouted VLAN 822',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:97:36',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9097) 0:01:30.97',
                        IFINOCTETS       => '4119657735',
                        IFOUTOCTETS      => '3440937562',
                    },
                    {
                        IFNUMBER         => '624',
                        IFNAME           => 'Vlan822',
                        IFDESCR          => 'Vlan822',
                        IFALIAS          => 'ADMINISTRATIFS-PCRI',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '195.83.213.190',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(58443) 0:09:44.43',
                        IFINOCTETS       => '4140425493',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '391824663',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '625',
                        IFNAME           => 'unrouted VLAN 829',
                        IFDESCR          => 'unrouted VLAN 829',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:97:3d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9098) 0:01:30.98',
                        IFINOCTETS       => '4062312330',
                        IFOUTOCTETS      => '3436742991',
                    },
                    {
                        IFNUMBER         => '626',
                        IFNAME           => 'Vlan829',
                        IFDESCR          => 'Vlan829',
                        IFALIAS          => 'PHONIE-PCRI',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '172.18.209.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(58444) 0:09:44.44',
                        IFINOCTETS       => '4062138989',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3637402271',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '633',
                        IFNAME           => 'Port-channel500',
                        IFDESCR          => 'Port-channel500',
                        IFALIAS          => 'Lien PCRI',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:26:cb:b2:12:11',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(58306) 0:09:43.06',
                        IFINOCTETS       => '1931913995',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3422910273',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '634',
                        IFNAME           => 'unrouted VLAN 824',
                        IFDESCR          => 'unrouted VLAN 824',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:97:38',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9098) 0:01:30.98',
                        IFINOCTETS       => '3956043432',
                        IFOUTOCTETS      => '2338477448',
                    },
                    {
                        IFNUMBER         => '635',
                        IFNAME           => 'Vlan824',
                        IFDESCR          => 'Vlan824',
                        IFALIAS          => 'CHERCHEURS-PCRI',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '195.83.212.190',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(58444) 0:09:44.44',
                        IFINOCTETS       => '1164760458',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1404205943',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '636',
                        IFNAME           => 'unrouted VLAN 204',
                        IFDESCR          => 'unrouted VLAN 204',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:cc',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9074) 0:01:30.74',
                        IFINOCTETS       => '4048540178',
                        IFOUTOCTETS      => '2484541557',
                    },
                    {
                        IFNUMBER         => '637',
                        IFNAME           => 'Vlan204',
                        IFDESCR          => 'Vlan204',
                        IFALIAS          => 'CHERCHEURS2-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '193.55.250.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150382) 0:25:03.82',
                        IFINOCTETS       => '355254331',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2140124080',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '643',
                        IFNAME           => 'unrouted VLAN 224',
                        IFDESCR          => 'unrouted VLAN 224',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:e0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9086) 0:01:30.86',
                        IFINOCTETS       => '1061476369',
                        IFOUTOCTETS      => '1061476369',
                    },
                    {
                        IFNUMBER         => '644',
                        IFNAME           => 'Vlan224',
                        IFDESCR          => 'Vlan224',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(247741809) 28 days, 16:10:18.09',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '645',
                        IFNAME           => 'unrouted VLAN 820',
                        IFDESCR          => 'unrouted VLAN 820',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:97:34',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9093) 0:01:30.93',
                        IFINOCTETS       => '808407970',
                        IFOUTOCTETS      => '808408156',
                    },
                    {
                        IFNUMBER         => '647',
                        IFNAME           => 'Port-channel14',
                        IFDESCR          => 'Port-channel14',
                        IFALIAS          => 'Lien Ctrl1-Wifi',
                        IFTYPE           => '53',
                        IFSPEED          => '4000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:5f:cb:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(149622) 0:24:56.22',
                        IFINOCTETS       => '1603338618',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3613507023',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '649',
                        IFNAME           => 'unrouted VLAN 2000',
                        IFDESCR          => 'unrouted VLAN 2000',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9099) 0:01:30.99',
                        IFINOCTETS       => '2132523744',
                        IFOUTOCTETS      => '2132538130',
                    },
                    {
                        IFNUMBER         => '650',
                        IFNAME           => 'Port-channel50',
                        IFDESCR          => 'Port-channel50',
                        IFALIAS          => 'INTERCO nx5K-1SRV-b2 swcore',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:68:22:4e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(260829543) 30 days, 4:31:35.43',
                        IFINOCTETS       => '958444528',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1458077447',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '651',
                        IFNAME           => 'Vlan201',
                        IFDESCR          => 'Vlan201',
                        IFALIAS          => 'NETADMIN-PUB-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '195.83.212.126',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150393) 0:25:03.93',
                        IFINOCTETS       => '4194567476',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2820280110',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '652',
                        IFNAME           => 'unrouted VLAN 201',
                        IFDESCR          => 'unrouted VLAN 201',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:c9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9073) 0:01:30.73',
                        IFINOCTETS       => '2884876233',
                        IFOUTOCTETS      => '1823628657',
                    },
                    {
                        IFNUMBER         => '653',
                        IFNAME           => 'TenGigabitEthernet2/2/1',
                        IFDESCR          => 'TenGigabitEthernet2/2/1',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7502) 0:01:15.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '654',
                        IFNAME           => 'TenGigabitEthernet2/2/2',
                        IFDESCR          => 'TenGigabitEthernet2/2/2',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7505) 0:01:15.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '655',
                        IFNAME           => 'TenGigabitEthernet2/2/3',
                        IFDESCR          => 'TenGigabitEthernet2/2/3',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7505) 0:01:15.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '656',
                        IFNAME           => 'TenGigabitEthernet2/2/4',
                        IFDESCR          => 'TenGigabitEthernet2/2/4',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7506) 0:01:15.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '657',
                        IFNAME           => 'TenGigabitEthernet2/2/5',
                        IFDESCR          => 'TenGigabitEthernet2/2/5',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7508) 0:01:15.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '658',
                        IFNAME           => 'TenGigabitEthernet2/2/6',
                        IFDESCR          => 'TenGigabitEthernet2/2/6',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7508) 0:01:15.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '659',
                        IFNAME           => 'TenGigabitEthernet2/2/7',
                        IFDESCR          => 'TenGigabitEthernet2/2/7',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7509) 0:01:15.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '660',
                        IFNAME           => 'TenGigabitEthernet2/2/8',
                        IFDESCR          => 'TenGigabitEthernet2/2/8',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7511) 0:01:15.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '661',
                        IFNAME           => 'TenGigabitEthernet2/2/9',
                        IFDESCR          => 'TenGigabitEthernet2/2/9',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7512) 0:01:15.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '662',
                        IFNAME           => 'TenGigabitEthernet2/2/10',
                        IFDESCR          => 'TenGigabitEthernet2/2/10',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7513) 0:01:15.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '663',
                        IFNAME           => 'TenGigabitEthernet2/2/11',
                        IFDESCR          => 'TenGigabitEthernet2/2/11',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7516) 0:01:15.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '664',
                        IFNAME           => 'TenGigabitEthernet2/2/12',
                        IFDESCR          => 'TenGigabitEthernet2/2/12',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '50:57:a8:66:1e:1b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(154846) 0:25:48.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '665',
                        IFNAME           => 'TenGigabitEthernet2/2/13',
                        IFDESCR          => 'TenGigabitEthernet2/2/13',
                        IFALIAS          => 'INTERCO st-1LTS-1 swcoreA',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '50:57:a8:66:1e:1c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(155872) 0:25:58.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2300573166',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '2699267610',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '666',
                        IFNAME           => 'TenGigabitEthernet2/2/14',
                        IFDESCR          => 'TenGigabitEthernet2/2/14',
                        IFALIAS          => 'INTERCO st-1LTS-2 swcoreA',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '50:57:a8:66:1e:1d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5942578) 16:30:25.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '864158481',
                        IFINERRORS       => '60122',
                        IFOUTOCTETS      => '597674039',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '667',
                        IFNAME           => 'TenGigabitEthernet2/2/15',
                        IFDESCR          => 'TenGigabitEthernet2/2/15',
                        IFALIAS          => 'INTERCO st-1LTN-1 swcoreA',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '50:57:a8:66:1e:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(155905) 0:25:59.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '615880383',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1891388034',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '668',
                        IFNAME           => 'TenGigabitEthernet2/2/16',
                        IFDESCR          => 'TenGigabitEthernet2/2/16',
                        IFALIAS          => 'INTERCO st-1LTN-2 swcoreA',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '50:57:a8:66:1e:1f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(155913) 0:25:59.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3961436832',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3684595855',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '669',
                        IFNAME           => 'unrouted VLAN 225',
                        IFDESCR          => 'unrouted VLAN 225',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:e1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(9087) 0:01:30.87',
                        IFINOCTETS       => '936585029',
                        IFOUTOCTETS      => '683317425',
                    },
                    {
                        IFNUMBER         => '670',
                        IFNAME           => 'Vlan225',
                        IFDESCR          => 'Vlan225',
                        IFALIAS          => 'WIFI-CAPWAP-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.200.18.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(151053) 0:25:10.53',
                        IFINOCTETS       => '549423865',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '146720541',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '671',
                        IFNAME           => 'Port-channel15',
                        IFDESCR          => 'Port-channel15',
                        IFALIAS          => 'Lien Ctrl2-Wifi',
                        IFTYPE           => '53',
                        IFSPEED          => '4000000000',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:5f:cb:a9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(149689) 0:24:56.89',
                        IFINOCTETS       => '305777133',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2514272128',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '674',
                        IFNAME           => 'Port-channel32',
                        IFDESCR          => 'Port-channel32',
                        IFALIAS          => 'INTERCO swcore st-1SRV-b8b10',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => 'c4:7d:4f:68:22:4f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(157354) 0:26:13.54',
                        IFINOCTETS       => '1586549368',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '2124791616',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '675',
                        IFNAME           => 'Port-channel30',
                        IFDESCR          => 'Port-channel30',
                        IFALIAS          => 'INTERCO swcore st-1SRV-b1b3',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:8c:75:9e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(150302) 0:25:03.02',
                        IFINOCTETS       => '1155734617',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3035606587',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '676',
                        IFNAME           => 'Port-channel31',
                        IFDESCR          => 'Port-channel31',
                        IFALIAS          => 'INTERCO swcore st-1SRV-b5b7',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:73:54:ea:c3',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(13908619) 1 day, 14:38:06.19',
                        IFINOCTETS       => '2577091143',
                        IFINERRORS       => '2',
                        IFOUTOCTETS      => '705321107',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '677',
                        IFNAME           => 'Port-channel40',
                        IFDESCR          => 'Port-channel40',
                        IFALIAS          => 'INTERCO st-1LTN-1 swcore',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '50:57:a8:66:1e:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(155904) 0:25:59.04',
                        IFINOCTETS       => '4236793133',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2380602749',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:26:bb:5c:78:80',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '678',
                        IFNAME           => 'Port-channel41',
                        IFDESCR          => 'Port-channel41',
                        IFALIAS          => 'INTERCO st-1LTN-2 swcore',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '50:57:a8:66:1e:1f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(155912) 0:25:59.12',
                        IFINOCTETS       => '6865606',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2106762783',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '679',
                        IFNAME           => 'Port-channel42',
                        IFDESCR          => 'Port-channel42',
                        IFALIAS          => 'INTERCO st-1LTS-1 swcore',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '50:57:a8:66:1e:1c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(155871) 0:25:58.71',
                        IFINOCTETS       => '829551810',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '3475339645',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:16:46:ac:f4:15',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '680',
                        IFNAME           => 'Port-channel43',
                        IFDESCR          => 'Port-channel43',
                        IFALIAS          => 'INTERCO st-1LTS-2 swcore',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '50:57:a8:66:1e:1d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5942577) 16:30:25.77',
                        IFINOCTETS       => '3991433322',
                        IFINERRORS       => '60122',
                        IFOUTOCTETS      => '2721098695',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '682',
                        IFNAME           => 'Port-channel51',
                        IFDESCR          => 'Port-channel51',
                        IFALIAS          => 'INTERCO nx5K-1SRV-b9 swcore',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:26:cb:b2:12:15',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(196790098) 22 days, 18:38:20.98',
                        IFINOCTETS       => '883953092',
                        IFINERRORS       => '224',
                        IFOUTOCTETS      => '1771232102',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '683',
                        IFNAME           => 'TenGigabitEthernet1/7/1',
                        IFDESCR          => 'TenGigabitEthernet1/7/1',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7808) 0:01:18.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '684',
                        IFNAME           => 'TenGigabitEthernet1/7/2',
                        IFDESCR          => 'TenGigabitEthernet1/7/2',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7808) 0:01:18.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '685',
                        IFNAME           => 'TenGigabitEthernet1/7/3',
                        IFDESCR          => 'TenGigabitEthernet1/7/3',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7809) 0:01:18.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '686',
                        IFNAME           => 'TenGigabitEthernet1/7/4',
                        IFDESCR          => 'TenGigabitEthernet1/7/4',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7810) 0:01:18.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '687',
                        IFNAME           => 'TenGigabitEthernet1/7/5',
                        IFDESCR          => 'TenGigabitEthernet1/7/5',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7811) 0:01:18.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '688',
                        IFNAME           => 'TenGigabitEthernet1/7/6',
                        IFDESCR          => 'TenGigabitEthernet1/7/6',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7812) 0:01:18.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '689',
                        IFNAME           => 'TenGigabitEthernet1/7/7',
                        IFDESCR          => 'TenGigabitEthernet1/7/7',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7812) 0:01:18.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '690',
                        IFNAME           => 'TenGigabitEthernet1/7/8',
                        IFDESCR          => 'TenGigabitEthernet1/7/8',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7813) 0:01:18.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '691',
                        IFNAME           => 'TenGigabitEthernet1/7/9',
                        IFDESCR          => 'TenGigabitEthernet1/7/9',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7814) 0:01:18.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '692',
                        IFNAME           => 'TenGigabitEthernet1/7/10',
                        IFDESCR          => 'TenGigabitEthernet1/7/10',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7814) 0:01:18.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '693',
                        IFNAME           => 'TenGigabitEthernet1/7/11',
                        IFDESCR          => 'TenGigabitEthernet1/7/11',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7815) 0:01:18.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '694',
                        IFNAME           => 'TenGigabitEthernet1/7/12',
                        IFDESCR          => 'TenGigabitEthernet1/7/12',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(7816) 0:01:18.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '695',
                        IFNAME           => 'TenGigabitEthernet1/7/13',
                        IFDESCR          => 'TenGigabitEthernet1/7/13',
                        IFALIAS          => 'INTERCO st-1LTS-1 swcoreB',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '64:9e:f3:a5:b2:54',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7340513) 20:23:25.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2826173080',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '778301001',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '696',
                        IFNAME           => 'TenGigabitEthernet1/7/14',
                        IFDESCR          => 'TenGigabitEthernet1/7/14',
                        IFALIAS          => 'INTERCO st-1LTS-2 swcoreB',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '64:9e:f3:a5:b2:55',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7342127) 20:23:41.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3127279977',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2123412584',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '697',
                        IFNAME           => 'TenGigabitEthernet1/7/15',
                        IFDESCR          => 'TenGigabitEthernet1/7/15',
                        IFALIAS          => 'INTERCO st-1LTN-1 swcoreB',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '64:9e:f3:a5:b2:56',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7376622) 20:29:26.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3620912750',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '489214715',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '698',
                        IFNAME           => 'TenGigabitEthernet1/7/16',
                        IFDESCR          => 'TenGigabitEthernet1/7/16',
                        IFALIAS          => 'INTERCO st-1LTN-2 swcoreB',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        MAC              => '64:9e:f3:a5:b2:57',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7382205) 20:30:22.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '340470182',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2717208272',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '699',
                        IFNAME           => 'Port-channel44',
                        IFDESCR          => 'Port-channel44',
                        IFALIAS          => 'INTERCO st-1LTP-1 swcore',
                        IFTYPE           => '53',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:b9:c4:5e:50',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(93548291) 10 days, 19:51:22.91',
                        IFINOCTETS       => '320576671',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1182891429',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '700',
                        IFNAME           => 'unrouted VLAN 999',
                        IFDESCR          => 'unrouted VLAN 999',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:97:e7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(93750506) 10 days, 20:25:05.06',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '701',
                        IFNAME           => 'Vlan214',
                        IFDESCR          => 'Vlan214',
                        IFALIAS          => 'CHERCHEURS1-INRIA',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '193.55.177.254',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(127861148) 14 days, 19:10:11.48',
                        IFINOCTETS       => '4128732555',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2124599646',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '702',
                        IFNAME           => 'unrouted VLAN 214',
                        IFDESCR          => 'unrouted VLAN 214',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:d6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(127860772) 14 days, 19:10:07.72',
                        IFINOCTETS       => '4122970985',
                        IFOUTOCTETS      => '1855541208',
                    },
                    {
                        IFNUMBER         => '703',
                        IFNAME           => 'Port-channel16',
                        IFDESCR          => 'Port-channel16',
                        IFALIAS          => 'VSS vers gwvoix-1SRV',
                        IFTYPE           => '53',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1500',
                        MAC              => '00:24:97:09:86:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(257730291) 29 days, 19:55:02.91',
                        IFINOCTETS       => '623217652',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '899621813',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:16:c7:be:e8:70',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '704',
                        IFNAME           => 'Vlan215',
                        IFDESCR          => 'Vlan215',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(247741775) 28 days, 16:10:17.75',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '705',
                        IFNAME           => 'Vlan216',
                        IFDESCR          => 'Vlan216',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(247741780) 28 days, 16:10:17.80',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '706',
                        IFNAME           => 'Vlan217',
                        IFDESCR          => 'Vlan217',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(247741786) 28 days, 16:10:17.86',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '707',
                        IFNAME           => 'Vlan223',
                        IFDESCR          => 'Vlan223',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(247741804) 28 days, 16:10:18.04',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '708',
                        IFNAME           => 'Vlan2000',
                        IFDESCR          => 'Vlan2000',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(247741816) 28 days, 16:10:18.16',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '709',
                        IFNAME           => 'unrouted VLAN 15',
                        IFDESCR          => 'unrouted VLAN 15',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:0f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258077027) 29 days, 20:52:50.27',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '710',
                        IFNAME           => 'unrouted VLAN 16',
                        IFDESCR          => 'unrouted VLAN 16',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:10',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258087567) 29 days, 20:54:35.67',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                    {
                        IFNUMBER         => '711',
                        IFNAME           => 'unrouted VLAN 105',
                        IFDESCR          => 'unrouted VLAN 105',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '00:18:74:6e:94:69',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(258675261) 29 days, 22:32:32.61',
                        IFINOCTETS       => '0',
                        IFOUTOCTETS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/sw-07a04-01-dc1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
            SNMPHOSTNAME => 'sw-07a04-01-dc1.inria.fr',
            MAC          => '64:e9:50:50:3f:80',
            MODEL        => 'Catalyst 2960S Software',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
            SNMPHOSTNAME => 'sw-07a04-01-dc1.inria.fr',
            MAC          => '64:e9:50:50:3f:80',
            MODEL        => 'Catalyst 2960S Software',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960S Software',
                COMMENTS     => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
                CONTACT      => 'dsi.sesi.reseau@inria.fr',
                NAME         => 'sw-07a04-01-dc1.inria.fr',
                IPS          => {
                    IP => [
                        '192.168.0.17',
                    ],
                },
                UPTIME       => '(140383196) 16 days, 5:57:11.96',
                CPU          => '89',
                RAM          => '512',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:c0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(46606) 0:07:46.06',
                        IFINOCTETS       => '35327',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '2',
                        IFNAME           => 'Vlan2',
                        IFDESCR          => 'Vlan2',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.0.17',
                        MAC              => '64:e9:50:50:3f:c1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1626515) 4:31:05.15',
                        IFINOCTETS       => '237166263',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '16306110',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5179',
                        IFNAME           => 'StackPort1',
                        IFDESCR          => 'StackPort1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7612) 0:01:16.12',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5180',
                        IFNAME           => 'StackSub-St1-1',
                        IFDESCR          => 'StackSub-St1-1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                    {
                        IFNUMBER         => '5181',
                        IFNAME           => 'StackSub-St1-2',
                        IFDESCR          => 'StackSub-St1-2',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet1/0/1',
                        IFDESCR          => 'GigabitEthernet1/0/1',
                        IFALIAS          => 'qlf-sesi-esx2-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(34409454) 3 days, 23:34:54.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '365364247',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '560831537',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet1/0/2',
                        IFDESCR          => 'GigabitEthernet1/0/2',
                        IFALIAS          => 'qlf-sesi-esx4-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:82',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(35328743) 4 days, 2:08:07.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '351219925',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '548462613',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10103',
                        IFNAME           => 'GigabitEthernet1/0/3',
                        IFDESCR          => 'GigabitEthernet1/0/3',
                        IFALIAS          => 'sesi-esx3-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(65100991) 7 days, 12:50:09.91',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '351763067',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '544500578',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10104',
                        IFNAME           => 'GigabitEthernet1/0/4',
                        IFDESCR          => 'GigabitEthernet1/0/4',
                        IFALIAS          => 'sesi-esx4-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:84',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(80171695) 9 days, 6:41:56.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2655601191',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2663232081',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10105',
                        IFNAME           => 'GigabitEthernet1/0/5',
                        IFDESCR          => 'GigabitEthernet1/0/5',
                        IFALIAS          => 'sesi-esx7-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:85',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(63319752) 7 days, 7:53:17.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '351256993',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '544012462',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10106',
                        IFNAME           => 'GigabitEthernet1/0/6',
                        IFDESCR          => 'GigabitEthernet1/0/6',
                        IFALIAS          => 'sesi-esx8-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:86',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(63419817) 7 days, 8:09:58.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '351174854',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '543992576',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10107',
                        IFNAME           => 'GigabitEthernet1/0/7',
                        IFDESCR          => 'GigabitEthernet1/0/7',
                        IFALIAS          => 'sesi-esx15-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:87',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(63693519) 7 days, 8:55:35.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '352063245',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '544738804',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10108',
                        IFNAME           => 'GigabitEthernet1/0/8',
                        IFDESCR          => 'GigabitEthernet1/0/8',
                        IFALIAS          => 'sesi-esx11-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:88',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10109',
                        IFNAME           => 'GigabitEthernet1/0/9',
                        IFDESCR          => 'GigabitEthernet1/0/9',
                        IFALIAS          => 'sesi-esx12-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:89',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(64969724) 7 days, 12:28:17.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '351141574',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '543628072',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10110',
                        IFNAME           => 'GigabitEthernet1/0/10',
                        IFDESCR          => 'GigabitEthernet1/0/10',
                        IFALIAS          => 'infrahv4-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:8a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(65055700) 7 days, 12:42:37.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '351941221',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '544450031',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10111',
                        IFNAME           => 'GigabitEthernet1/0/11',
                        IFDESCR          => 'GigabitEthernet1/0/11',
                        IFALIAS          => 'sesi-esx18-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:8b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(69713678) 8 days, 1:38:56.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '390844328',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '577306694',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10112',
                        IFNAME           => 'GigabitEthernet1/0/12',
                        IFDESCR          => 'GigabitEthernet1/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:8c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(69000908) 7 days, 23:40:09.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3098',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '39426134',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10113',
                        IFNAME           => 'GigabitEthernet1/0/13',
                        IFDESCR          => 'GigabitEthernet1/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:8d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10114',
                        IFNAME           => 'GigabitEthernet1/0/14',
                        IFDESCR          => 'GigabitEthernet1/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:8e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10115',
                        IFNAME           => 'GigabitEthernet1/0/15',
                        IFDESCR          => 'GigabitEthernet1/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:8f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10116',
                        IFNAME           => 'GigabitEthernet1/0/16',
                        IFDESCR          => 'GigabitEthernet1/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10117',
                        IFNAME           => 'GigabitEthernet1/0/17',
                        IFDESCR          => 'GigabitEthernet1/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:91',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10118',
                        IFNAME           => 'GigabitEthernet1/0/18',
                        IFDESCR          => 'GigabitEthernet1/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:92',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10119',
                        IFNAME           => 'GigabitEthernet1/0/19',
                        IFDESCR          => 'GigabitEthernet1/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:93',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10120',
                        IFNAME           => 'GigabitEthernet1/0/20',
                        IFDESCR          => 'GigabitEthernet1/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:94',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10121',
                        IFNAME           => 'GigabitEthernet1/0/21',
                        IFDESCR          => 'GigabitEthernet1/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:95',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10122',
                        IFNAME           => 'GigabitEthernet1/0/22',
                        IFDESCR          => 'GigabitEthernet1/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:96',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10123',
                        IFNAME           => 'GigabitEthernet1/0/23',
                        IFDESCR          => 'GigabitEthernet1/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:97',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10124',
                        IFNAME           => 'GigabitEthernet1/0/24',
                        IFDESCR          => 'GigabitEthernet1/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:98',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10125',
                        IFNAME           => 'GigabitEthernet1/0/25',
                        IFDESCR          => 'GigabitEthernet1/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:99',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1626612) 4:31:06.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1978073708',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1881916352',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet2/0/25',
                                SYSNAME  => 'st-07a05-01-dc1.inria.fr',
                                SYSDESCR => '"Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.0.19',
                                MODEL    => 'cisco WS-C2960X-24TS-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10126',
                        IFNAME           => 'GigabitEthernet1/0/26',
                        IFDESCR          => 'GigabitEthernet1/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10127',
                        IFNAME           => 'GigabitEthernet1/0/27',
                        IFDESCR          => 'GigabitEthernet1/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:9b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10128',
                        IFNAME           => 'GigabitEthernet1/0/28',
                        IFDESCR          => 'GigabitEthernet1/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:9c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10135) 0:01:41.35',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '14001',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '14002',
                        IFNAME           => 'FastEthernet0',
                        IFDESCR          => 'FastEthernet0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:50:3f:b9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(46606) 0:07:46.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/sw-07a10-01-dc1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
            SNMPHOSTNAME => 'sw-07a1O-01-dc1.inria.fr',
            MAC          => '34:db:fd:e9:53:80',
            MODEL        => 'Catalyst 2960S Software',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
            SNMPHOSTNAME => 'sw-07a1O-01-dc1.inria.fr',
            MAC          => '34:db:fd:e9:53:80',
            MODEL        => 'Catalyst 2960S Software',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960S Software',
                COMMENTS     => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
                CONTACT      => 'dsi.sesi.reseau@inria.rf',
                NAME         => 'sw-07a1O-01-dc1.inria.fr',
                IPS          => {
                    IP => [
                        '192.168.0.18',
                    ],
                },
                UPTIME       => '(198661330) 22 days, 23:50:13.30',
                CPU          => '89',
                RAM          => '512',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:c0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(58655806) 6 days, 18:55:58.06',
                        IFINOCTETS       => '35327',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '64320',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '2',
                        IFNAME           => 'Vlan2',
                        IFDESCR          => 'Vlan2',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.0.18',
                        MAC              => '34:db:fd:e9:53:c1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(122829514) 14 days, 5:11:35.14',
                        IFINOCTETS       => '228773167',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '15849629',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5179',
                        IFNAME           => 'StackPort1',
                        IFDESCR          => 'StackPort1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7584) 0:01:15.84',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5180',
                        IFNAME           => 'StackSub-St1-1',
                        IFDESCR          => 'StackSub-St1-1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                    {
                        IFNUMBER         => '5181',
                        IFNAME           => 'StackSub-St1-2',
                        IFDESCR          => 'StackSub-St1-2',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet1/0/1',
                        IFDESCR          => 'GigabitEthernet1/0/1',
                        IFALIAS          => 'holmium-rsc',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(123632706) 14 days, 7:25:27.06',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '56245897',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '279253167',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet1/0/2',
                        IFDESCR          => 'GigabitEthernet1/0/2',
                        IFALIAS          => 'etain-rsc',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:82',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(121953144) 14 days, 2:45:31.44',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '61264751',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '284641800',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10103',
                        IFNAME           => 'GigabitEthernet1/0/3',
                        IFDESCR          => 'GigabitEthernet1/0/3',
                        IFALIAS          => 'neptunium-rsc',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(128580593) 14 days, 21:10:05.93',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '585455',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '226351631',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10104',
                        IFNAME           => 'GigabitEthernet1/0/4',
                        IFDESCR          => 'GigabitEthernet1/0/4',
                        IFALIAS          => 'cesium-rsc',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:84',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(128582097) 14 days, 21:10:20.97',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '75629301',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '291686952',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10105',
                        IFNAME           => 'GigabitEthernet1/0/5',
                        IFDESCR          => 'GigabitEthernet1/0/5',
                        IFALIAS          => 'sesi-bacula-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:85',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(129145679) 14 days, 22:44:16.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '417299560',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '600922724',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10106',
                        IFNAME           => 'GigabitEthernet1/0/6',
                        IFDESCR          => 'GigabitEthernet1/0/6',
                        IFALIAS          => 'cerise-rsc',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:86',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10106) 0:01:41.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10107',
                        IFNAME           => 'GigabitEthernet1/0/7',
                        IFDESCR          => 'GigabitEthernet1/0/7',
                        IFALIAS          => 'coing-rsc',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10106) 0:01:41.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10108',
                        IFNAME           => 'GigabitEthernet1/0/8',
                        IFDESCR          => 'GigabitEthernet1/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:88',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(128579373) 14 days, 21:09:53.73',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3426033',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10109',
                        IFNAME           => 'GigabitEthernet1/0/9',
                        IFDESCR          => 'GigabitEthernet1/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:89',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10110',
                        IFNAME           => 'GigabitEthernet1/0/10',
                        IFDESCR          => 'GigabitEthernet1/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10111',
                        IFNAME           => 'GigabitEthernet1/0/11',
                        IFDESCR          => 'GigabitEthernet1/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:8b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10112',
                        IFNAME           => 'GigabitEthernet1/0/12',
                        IFDESCR          => 'GigabitEthernet1/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:8c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10113',
                        IFNAME           => 'GigabitEthernet1/0/13',
                        IFDESCR          => 'GigabitEthernet1/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:8d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10114',
                        IFNAME           => 'GigabitEthernet1/0/14',
                        IFDESCR          => 'GigabitEthernet1/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:8e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10115',
                        IFNAME           => 'GigabitEthernet1/0/15',
                        IFDESCR          => 'GigabitEthernet1/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:8f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10116',
                        IFNAME           => 'GigabitEthernet1/0/16',
                        IFDESCR          => 'GigabitEthernet1/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10117',
                        IFNAME           => 'GigabitEthernet1/0/17',
                        IFDESCR          => 'GigabitEthernet1/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:91',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10118',
                        IFNAME           => 'GigabitEthernet1/0/18',
                        IFDESCR          => 'GigabitEthernet1/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:92',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10119',
                        IFNAME           => 'GigabitEthernet1/0/19',
                        IFDESCR          => 'GigabitEthernet1/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:93',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10120',
                        IFNAME           => 'GigabitEthernet1/0/20',
                        IFDESCR          => 'GigabitEthernet1/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:94',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10121',
                        IFNAME           => 'GigabitEthernet1/0/21',
                        IFDESCR          => 'GigabitEthernet1/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:95',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10122',
                        IFNAME           => 'GigabitEthernet1/0/22',
                        IFDESCR          => 'GigabitEthernet1/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:96',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10123',
                        IFNAME           => 'GigabitEthernet1/0/23',
                        IFDESCR          => 'GigabitEthernet1/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:97',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10124',
                        IFNAME           => 'GigabitEthernet1/0/24',
                        IFDESCR          => 'GigabitEthernet1/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:98',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10125',
                        IFNAME           => 'GigabitEthernet1/0/25',
                        IFDESCR          => 'GigabitEthernet1/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:99',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(122826613) 14 days, 5:11:06.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1252746706',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '690694624',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet1/0/25',
                                SYSNAME  => 'st-07a05-01-dc1.inria.fr',
                                SYSDESCR => '"Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.0.19',
                                MODEL    => 'cisco WS-C2960X-24TS-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10126',
                        IFNAME           => 'GigabitEthernet1/0/26',
                        IFDESCR          => 'GigabitEthernet1/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10127',
                        IFNAME           => 'GigabitEthernet1/0/27',
                        IFDESCR          => 'GigabitEthernet1/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:9b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10128',
                        IFNAME           => 'GigabitEthernet1/0/28',
                        IFDESCR          => 'GigabitEthernet1/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:9c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10107) 0:01:41.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '14001',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '14002',
                        IFNAME           => 'FastEthernet0',
                        IFDESCR          => 'FastEthernet0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '34:db:fd:e9:53:b9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(58655607) 6 days, 18:55:56.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/sw-30c04-01-dc1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
            SNMPHOSTNAME => 'sw-30c04-01-dc1.inria.fr',
            MAC          => '64:e9:50:7b:1a:80',
            MODEL        => 'Catalyst 2960S Software',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
            SNMPHOSTNAME => 'sw-30c04-01-dc1.inria.fr',
            MAC          => '64:e9:50:7b:1a:80',
            MODEL        => 'Catalyst 2960S Software',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960S Software',
                COMMENTS     => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
                CONTACT      => 'dsi.sesi.reseau@inria.fr.',
                NAME         => 'sw-30c04-01-dc1.inria.fr',
                IPS          => {
                    IP => [
                        '192.168.0.13',
                    ],
                },
                UPTIME       => '(198825994) 23 days, 0:17:39.94',
                CPU          => '83',
                RAM          => '512',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:c0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(17709190) 2 days, 1:11:31.90',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '2',
                        IFNAME           => 'Vlan2',
                        IFDESCR          => 'Vlan2',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.0.13',
                        MAC              => '64:e9:50:7b:1a:c1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(96016858) 11 days, 2:42:48.58',
                        IFINOCTETS       => '177241661',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '8270115',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5179',
                        IFNAME           => 'StackPort1',
                        IFDESCR          => 'StackPort1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7641) 0:01:16.41',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5180',
                        IFNAME           => 'StackSub-St1-1',
                        IFDESCR          => 'StackSub-St1-1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                    {
                        IFNUMBER         => '5181',
                        IFNAME           => 'StackSub-St1-2',
                        IFDESCR          => 'StackSub-St1-2',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet1/0/1',
                        IFDESCR          => 'GigabitEthernet1/0/1',
                        IFALIAS          => 'pro30-1-1-kvm1-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147452225) 17 days, 1:35:22.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7147044',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '617499909',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet1/0/2',
                        IFDESCR          => 'GigabitEthernet1/0/2',
                        IFALIAS          => 'pro30-1-1-kvm2-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:82',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147493999) 17 days, 1:42:19.99',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7681206',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '615484511',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10103',
                        IFNAME           => 'GigabitEthernet1/0/3',
                        IFDESCR          => 'GigabitEthernet1/0/3',
                        IFALIAS          => 'pro30-1-1-kvm3-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147347721) 17 days, 1:17:57.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '6857024',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '617196466',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10104',
                        IFNAME           => 'GigabitEthernet1/0/4',
                        IFDESCR          => 'GigabitEthernet1/0/4',
                        IFALIAS          => 'pro30-1-1-kvm4-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:84',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147347721) 17 days, 1:17:57.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7132710',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '617476032',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10105',
                        IFNAME           => 'GigabitEthernet1/0/5',
                        IFDESCR          => 'GigabitEthernet1/0/5',
                        IFALIAS          => 'pro30-1-2-kvm1-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:85',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147347723) 17 days, 1:17:57.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13297322',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '623408422',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10106',
                        IFNAME           => 'GigabitEthernet1/0/6',
                        IFDESCR          => 'GigabitEthernet1/0/6',
                        IFALIAS          => 'pro30-1-2-kvm2-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:86',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147347723) 17 days, 1:17:57.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13320584',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '623556144',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10107',
                        IFNAME           => 'GigabitEthernet1/0/7',
                        IFDESCR          => 'GigabitEthernet1/0/7',
                        IFALIAS          => 'pro30-1-2-kvm3-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:87',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147416797) 17 days, 1:29:27.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13490000',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '622122928',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10108',
                        IFNAME           => 'GigabitEthernet1/0/8',
                        IFDESCR          => 'GigabitEthernet1/0/8',
                        IFALIAS          => 'pro30-1-2-kvm4-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147420737) 17 days, 1:30:07.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13441620',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '621979252',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10109',
                        IFNAME           => 'GigabitEthernet1/0/9',
                        IFDESCR          => 'GigabitEthernet1/0/9',
                        IFALIAS          => 'pro30-1-3-kvm1-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:89',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147347724) 17 days, 1:17:57.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13423768',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '623649037',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10110',
                        IFNAME           => 'GigabitEthernet1/0/10',
                        IFDESCR          => 'GigabitEthernet1/0/10',
                        IFALIAS          => 'pro30-1-3-kvm2-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:8a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147481890) 17 days, 1:40:18.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13387126',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '621161478',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10111',
                        IFNAME           => 'GigabitEthernet1/0/11',
                        IFDESCR          => 'GigabitEthernet1/0/11',
                        IFALIAS          => 'pro30-1-3-kvm3-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:8b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147347725) 17 days, 1:17:57.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13671536',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '623814679',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10112',
                        IFNAME           => 'GigabitEthernet1/0/12',
                        IFDESCR          => 'GigabitEthernet1/0/12',
                        IFALIAS          => 'pro30-1-3-kvm4-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:8c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147347725) 17 days, 1:17:57.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13603876',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '623707895',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10113',
                        IFNAME           => 'GigabitEthernet1/0/13',
                        IFDESCR          => 'GigabitEthernet1/0/13',
                        IFALIAS          => 'pro30-1-4-kvm1-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:8d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147347726) 17 days, 1:17:57.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13647602',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '623857103',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10114',
                        IFNAME           => 'GigabitEthernet1/0/14',
                        IFDESCR          => 'GigabitEthernet1/0/14',
                        IFALIAS          => 'pro30-1-4-kvm2-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:8e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147487146) 17 days, 1:41:11.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13613614',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '621377377',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10115',
                        IFNAME           => 'GigabitEthernet1/0/15',
                        IFDESCR          => 'GigabitEthernet1/0/15',
                        IFALIAS          => 'pro30-1-4-kvm3-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:8f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147347727) 17 days, 1:17:57.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13395388',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '623526165',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10116',
                        IFNAME           => 'GigabitEthernet1/0/16',
                        IFDESCR          => 'GigabitEthernet1/0/16',
                        IFALIAS          => 'pro30-1-4-kvm4-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:90',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147347727) 17 days, 1:17:57.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13486706',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '623661077',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10117',
                        IFNAME           => 'GigabitEthernet1/0/17',
                        IFDESCR          => 'GigabitEthernet1/0/17',
                        IFALIAS          => 'pro30-1-5-kvm1-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:91',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147461345) 17 days, 1:36:53.45',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '13466052',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '621433831',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10118',
                        IFNAME           => 'GigabitEthernet1/0/18',
                        IFDESCR          => 'GigabitEthernet1/0/18',
                        IFALIAS          => 'pro30-1-5-kvm2-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:92',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147596925) 17 days, 1:59:29.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13449058',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '619935316',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10119',
                        IFNAME           => 'GigabitEthernet1/0/19',
                        IFDESCR          => 'GigabitEthernet1/0/19',
                        IFALIAS          => 'pro30-1-5-kvm3-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:93',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147443981) 17 days, 1:33:59.81',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '13394819',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '621598631',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10120',
                        IFNAME           => 'GigabitEthernet1/0/20',
                        IFDESCR          => 'GigabitEthernet1/0/20',
                        IFALIAS          => 'pro30-1-5-kvm4-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:94',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147347955) 17 days, 1:17:59.55',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '13385818',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '623615644',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10121',
                        IFNAME           => 'GigabitEthernet1/0/21',
                        IFDESCR          => 'GigabitEthernet1/0/21',
                        IFALIAS          => 'pro30-1-6-kvm1-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:95',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147347956) 17 days, 1:17:59.56',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '13568683',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '623656919',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10122',
                        IFNAME           => 'GigabitEthernet1/0/22',
                        IFDESCR          => 'GigabitEthernet1/0/22',
                        IFALIAS          => 'pro30-1-6-kvm2-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:96',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147455305) 17 days, 1:35:53.05',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '13539360',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '623640747',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10123',
                        IFNAME           => 'GigabitEthernet1/0/23',
                        IFDESCR          => 'GigabitEthernet1/0/23',
                        IFALIAS          => 'pro30-1-6-kvm3-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:97',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147347959) 17 days, 1:17:59.59',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '13994804',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '624152183',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10124',
                        IFNAME           => 'GigabitEthernet1/0/24',
                        IFDESCR          => 'GigabitEthernet1/0/24',
                        IFALIAS          => 'pro30-1-6-kvm4-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:98',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(147347959) 17 days, 1:17:59.59',
                        IFPORTDUPLEX     => '2',
                        IFINOCTETS       => '14295820',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '626911125',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10125',
                        IFNAME           => 'GigabitEthernet1/0/25',
                        IFDESCR          => 'GigabitEthernet1/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:99',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(96016957) 11 days, 2:42:49.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1667370804',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '407052618',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet2/0/25',
                                SYSNAME  => 'st-30rs04-01-dc1.inria.fr',
                                SYSDESCR => '"Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.0.16',
                                MODEL    => 'cisco WS-C2960X-24TS-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10126',
                        IFNAME           => 'GigabitEthernet1/0/26',
                        IFDESCR          => 'GigabitEthernet1/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10164) 0:01:41.64',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10127',
                        IFNAME           => 'GigabitEthernet1/0/27',
                        IFDESCR          => 'GigabitEthernet1/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:9b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10164) 0:01:41.64',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10128',
                        IFNAME           => 'GigabitEthernet1/0/28',
                        IFDESCR          => 'GigabitEthernet1/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:9c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10164) 0:01:41.64',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '14001',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '14002',
                        IFNAME           => 'FastEthernet0',
                        IFDESCR          => 'FastEthernet0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:1a:b9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(10571) 0:01:45.71',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/sw-30c05-01-dc1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
            SNMPHOSTNAME => 'sw-30c05-01-dc1.inria.fr',
            MAC          => '64:e9:50:7b:14:80',
            MODEL        => 'Catalyst 2960S Software',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
            SNMPHOSTNAME => 'sw-30c05-01-dc1.inria.fr',
            MAC          => '64:e9:50:7b:14:80',
            MODEL        => 'Catalyst 2960S Software',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960S Software',
                COMMENTS     => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
                CONTACT      => 'dsi.sesi.reseau@inria.rf',
                NAME         => 'sw-30c05-01-dc1.inria.fr',
                IPS          => {
                    IP => [
                        '192.168.0.14',
                    ],
                },
                UPTIME       => '(181163606) 20 days, 23:13:56.06',
                CPU          => '92',
                RAM          => '512',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:c0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(8282) 0:01:22.82',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '2',
                        IFNAME           => 'Vlan2',
                        IFDESCR          => 'Vlan2',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.0.14',
                        MAC              => '64:e9:50:7b:14:c1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(78223456) 9 days, 1:17:14.56',
                        IFINOCTETS       => '177284324',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '12002318',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5179',
                        IFNAME           => 'StackPort1',
                        IFDESCR          => 'StackPort1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7649) 0:01:16.49',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5180',
                        IFNAME           => 'StackSub-St1-1',
                        IFDESCR          => 'StackSub-St1-1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                    {
                        IFNUMBER         => '5181',
                        IFNAME           => 'StackSub-St1-2',
                        IFDESCR          => 'StackSub-St1-2',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet1/0/1',
                        IFDESCR          => 'GigabitEthernet1/0/1',
                        IFALIAS          => 'pro30-1-7-kvm1-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(106361341) 12 days, 7:26:53.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4020423',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '712081496',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet1/0/2',
                        IFDESCR          => 'GigabitEthernet1/0/2',
                        IFALIAS          => 'pro30-1-7-kvm2-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:82',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8306) 0:01:23.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10103',
                        IFNAME           => 'GigabitEthernet1/0/3',
                        IFDESCR          => 'GigabitEthernet1/0/3',
                        IFALIAS          => 'pro30-1-7-kvm3-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:83',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8306) 0:01:23.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10104',
                        IFNAME           => 'GigabitEthernet1/0/4',
                        IFDESCR          => 'GigabitEthernet1/0/4',
                        IFALIAS          => 'pro30-1-7-kvm4-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:84',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8306) 0:01:23.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10105',
                        IFNAME           => 'GigabitEthernet1/0/5',
                        IFDESCR          => 'GigabitEthernet1/0/5',
                        IFALIAS          => 'sesi-vcenter-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:85',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8306) 0:01:23.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10106',
                        IFNAME           => 'GigabitEthernet1/0/6',
                        IFDESCR          => 'GigabitEthernet1/0/6',
                        IFALIAS          => 'sesi-esx1-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:86',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8306) 0:01:23.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10107',
                        IFNAME           => 'GigabitEthernet1/0/7',
                        IFDESCR          => 'GigabitEthernet1/0/7',
                        IFALIAS          => 'sesi-esx2-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8306) 0:01:23.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10108',
                        IFNAME           => 'GigabitEthernet1/0/8',
                        IFDESCR          => 'GigabitEthernet1/0/8',
                        IFALIAS          => 'sesi-esx17-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:88',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8306) 0:01:23.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10109',
                        IFNAME           => 'GigabitEthernet1/0/9',
                        IFDESCR          => 'GigabitEthernet1/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:89',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8306) 0:01:23.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10110',
                        IFNAME           => 'GigabitEthernet1/0/10',
                        IFDESCR          => 'GigabitEthernet1/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8306) 0:01:23.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10111',
                        IFNAME           => 'GigabitEthernet1/0/11',
                        IFDESCR          => 'GigabitEthernet1/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:8b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8306) 0:01:23.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10112',
                        IFNAME           => 'GigabitEthernet1/0/12',
                        IFDESCR          => 'GigabitEthernet1/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:8c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8306) 0:01:23.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10113',
                        IFNAME           => 'GigabitEthernet1/0/13',
                        IFDESCR          => 'GigabitEthernet1/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:8d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8306) 0:01:23.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10114',
                        IFNAME           => 'GigabitEthernet1/0/14',
                        IFDESCR          => 'GigabitEthernet1/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:8e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8306) 0:01:23.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10115',
                        IFNAME           => 'GigabitEthernet1/0/15',
                        IFDESCR          => 'GigabitEthernet1/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:8f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8306) 0:01:23.06',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10116',
                        IFNAME           => 'GigabitEthernet1/0/16',
                        IFDESCR          => 'GigabitEthernet1/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8307) 0:01:23.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10117',
                        IFNAME           => 'GigabitEthernet1/0/17',
                        IFDESCR          => 'GigabitEthernet1/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:91',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8307) 0:01:23.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10118',
                        IFNAME           => 'GigabitEthernet1/0/18',
                        IFDESCR          => 'GigabitEthernet1/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:92',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8307) 0:01:23.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10119',
                        IFNAME           => 'GigabitEthernet1/0/19',
                        IFDESCR          => 'GigabitEthernet1/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:93',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8307) 0:01:23.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10120',
                        IFNAME           => 'GigabitEthernet1/0/20',
                        IFDESCR          => 'GigabitEthernet1/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:94',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8307) 0:01:23.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10121',
                        IFNAME           => 'GigabitEthernet1/0/21',
                        IFDESCR          => 'GigabitEthernet1/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:95',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8307) 0:01:23.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10122',
                        IFNAME           => 'GigabitEthernet1/0/22',
                        IFDESCR          => 'GigabitEthernet1/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:96',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8307) 0:01:23.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10123',
                        IFNAME           => 'GigabitEthernet1/0/23',
                        IFDESCR          => 'GigabitEthernet1/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:97',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8307) 0:01:23.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10124',
                        IFNAME           => 'GigabitEthernet1/0/24',
                        IFDESCR          => 'GigabitEthernet1/0/24',
                        IFALIAS          => 'sesi-kvm1-nat',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:98',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(171302833) 19 days, 19:50:28.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '10674589',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '119929392',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10125',
                        IFNAME           => 'GigabitEthernet1/0/25',
                        IFDESCR          => 'GigabitEthernet1/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:99',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(78223553) 9 days, 1:17:15.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1361446129',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '53047255',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet1/0/26',
                                SYSNAME  => 'st-30rs04-01-dc1.inria.fr',
                                SYSDESCR => '"Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.0.16',
                                MODEL    => 'cisco WS-C2960X-24TS-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10126',
                        IFNAME           => 'GigabitEthernet1/0/26',
                        IFDESCR          => 'GigabitEthernet1/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8307) 0:01:23.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10127',
                        IFNAME           => 'GigabitEthernet1/0/27',
                        IFDESCR          => 'GigabitEthernet1/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:9b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8307) 0:01:23.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10128',
                        IFNAME           => 'GigabitEthernet1/0/28',
                        IFDESCR          => 'GigabitEthernet1/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:9c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8307) 0:01:23.07',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '14001',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '14002',
                        IFNAME           => 'FastEthernet0',
                        IFDESCR          => 'FastEthernet0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:14:b9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(8278) 0:01:22.78',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
    'cisco/sw-30c07-01-dc1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
            SNMPHOSTNAME => 'sw-30c07-01-dc1.inria.fr',
            MAC          => '64:e9:50:7b:16:00',
            MODEL        => 'Catalyst 2960S Software',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
            SNMPHOSTNAME => 'sw-30c07-01-dc1.inria.fr',
            MAC          => '64:e9:50:7b:16:00',
            MODEL        => 'Catalyst 2960S Software',
        },
        {
            INFO => {
                ID           => undef,
                MANUFACTURER => 'Cisco',
                TYPE         => 'NETWORKING',
                MODEL        => 'Catalyst 2960S Software',
                COMMENTS     => 'Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2013 by Cisco Systems, Inc.
Compiled Wed 11-Sep-13 02:04 by prod_rel_team',
                CONTACT      => 'dsi.sesi.reseau@inria.fr.',
                NAME         => 'sw-30c07-01-dc1.inria.fr',
                IPS          => {
                    IP => [
                        '192.168.0.15',
                    ],
                },
                UPTIME       => '(181517513) 21 days, 0:12:55.13',
                CPU          => '98',
                RAM          => '512',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Vlan1',
                        IFDESCR          => 'Vlan1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:40',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(25956) 0:04:19.56',
                        IFINOCTETS       => '24377',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '2',
                        IFNAME           => 'Vlan2',
                        IFDESCR          => 'Vlan2',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.0.15',
                        MAC              => '64:e9:50:7b:16:41',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(78584683) 9 days, 2:17:26.83',
                        IFINOCTETS       => '217306241',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '16262701',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5179',
                        IFNAME           => 'StackPort1',
                        IFDESCR          => 'StackPort1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7654) 0:01:16.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5180',
                        IFNAME           => 'StackSub-St1-1',
                        IFDESCR          => 'StackSub-St1-1',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                    {
                        IFNUMBER         => '5181',
                        IFNAME           => 'StackSub-St1-2',
                        IFDESCR          => 'StackSub-St1-2',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                    },
                    {
                        IFNUMBER         => '10101',
                        IFNAME           => 'GigabitEthernet1/0/1',
                        IFDESCR          => 'GigabitEthernet1/0/1',
                        IFALIAS          => 'qlf-sesi-esx1-adm ',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:01',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(320810) 0:53:28.10',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '42114110',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4954891',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10102',
                        IFNAME           => 'GigabitEthernet1/0/2',
                        IFDESCR          => 'GigabitEthernet1/0/2',
                        IFALIAS          => 'qlf-sesi-esx3-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:02',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10103',
                        IFNAME           => 'GigabitEthernet1/0/3',
                        IFDESCR          => 'GigabitEthernet1/0/3',
                        IFALIAS          => 'sesi-esx5-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10104',
                        IFNAME           => 'GigabitEthernet1/0/4',
                        IFDESCR          => 'GigabitEthernet1/0/4',
                        IFALIAS          => 'sesi-esx6-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:04',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10105',
                        IFNAME           => 'GigabitEthernet1/0/5',
                        IFDESCR          => 'GigabitEthernet1/0/5',
                        IFALIAS          => 'sesi-esx9-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:05',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10106',
                        IFNAME           => 'GigabitEthernet1/0/6',
                        IFDESCR          => 'GigabitEthernet1/0/6',
                        IFALIAS          => 'sesi-esx10-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:06',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10107',
                        IFNAME           => 'GigabitEthernet1/0/7',
                        IFDESCR          => 'GigabitEthernet1/0/7',
                        IFALIAS          => 'sesi-esx13-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:07',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10108',
                        IFNAME           => 'GigabitEthernet1/0/8',
                        IFDESCR          => 'GigabitEthernet1/0/8',
                        IFALIAS          => 'sesi-esx14-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:08',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10109',
                        IFNAME           => 'GigabitEthernet1/0/9',
                        IFDESCR          => 'GigabitEthernet1/0/9',
                        IFALIAS          => 'sesi-esx16-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:09',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10110',
                        IFNAME           => 'GigabitEthernet1/0/10',
                        IFDESCR          => 'GigabitEthernet1/0/10',
                        IFALIAS          => 'sesi-syslog-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:0a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10111',
                        IFNAME           => 'GigabitEthernet1/0/11',
                        IFDESCR          => 'GigabitEthernet1/0/11',
                        IFALIAS          => 'sesi-nagios-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:0b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10112',
                        IFNAME           => 'GigabitEthernet1/0/12',
                        IFDESCR          => 'GigabitEthernet1/0/12',
                        IFALIAS          => 'sesi-nagios-admin',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:0c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10113',
                        IFNAME           => 'GigabitEthernet1/0/13',
                        IFDESCR          => 'GigabitEthernet1/0/13',
                        IFALIAS          => 'infrahv3-adm',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:0d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10114',
                        IFNAME           => 'GigabitEthernet1/0/14',
                        IFDESCR          => 'GigabitEthernet1/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:0e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10115',
                        IFNAME           => 'GigabitEthernet1/0/15',
                        IFDESCR          => 'GigabitEthernet1/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:0f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10116',
                        IFNAME           => 'GigabitEthernet1/0/16',
                        IFDESCR          => 'GigabitEthernet1/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:10',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10117',
                        IFNAME           => 'GigabitEthernet1/0/17',
                        IFDESCR          => 'GigabitEthernet1/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:11',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10118',
                        IFNAME           => 'GigabitEthernet1/0/18',
                        IFDESCR          => 'GigabitEthernet1/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:12',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10119',
                        IFNAME           => 'GigabitEthernet1/0/19',
                        IFDESCR          => 'GigabitEthernet1/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:13',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10120',
                        IFNAME           => 'GigabitEthernet1/0/20',
                        IFDESCR          => 'GigabitEthernet1/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:14',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10121',
                        IFNAME           => 'GigabitEthernet1/0/21',
                        IFDESCR          => 'GigabitEthernet1/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:15',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10122',
                        IFNAME           => 'GigabitEthernet1/0/22',
                        IFDESCR          => 'GigabitEthernet1/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:16',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10123',
                        IFNAME           => 'GigabitEthernet1/0/23',
                        IFDESCR          => 'GigabitEthernet1/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:17',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10124',
                        IFNAME           => 'GigabitEthernet1/0/24',
                        IFDESCR          => 'GigabitEthernet1/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:18',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10125',
                        IFNAME           => 'GigabitEthernet1/0/25',
                        IFDESCR          => 'GigabitEthernet1/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:19',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(78584680) 9 days, 2:17:26.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1364062879',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '29581380',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR  => 'GigabitEthernet1/0/25',
                                SYSNAME  => 'st-30rs04-01-dc1.inria.fr',
                                SYSDESCR => '"Cisco IOS Software, C2960X Software (C2960X-UNIVERSALK9-M), Version 15.0(2)EX3, RELEASE SOFTWARE (fc1)',
                                IP       => '192.168.0.16',
                                MODEL    => 'cisco WS-C2960X-24TS-L',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '10126',
                        IFNAME           => 'GigabitEthernet1/0/26',
                        IFDESCR          => 'GigabitEthernet1/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:1a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10127',
                        IFNAME           => 'GigabitEthernet1/0/27',
                        IFDESCR          => 'GigabitEthernet1/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:1b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '10128',
                        IFNAME           => 'GigabitEthernet1/0/28',
                        IFDESCR          => 'GigabitEthernet1/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:1c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8327) 0:01:23.27',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        TRUNK            => '1',
                    },
                    {
                        IFNUMBER         => '14001',
                        IFNAME           => 'Null0',
                        IFDESCR          => 'Null0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1500',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '14002',
                        IFNAME           => 'FastEthernet0',
                        IFDESCR          => 'FastEthernet0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '64:e9:50:7b:16:39',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8736) 0:01:27.36',
                        IFPORTDUPLEX     => '1',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        }
    ],
);

setPlan(scalar keys %tests);

my $dictionary = getDictionnary();
my $index      = getIndex();

foreach my $test (sort keys %tests) {
    my $snmp  = getSNMP($test);
    my $model = getModel($index, $tests{$test}->[1]->{MODELSNMP});

    my %device0 = getDeviceInfo(
        snmp       => $snmp,
        datadir    => './share'
    );
    cmp_deeply(\%device0, $tests{$test}->[0], "$test: base stage");

    my %device1 = getDeviceInfo(
        snmp       => $snmp,
        dictionary => $dictionary,
        datadir    => './share'
    );
    cmp_deeply(\%device1, $tests{$test}->[1], "$test: base + dictionnary stage");

    my $device3 = getDeviceFullInfo(
        snmp    => $snmp,
        model   => $model,
        datadir => './share'
    );
    cmp_deeply($device3, $tests{$test}->[2], "$test: base + model stage");
}
